Annotation Type ImmutableEntityStyle
A custom annotation that is intended to be applied with Value.Immutable,
on
package classes.
invalid reference
io.github.eggy03.dmidecode.entity
It modifies the naming and structural style of the generated immutable implementations via Value.Style
- Since:
- 0.2.0