Uses of Annotation Type
io.github.eggy03.dmidecode.annotation.ImmutableEntityStyle
Packages that use ImmutableEntityStyle
Package
Description
-
Uses of ImmutableEntityStyle in io.github.eggy03.dmidecode.entity.board
Classes in io.github.eggy03.dmidecode.entity.board with annotations of type ImmutableEntityStyleModifier and TypeClassDescriptionclassImmutable representation of a baseboard (motherboard) device retrieved via DMI.classImmutable representation of BIOS information retrieved via DMI.classImmutable representation of BIOS language information retrieved via DMI.classImmutable representation of system chassis information retrieved via DMI.classImmutable representation of port connector information retrieved via DMI.classImmutable representation of system slot information retrieved via DMI. -
Uses of ImmutableEntityStyle in io.github.eggy03.dmidecode.entity.memory
Classes in io.github.eggy03.dmidecode.entity.memory with annotations of type ImmutableEntityStyleModifier and TypeClassDescriptionclassImmutable representation of memory device information retrieved via DMI.classImmutable representation of physical memory array information retrieved via DMI. -
Uses of ImmutableEntityStyle in io.github.eggy03.dmidecode.entity.peripheral
Classes in io.github.eggy03.dmidecode.entity.peripheral with annotations of type ImmutableEntityStyleModifier and TypeClassDescriptionclassImmutable representation of portable battery information retrieved via DMI. -
Uses of ImmutableEntityStyle in io.github.eggy03.dmidecode.entity.processor
Classes in io.github.eggy03.dmidecode.entity.processor with annotations of type ImmutableEntityStyleModifier and TypeClassDescriptionclassImmutable representation of processor cache information retrieved via DMI.classImmutable representation of processor information retrieved via DMI. -
Uses of ImmutableEntityStyle in io.github.eggy03.dmidecode.entity.system
Classes in io.github.eggy03.dmidecode.entity.system with annotations of type ImmutableEntityStyleModifier and TypeClassDescriptionclassImmutable representation of system information retrieved via DMI.