Class AbstractDMISystemSlots

java.lang.Object
io.github.eggy03.dmidecode.entity.board.AbstractDMISystemSlots
Direct Known Subclasses:
DMISystemSlots, DMISystemSlots.Json

@Immutable @NullMarked public abstract class AbstractDMISystemSlots extends Object
Immutable representation of system slot information retrieved via DMI.

Fields correspond to properties reported by dmidecode for the System Slots (Type 9) SMBIOS structure.

Instances of this class are thread-safe.

Usage example


 DMISystemSlots slot = new DMISystemSlots.Builder()
     .designation("PCIEX16")
     .type("PCI Express")
     .currentUsage("In Use")
     .busAddress("0000:01:00.0")
     .build();

 // Create a modified copy
 DMISystemSlots updated = slot
     .withCurrentUsage("Available");
 
Since:
0.2.0
  • Constructor Details

    • AbstractDMISystemSlots

      public AbstractDMISystemSlots()
  • Method Details

    • designation

      public abstract @Nullable String designation()
    • type

      public abstract @Nullable String type()
    • currentUsage

      public abstract @Nullable String currentUsage()
    • length

      public abstract @Nullable String length()
    • id

      public abstract @Nullable Integer id()
    • characteristics

      public abstract @Nullable List<@Nullable String> characteristics()
    • busAddress

      public abstract @Nullable String busAddress()
    • toString

      public String toString()
      Overrides:
      toString in class Object