Class ImmutableDMIBIOSLanguage

java.lang.Object
io.github.eggy03.dmidecode.entity.board.DMIBIOSLanguage
io.github.eggy03.dmidecode.entity.board.ImmutableDMIBIOSLanguage

@Generated(from="DMIBIOSLanguage", generator="Immutables") @Generated("org.immutables.processor.ProxyProcessor") public final class ImmutableDMIBIOSLanguage extends DMIBIOSLanguage
Immutable implementation of DMIBIOSLanguage.

Use the builder to create immutable instances: new ImmutableDMIBIOSLanguage.Builder().

  • Field Details

    • installableLanguages

      private final @Nullable List<String> installableLanguages
    • currentLanguage

      private final @Nullable String currentLanguage
  • Constructor Details

    • ImmutableDMIBIOSLanguage

      private ImmutableDMIBIOSLanguage(@Nullable List<String> installableLanguages, @Nullable String currentLanguage)
  • Method Details

    • installableLanguages

      public @Nullable List<String> installableLanguages()
      Specified by:
      installableLanguages in class DMIBIOSLanguage
      Returns:
      The value of the installableLanguages attribute
    • currentLanguage

      public @Nullable String currentLanguage()
      Specified by:
      currentLanguage in class DMIBIOSLanguage
      Returns:
      The value of the currentLanguage attribute
    • withInstallableLanguages

      public final ImmutableDMIBIOSLanguage withInstallableLanguages(@Nullable String @Nullable ... elements)
      Copy the current immutable object with elements that replace the content of installableLanguages.
      Parameters:
      elements - The elements to set
      Returns:
      A modified copy of this object
    • withInstallableLanguages

      public final ImmutableDMIBIOSLanguage withInstallableLanguages(@Nullable Iterable<@Nullable String> elements)
      Copy the current immutable object with elements that replace the content of installableLanguages. A shallow reference equality check is used to prevent copying of the same value by returning this.
      Parameters:
      elements - An iterable of installableLanguages elements to set
      Returns:
      A modified copy or this if not changed
    • withCurrentLanguage

      public final ImmutableDMIBIOSLanguage withCurrentLanguage(@Nullable String value)
      Copy the current immutable object by setting a value for the currentLanguage attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for currentLanguage (can be null)
      Returns:
      A modified copy or the this object
    • equals

      public boolean equals(@Nullable Object another)
      This instance is equal to all instances of ImmutableDMIBIOSLanguage that have equal attribute values.
      Overrides:
      equals in class Object
      Returns:
      true if this is equal to another instance
    • equalsByValue

      private boolean equalsByValue(ImmutableDMIBIOSLanguage another)
    • hashCode

      public int hashCode()
      Computes a hash code from attributes: installableLanguages, currentLanguage.
      Overrides:
      hashCode in class Object
      Returns:
      hashCode value
    • toString

      public String toString()
      Prints the immutable value DMIBIOSLanguage with attribute values.
      Overrides:
      toString in class Object
      Returns:
      A string representation of the value
    • fromJson

      Deprecated.
      Do not use this method directly, it exists only for the Jackson-binding infrastructure
      Parameters:
      json - A JSON-bindable data structure
      Returns:
      An immutable value type
    • copyOf

      public static ImmutableDMIBIOSLanguage copyOf(DMIBIOSLanguage instance)
      Creates an immutable copy of a DMIBIOSLanguage value. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.
      Parameters:
      instance - The instance to copy
      Returns:
      A copied immutable DMIBIOSLanguage instance
    • createSafeList

      private static <T> List<T> createSafeList(Iterable<? extends T> iterable, boolean checkNulls, boolean skipNulls)
    • createUnmodifiableList

      private static <T> List<T> createUnmodifiableList(boolean clone, List<? extends T> list)