Class ImmutableDMIBaseboard

java.lang.Object
io.github.eggy03.dmidecode.entity.board.DMIBaseboard
io.github.eggy03.dmidecode.entity.board.ImmutableDMIBaseboard

@Generated(from="DMIBaseboard", generator="Immutables") @Generated("org.immutables.processor.ProxyProcessor") public final class ImmutableDMIBaseboard extends DMIBaseboard
Immutable implementation of DMIBaseboard.

Use the builder to create immutable instances: new ImmutableDMIBaseboard.Builder().

  • Field Details

    • manufacturer

      private final @Nullable String manufacturer
    • productName

      private final @Nullable String productName
    • version

      private final @Nullable String version
    • serialNumber

      private final @Nullable String serialNumber
    • assetTag

      private final @Nullable String assetTag
    • features

      private final @Nullable List<String> features
    • locationInChassis

      private final @Nullable String locationInChassis
    • chassisHandle

      private final @Nullable String chassisHandle
    • type

      private final @Nullable String type
    • containedObjectHandles

      private final @Nullable Integer containedObjectHandles
  • Constructor Details

    • ImmutableDMIBaseboard

      private ImmutableDMIBaseboard(@Nullable String manufacturer, @Nullable String productName, @Nullable String version, @Nullable String serialNumber, @Nullable String assetTag, @Nullable List<String> features, @Nullable String locationInChassis, @Nullable String chassisHandle, @Nullable String type, @Nullable Integer containedObjectHandles)
  • Method Details

    • manufacturer

      public @Nullable String manufacturer()
      Specified by:
      manufacturer in class DMIBaseboard
      Returns:
      The value of the manufacturer attribute
    • productName

      public @Nullable String productName()
      Specified by:
      productName in class DMIBaseboard
      Returns:
      The value of the productName attribute
    • version

      public @Nullable String version()
      Specified by:
      version in class DMIBaseboard
      Returns:
      The value of the version attribute
    • serialNumber

      public @Nullable String serialNumber()
      Specified by:
      serialNumber in class DMIBaseboard
      Returns:
      The value of the serialNumber attribute
    • assetTag

      public @Nullable String assetTag()
      Specified by:
      assetTag in class DMIBaseboard
      Returns:
      The value of the assetTag attribute
    • features

      public @Nullable List<String> features()
      Specified by:
      features in class DMIBaseboard
      Returns:
      The value of the features attribute
    • locationInChassis

      public @Nullable String locationInChassis()
      Specified by:
      locationInChassis in class DMIBaseboard
      Returns:
      The value of the locationInChassis attribute
    • chassisHandle

      public @Nullable String chassisHandle()
      Specified by:
      chassisHandle in class DMIBaseboard
      Returns:
      The value of the chassisHandle attribute
    • type

      public @Nullable String type()
      Specified by:
      type in class DMIBaseboard
      Returns:
      The value of the type attribute
    • containedObjectHandles

      public @Nullable Integer containedObjectHandles()
      Specified by:
      containedObjectHandles in class DMIBaseboard
      Returns:
      The value of the containedObjectHandles attribute
    • withManufacturer

      public final ImmutableDMIBaseboard withManufacturer(@Nullable String value)
      Copy the current immutable object by setting a value for the manufacturer attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for manufacturer (can be null)
      Returns:
      A modified copy or the this object
    • withProductName

      public final ImmutableDMIBaseboard withProductName(@Nullable String value)
      Copy the current immutable object by setting a value for the productName attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for productName (can be null)
      Returns:
      A modified copy or the this object
    • withVersion

      public final ImmutableDMIBaseboard withVersion(@Nullable String value)
      Copy the current immutable object by setting a value for the version attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for version (can be null)
      Returns:
      A modified copy or the this object
    • withSerialNumber

      public final ImmutableDMIBaseboard withSerialNumber(@Nullable String value)
      Copy the current immutable object by setting a value for the serialNumber attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for serialNumber (can be null)
      Returns:
      A modified copy or the this object
    • withAssetTag

      public final ImmutableDMIBaseboard withAssetTag(@Nullable String value)
      Copy the current immutable object by setting a value for the assetTag attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for assetTag (can be null)
      Returns:
      A modified copy or the this object
    • withFeatures

      public final ImmutableDMIBaseboard withFeatures(@Nullable String @Nullable ... elements)
      Copy the current immutable object with elements that replace the content of features.
      Parameters:
      elements - The elements to set
      Returns:
      A modified copy of this object
    • withFeatures

      public final ImmutableDMIBaseboard withFeatures(@Nullable Iterable<@Nullable String> elements)
      Copy the current immutable object with elements that replace the content of features. A shallow reference equality check is used to prevent copying of the same value by returning this.
      Parameters:
      elements - An iterable of features elements to set
      Returns:
      A modified copy or this if not changed
    • withLocationInChassis

      public final ImmutableDMIBaseboard withLocationInChassis(@Nullable String value)
      Copy the current immutable object by setting a value for the locationInChassis attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for locationInChassis (can be null)
      Returns:
      A modified copy or the this object
    • withChassisHandle

      public final ImmutableDMIBaseboard withChassisHandle(@Nullable String value)
      Copy the current immutable object by setting a value for the chassisHandle attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for chassisHandle (can be null)
      Returns:
      A modified copy or the this object
    • withType

      public final ImmutableDMIBaseboard withType(@Nullable String value)
      Copy the current immutable object by setting a value for the type attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for type (can be null)
      Returns:
      A modified copy or the this object
    • withContainedObjectHandles

      public final ImmutableDMIBaseboard withContainedObjectHandles(@Nullable Integer value)
      Copy the current immutable object by setting a value for the containedObjectHandles attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for containedObjectHandles (can be null)
      Returns:
      A modified copy or the this object
    • equals

      public boolean equals(@Nullable Object another)
      This instance is equal to all instances of ImmutableDMIBaseboard that have equal attribute values.
      Overrides:
      equals in class Object
      Returns:
      true if this is equal to another instance
    • equalsByValue

      private boolean equalsByValue(ImmutableDMIBaseboard another)
    • hashCode

      public int hashCode()
      Computes a hash code from attributes: manufacturer, productName, version, serialNumber, assetTag, features, locationInChassis, chassisHandle, type, containedObjectHandles.
      Overrides:
      hashCode in class Object
      Returns:
      hashCode value
    • toString

      public String toString()
      Prints the immutable value DMIBaseboard with attribute values.
      Overrides:
      toString in class Object
      Returns:
      A string representation of the value
    • fromJson

      Deprecated.
      Do not use this method directly, it exists only for the Jackson-binding infrastructure
      Parameters:
      json - A JSON-bindable data structure
      Returns:
      An immutable value type
    • copyOf

      public static ImmutableDMIBaseboard copyOf(DMIBaseboard instance)
      Creates an immutable copy of a DMIBaseboard value. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.
      Parameters:
      instance - The instance to copy
      Returns:
      A copied immutable DMIBaseboard instance
    • createSafeList

      private static <T> List<T> createSafeList(Iterable<? extends T> iterable, boolean checkNulls, boolean skipNulls)
    • createUnmodifiableList

      private static <T> List<T> createUnmodifiableList(boolean clone, List<? extends T> list)