Class ImmutableDMISystemSlots

java.lang.Object
io.github.eggy03.dmidecode.entity.board.DMISystemSlots
io.github.eggy03.dmidecode.entity.board.ImmutableDMISystemSlots

@Generated(from="DMISystemSlots", generator="Immutables") @Generated("org.immutables.processor.ProxyProcessor") public final class ImmutableDMISystemSlots extends DMISystemSlots
Immutable implementation of DMISystemSlots.

Use the builder to create immutable instances: new ImmutableDMISystemSlots.Builder().

  • Field Details

    • designation

      private final @Nullable String designation
    • type

      private final @Nullable String type
    • currentUsage

      private final @Nullable String currentUsage
    • length

      private final @Nullable String length
    • id

      private final @Nullable Integer id
    • characteristics

      private final @Nullable List<String> characteristics
    • busAddress

      private final @Nullable String busAddress
  • Constructor Details

    • ImmutableDMISystemSlots

      private ImmutableDMISystemSlots(@Nullable String designation, @Nullable String type, @Nullable String currentUsage, @Nullable String length, @Nullable Integer id, @Nullable List<String> characteristics, @Nullable String busAddress)
  • Method Details

    • designation

      public @Nullable String designation()
      Specified by:
      designation in class DMISystemSlots
      Returns:
      The value of the designation attribute
    • type

      public @Nullable String type()
      Specified by:
      type in class DMISystemSlots
      Returns:
      The value of the type attribute
    • currentUsage

      public @Nullable String currentUsage()
      Specified by:
      currentUsage in class DMISystemSlots
      Returns:
      The value of the currentUsage attribute
    • length

      public @Nullable String length()
      Specified by:
      length in class DMISystemSlots
      Returns:
      The value of the length attribute
    • id

      public @Nullable Integer id()
      Specified by:
      id in class DMISystemSlots
      Returns:
      The value of the id attribute
    • characteristics

      public @Nullable List<String> characteristics()
      Specified by:
      characteristics in class DMISystemSlots
      Returns:
      The value of the characteristics attribute
    • busAddress

      public @Nullable String busAddress()
      Specified by:
      busAddress in class DMISystemSlots
      Returns:
      The value of the busAddress attribute
    • withDesignation

      public final ImmutableDMISystemSlots withDesignation(@Nullable String value)
      Copy the current immutable object by setting a value for the designation attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for designation (can be null)
      Returns:
      A modified copy or the this object
    • withType

      public final ImmutableDMISystemSlots withType(@Nullable String value)
      Copy the current immutable object by setting a value for the type attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for type (can be null)
      Returns:
      A modified copy or the this object
    • withCurrentUsage

      public final ImmutableDMISystemSlots withCurrentUsage(@Nullable String value)
      Copy the current immutable object by setting a value for the currentUsage attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for currentUsage (can be null)
      Returns:
      A modified copy or the this object
    • withLength

      public final ImmutableDMISystemSlots withLength(@Nullable String value)
      Copy the current immutable object by setting a value for the length attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for length (can be null)
      Returns:
      A modified copy or the this object
    • withId

      public final ImmutableDMISystemSlots withId(@Nullable Integer value)
      Copy the current immutable object by setting a value for the id attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for id (can be null)
      Returns:
      A modified copy or the this object
    • withCharacteristics

      public final ImmutableDMISystemSlots withCharacteristics(@Nullable String @Nullable ... elements)
      Copy the current immutable object with elements that replace the content of characteristics.
      Parameters:
      elements - The elements to set
      Returns:
      A modified copy of this object
    • withCharacteristics

      public final ImmutableDMISystemSlots withCharacteristics(@Nullable Iterable<@Nullable String> elements)
      Copy the current immutable object with elements that replace the content of characteristics. A shallow reference equality check is used to prevent copying of the same value by returning this.
      Parameters:
      elements - An iterable of characteristics elements to set
      Returns:
      A modified copy or this if not changed
    • withBusAddress

      public final ImmutableDMISystemSlots withBusAddress(@Nullable String value)
      Copy the current immutable object by setting a value for the busAddress attribute. An equals check used to prevent copying of the same value by returning this.
      Parameters:
      value - A new value for busAddress (can be null)
      Returns:
      A modified copy or the this object
    • equals

      public boolean equals(@Nullable Object another)
      This instance is equal to all instances of ImmutableDMISystemSlots that have equal attribute values.
      Overrides:
      equals in class Object
      Returns:
      true if this is equal to another instance
    • equalsByValue

      private boolean equalsByValue(ImmutableDMISystemSlots another)
    • hashCode

      public int hashCode()
      Computes a hash code from attributes: designation, type, currentUsage, length, id, characteristics, busAddress.
      Overrides:
      hashCode in class Object
      Returns:
      hashCode value
    • toString

      public String toString()
      Prints the immutable value DMISystemSlots with attribute values.
      Overrides:
      toString in class Object
      Returns:
      A string representation of the value
    • fromJson

      Deprecated.
      Do not use this method directly, it exists only for the Jackson-binding infrastructure
      Parameters:
      json - A JSON-bindable data structure
      Returns:
      An immutable value type
    • copyOf

      public static ImmutableDMISystemSlots copyOf(DMISystemSlots instance)
      Creates an immutable copy of a DMISystemSlots value. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.
      Parameters:
      instance - The instance to copy
      Returns:
      A copied immutable DMISystemSlots instance
    • createSafeList

      private static <T> List<T> createSafeList(Iterable<? extends T> iterable, boolean checkNulls, boolean skipNulls)
    • createUnmodifiableList

      private static <T> List<T> createUnmodifiableList(boolean clone, List<? extends T> list)