Class DMIPhysicalMemoryArray

java.lang.Object
io.github.eggy03.dmidecode.entity.memory.DMIPhysicalMemoryArray
Direct Known Subclasses:
ImmutableDMIPhysicalMemoryArray, ImmutableDMIPhysicalMemoryArray.Json

@Immutable @NullMarked public abstract class DMIPhysicalMemoryArray extends Object
Immutable representation of physical memory array information retrieved via DMI.

Fields correspond to properties reported by dmidecode for the Physical Memory Array (Type 16) SMBIOS structure.

Instances of this class are thread-safe.

Since:
0.2.0
  • Constructor Details

    • DMIPhysicalMemoryArray

      public DMIPhysicalMemoryArray()
  • Method Details

    • location

      public abstract @Nullable String location()
    • use

      public abstract @Nullable String use()
    • errorCorrectionType

      public abstract @Nullable String errorCorrectionType()
    • maximumCapacity

      public abstract @Nullable String maximumCapacity()
    • errorInformationHandle

      public abstract @Nullable String errorInformationHandle()
    • numberOfDevices

      public abstract @Nullable Integer numberOfDevices()
    • toJson

      public String toJson()