Class DMIPhysicalMemoryArray.Json

java.lang.Object
io.github.eggy03.dmidecode.entity.memory.AbstractDMIPhysicalMemoryArray
io.github.eggy03.dmidecode.entity.memory.DMIPhysicalMemoryArray.Json
Enclosing class:
DMIPhysicalMemoryArray

@Generated(from="AbstractDMIPhysicalMemoryArray", generator="Immutables") @Deprecated static final class DMIPhysicalMemoryArray.Json extends AbstractDMIPhysicalMemoryArray
Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Utility type used to correctly read immutable object from JSON representation.