Class ImmutableDMIMemoryDevice.Builder

java.lang.Object
io.github.eggy03.dmidecode.entity.memory.ImmutableDMIMemoryDevice.Builder
Enclosing class:
ImmutableDMIMemoryDevice

@Generated(from="DMIMemoryDevice", generator="Immutables") public static final class ImmutableDMIMemoryDevice.Builder extends Object
Builds instances of type ImmutableDMIMemoryDevice. Initialize attributes and then invoke the build() method to create an immutable instance.

Builder is not thread-safe and generally should not be stored in a field or collection, but instead used immediately to create instances.

  • Field Details

    • arrayHandle

      private @Nullable String arrayHandle
    • errorInformationHandle

      private @Nullable String errorInformationHandle
    • totalWidth

      private @Nullable String totalWidth
    • dataWidth

      private @Nullable String dataWidth
    • size

      private @Nullable String size
    • formFactor

      private @Nullable String formFactor
    • set

      private @Nullable String set
    • locator

      private @Nullable String locator
    • bankLocator

      private @Nullable String bankLocator
    • type

      private @Nullable String type
    • typeDetail

      private @Nullable String typeDetail
    • speed

      private @Nullable String speed
    • manufacturer

      private @Nullable String manufacturer
    • serialNumber

      private @Nullable String serialNumber
    • assetTag

      private @Nullable String assetTag
    • partNumber

      private @Nullable String partNumber
    • rank

      private @Nullable Integer rank
    • configuredMemorySpeed

      private @Nullable String configuredMemorySpeed
    • minimumVoltage

      private @Nullable String minimumVoltage
    • maximumVoltage

      private @Nullable String maximumVoltage
    • configuredVoltage

      private @Nullable String configuredVoltage
    • memoryTechnology

      private @Nullable String memoryTechnology
    • memoryOperatingModeCapability

      private @Nullable String memoryOperatingModeCapability
    • firmwareVersion

      private @Nullable String firmwareVersion
    • moduleManufacturerId

      private @Nullable String moduleManufacturerId
    • moduleProductId

      private @Nullable String moduleProductId
    • memorySubsystemControllerManufacturerId

      private @Nullable String memorySubsystemControllerManufacturerId
    • memorySubsystemControllerProductId

      private @Nullable String memorySubsystemControllerProductId
    • nonVolatileSize

      private @Nullable String nonVolatileSize
    • volatileSize

      private @Nullable String volatileSize
    • cacheSize

      private @Nullable String cacheSize
    • logicalSize

      private @Nullable String logicalSize
  • Constructor Details

  • Method Details

    • from

      public final ImmutableDMIMemoryDevice.Builder from(DMIMemoryDevice instance)
      Fill a builder with attribute values from the provided DMIMemoryDevice instance. Regular attribute values will be replaced with those from the given instance. Absent optional values will not replace present values.
      Parameters:
      instance - The instance from which to copy values
      Returns:
      this builder for use in a chained invocation
    • arrayHandle

      public final ImmutableDMIMemoryDevice.Builder arrayHandle(@Nullable String arrayHandle)
      Initializes the value for the arrayHandle attribute.
      Parameters:
      arrayHandle - The value for arrayHandle (can be null)
      Returns:
      this builder for use in a chained invocation
    • errorInformationHandle

      public final ImmutableDMIMemoryDevice.Builder errorInformationHandle(@Nullable String errorInformationHandle)
      Initializes the value for the errorInformationHandle attribute.
      Parameters:
      errorInformationHandle - The value for errorInformationHandle (can be null)
      Returns:
      this builder for use in a chained invocation
    • totalWidth

      public final ImmutableDMIMemoryDevice.Builder totalWidth(@Nullable String totalWidth)
      Initializes the value for the totalWidth attribute.
      Parameters:
      totalWidth - The value for totalWidth (can be null)
      Returns:
      this builder for use in a chained invocation
    • dataWidth

      public final ImmutableDMIMemoryDevice.Builder dataWidth(@Nullable String dataWidth)
      Initializes the value for the dataWidth attribute.
      Parameters:
      dataWidth - The value for dataWidth (can be null)
      Returns:
      this builder for use in a chained invocation
    • size

      public final ImmutableDMIMemoryDevice.Builder size(@Nullable String size)
      Initializes the value for the size attribute.
      Parameters:
      size - The value for size (can be null)
      Returns:
      this builder for use in a chained invocation
    • formFactor

      public final ImmutableDMIMemoryDevice.Builder formFactor(@Nullable String formFactor)
      Initializes the value for the formFactor attribute.
      Parameters:
      formFactor - The value for formFactor (can be null)
      Returns:
      this builder for use in a chained invocation
    • set

      public final ImmutableDMIMemoryDevice.Builder set(@Nullable String set)
      Initializes the value for the set attribute.
      Parameters:
      set - The value for set (can be null)
      Returns:
      this builder for use in a chained invocation
    • locator

      public final ImmutableDMIMemoryDevice.Builder locator(@Nullable String locator)
      Initializes the value for the locator attribute.
      Parameters:
      locator - The value for locator (can be null)
      Returns:
      this builder for use in a chained invocation
    • bankLocator

      public final ImmutableDMIMemoryDevice.Builder bankLocator(@Nullable String bankLocator)
      Initializes the value for the bankLocator attribute.
      Parameters:
      bankLocator - The value for bankLocator (can be null)
      Returns:
      this builder for use in a chained invocation
    • type

      public final ImmutableDMIMemoryDevice.Builder type(@Nullable String type)
      Initializes the value for the type attribute.
      Parameters:
      type - The value for type (can be null)
      Returns:
      this builder for use in a chained invocation
    • typeDetail

      public final ImmutableDMIMemoryDevice.Builder typeDetail(@Nullable String typeDetail)
      Initializes the value for the typeDetail attribute.
      Parameters:
      typeDetail - The value for typeDetail (can be null)
      Returns:
      this builder for use in a chained invocation
    • speed

      public final ImmutableDMIMemoryDevice.Builder speed(@Nullable String speed)
      Initializes the value for the speed attribute.
      Parameters:
      speed - The value for speed (can be null)
      Returns:
      this builder for use in a chained invocation
    • manufacturer

      public final ImmutableDMIMemoryDevice.Builder manufacturer(@Nullable String manufacturer)
      Initializes the value for the manufacturer attribute.
      Parameters:
      manufacturer - The value for manufacturer (can be null)
      Returns:
      this builder for use in a chained invocation
    • serialNumber

      public final ImmutableDMIMemoryDevice.Builder serialNumber(@Nullable String serialNumber)
      Initializes the value for the serialNumber attribute.
      Parameters:
      serialNumber - The value for serialNumber (can be null)
      Returns:
      this builder for use in a chained invocation
    • assetTag

      public final ImmutableDMIMemoryDevice.Builder assetTag(@Nullable String assetTag)
      Initializes the value for the assetTag attribute.
      Parameters:
      assetTag - The value for assetTag (can be null)
      Returns:
      this builder for use in a chained invocation
    • partNumber

      public final ImmutableDMIMemoryDevice.Builder partNumber(@Nullable String partNumber)
      Initializes the value for the partNumber attribute.
      Parameters:
      partNumber - The value for partNumber (can be null)
      Returns:
      this builder for use in a chained invocation
    • rank

      public final ImmutableDMIMemoryDevice.Builder rank(@Nullable Integer rank)
      Initializes the value for the rank attribute.
      Parameters:
      rank - The value for rank (can be null)
      Returns:
      this builder for use in a chained invocation
    • configuredMemorySpeed

      public final ImmutableDMIMemoryDevice.Builder configuredMemorySpeed(@Nullable String configuredMemorySpeed)
      Initializes the value for the configuredMemorySpeed attribute.
      Parameters:
      configuredMemorySpeed - The value for configuredMemorySpeed (can be null)
      Returns:
      this builder for use in a chained invocation
    • minimumVoltage

      public final ImmutableDMIMemoryDevice.Builder minimumVoltage(@Nullable String minimumVoltage)
      Initializes the value for the minimumVoltage attribute.
      Parameters:
      minimumVoltage - The value for minimumVoltage (can be null)
      Returns:
      this builder for use in a chained invocation
    • maximumVoltage

      public final ImmutableDMIMemoryDevice.Builder maximumVoltage(@Nullable String maximumVoltage)
      Initializes the value for the maximumVoltage attribute.
      Parameters:
      maximumVoltage - The value for maximumVoltage (can be null)
      Returns:
      this builder for use in a chained invocation
    • configuredVoltage

      public final ImmutableDMIMemoryDevice.Builder configuredVoltage(@Nullable String configuredVoltage)
      Initializes the value for the configuredVoltage attribute.
      Parameters:
      configuredVoltage - The value for configuredVoltage (can be null)
      Returns:
      this builder for use in a chained invocation
    • memoryTechnology

      public final ImmutableDMIMemoryDevice.Builder memoryTechnology(@Nullable String memoryTechnology)
      Initializes the value for the memoryTechnology attribute.
      Parameters:
      memoryTechnology - The value for memoryTechnology (can be null)
      Returns:
      this builder for use in a chained invocation
    • memoryOperatingModeCapability

      public final ImmutableDMIMemoryDevice.Builder memoryOperatingModeCapability(@Nullable String memoryOperatingModeCapability)
      Initializes the value for the memoryOperatingModeCapability attribute.
      Parameters:
      memoryOperatingModeCapability - The value for memoryOperatingModeCapability (can be null)
      Returns:
      this builder for use in a chained invocation
    • firmwareVersion

      public final ImmutableDMIMemoryDevice.Builder firmwareVersion(@Nullable String firmwareVersion)
      Initializes the value for the firmwareVersion attribute.
      Parameters:
      firmwareVersion - The value for firmwareVersion (can be null)
      Returns:
      this builder for use in a chained invocation
    • moduleManufacturerId

      public final ImmutableDMIMemoryDevice.Builder moduleManufacturerId(@Nullable String moduleManufacturerId)
      Initializes the value for the moduleManufacturerId attribute.
      Parameters:
      moduleManufacturerId - The value for moduleManufacturerId (can be null)
      Returns:
      this builder for use in a chained invocation
    • moduleProductId

      public final ImmutableDMIMemoryDevice.Builder moduleProductId(@Nullable String moduleProductId)
      Initializes the value for the moduleProductId attribute.
      Parameters:
      moduleProductId - The value for moduleProductId (can be null)
      Returns:
      this builder for use in a chained invocation
    • memorySubsystemControllerManufacturerId

      public final ImmutableDMIMemoryDevice.Builder memorySubsystemControllerManufacturerId(@Nullable String memorySubsystemControllerManufacturerId)
      Initializes the value for the memorySubsystemControllerManufacturerId attribute.
      Parameters:
      memorySubsystemControllerManufacturerId - The value for memorySubsystemControllerManufacturerId (can be null)
      Returns:
      this builder for use in a chained invocation
    • memorySubsystemControllerProductId

      public final ImmutableDMIMemoryDevice.Builder memorySubsystemControllerProductId(@Nullable String memorySubsystemControllerProductId)
      Initializes the value for the memorySubsystemControllerProductId attribute.
      Parameters:
      memorySubsystemControllerProductId - The value for memorySubsystemControllerProductId (can be null)
      Returns:
      this builder for use in a chained invocation
    • nonVolatileSize

      public final ImmutableDMIMemoryDevice.Builder nonVolatileSize(@Nullable String nonVolatileSize)
      Initializes the value for the nonVolatileSize attribute.
      Parameters:
      nonVolatileSize - The value for nonVolatileSize (can be null)
      Returns:
      this builder for use in a chained invocation
    • volatileSize

      public final ImmutableDMIMemoryDevice.Builder volatileSize(@Nullable String volatileSize)
      Initializes the value for the volatileSize attribute.
      Parameters:
      volatileSize - The value for volatileSize (can be null)
      Returns:
      this builder for use in a chained invocation
    • cacheSize

      public final ImmutableDMIMemoryDevice.Builder cacheSize(@Nullable String cacheSize)
      Initializes the value for the cacheSize attribute.
      Parameters:
      cacheSize - The value for cacheSize (can be null)
      Returns:
      this builder for use in a chained invocation
    • logicalSize

      public final ImmutableDMIMemoryDevice.Builder logicalSize(@Nullable String logicalSize)
      Initializes the value for the logicalSize attribute.
      Parameters:
      logicalSize - The value for logicalSize (can be null)
      Returns:
      this builder for use in a chained invocation
    • build

      public ImmutableDMIMemoryDevice build()
      Returns:
      An immutable instance of DMIMemoryDevice
      Throws:
      IllegalStateException - if any required attributes are missing