Class ImmutableDMIPhysicalMemoryArray.Builder

java.lang.Object
io.github.eggy03.dmidecode.entity.memory.ImmutableDMIPhysicalMemoryArray.Builder
Enclosing class:
ImmutableDMIPhysicalMemoryArray

@Generated(from="DMIPhysicalMemoryArray", generator="Immutables") public static final class ImmutableDMIPhysicalMemoryArray.Builder extends Object
Builds instances of type ImmutableDMIPhysicalMemoryArray. Initialize attributes and then invoke the build() method to create an immutable instance.

Builder is not thread-safe and generally should not be stored in a field or collection, but instead used immediately to create instances.

  • Field Details

    • location

      private @Nullable String location
    • use

      private @Nullable String use
    • errorCorrectionType

      private @Nullable String errorCorrectionType
    • maximumCapacity

      private @Nullable String maximumCapacity
    • errorInformationHandle

      private @Nullable String errorInformationHandle
    • numberOfDevices

      private @Nullable Integer numberOfDevices
  • Constructor Details

  • Method Details