Class ImmutableDMIPhysicalMemoryArray.Json

java.lang.Object
io.github.eggy03.dmidecode.entity.memory.DMIPhysicalMemoryArray
io.github.eggy03.dmidecode.entity.memory.ImmutableDMIPhysicalMemoryArray.Json
Enclosing class:
ImmutableDMIPhysicalMemoryArray

@Generated(from="DMIPhysicalMemoryArray", generator="Immutables") @Deprecated static final class ImmutableDMIPhysicalMemoryArray.Json extends DMIPhysicalMemoryArray
Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Utility type used to correctly read immutable object from JSON representation.
  • Field Details

    • _location

      @Nullable String _location
      Deprecated.
    • _use

      @Nullable String _use
      Deprecated.
    • _errorCorrectionType

      @Nullable String _errorCorrectionType
      Deprecated.
    • _maximumCapacity

      @Nullable String _maximumCapacity
      Deprecated.
    • _errorInformationHandle

      @Nullable String _errorInformationHandle
      Deprecated.
    • _numberOfDevices

      @Nullable Integer _numberOfDevices
      Deprecated.
  • Constructor Details

    • Json

      Json()
      Deprecated.
  • Method Details