Uses of Class
io.github.eggy03.dmidecode.entity.memory.AbstractDMIMemoryDevice
Packages that use AbstractDMIMemoryDevice
-
Uses of AbstractDMIMemoryDevice in io.github.eggy03.dmidecode.entity.memory
Subclasses of AbstractDMIMemoryDevice in io.github.eggy03.dmidecode.entity.memoryModifier and TypeClassDescriptionfinal classImmutable representation of memory device information retrieved via DMI.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructureMethods in io.github.eggy03.dmidecode.entity.memory with parameters of type AbstractDMIMemoryDeviceModifier and TypeMethodDescriptionstatic DMIMemoryDeviceDMIMemoryDevice.copyOf(AbstractDMIMemoryDevice instance) Creates an immutable copy of aAbstractDMIMemoryDevicevalue.final DMIMemoryDevice.BuilderDMIMemoryDevice.Builder.from(AbstractDMIMemoryDevice instance) Fill a builder with attribute values from the providedAbstractDMIMemoryDeviceinstance.