Uses of Class
io.github.eggy03.dmidecode.entity.memory.AbstractDMIPhysicalMemoryArray
Packages that use AbstractDMIPhysicalMemoryArray
-
Uses of AbstractDMIPhysicalMemoryArray in io.github.eggy03.dmidecode.entity.memory
Subclasses of AbstractDMIPhysicalMemoryArray in io.github.eggy03.dmidecode.entity.memoryModifier and TypeClassDescriptionfinal classImmutable representation of physical memory array information retrieved via DMI.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructureMethods in io.github.eggy03.dmidecode.entity.memory with parameters of type AbstractDMIPhysicalMemoryArrayModifier and TypeMethodDescriptionstatic DMIPhysicalMemoryArrayDMIPhysicalMemoryArray.copyOf(AbstractDMIPhysicalMemoryArray instance) Creates an immutable copy of aAbstractDMIPhysicalMemoryArrayvalue.DMIPhysicalMemoryArray.Builder.from(AbstractDMIPhysicalMemoryArray instance) Fill a builder with attribute values from the providedAbstractDMIPhysicalMemoryArrayinstance.