Uses of Class
io.github.eggy03.dmidecode.entity.memory.DMIPhysicalMemoryArray
Packages that use DMIPhysicalMemoryArray
Package
Description
-
Uses of DMIPhysicalMemoryArray in io.github.eggy03.dmidecode.entity.memory
Subclasses of DMIPhysicalMemoryArray in io.github.eggy03.dmidecode.entity.memoryModifier and TypeClassDescriptionfinal classImmutable implementation ofDMIPhysicalMemoryArray.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructureMethods in io.github.eggy03.dmidecode.entity.memory with parameters of type DMIPhysicalMemoryArrayModifier and TypeMethodDescriptionImmutableDMIPhysicalMemoryArray.copyOf(DMIPhysicalMemoryArray instance) Creates an immutable copy of aDMIPhysicalMemoryArrayvalue.ImmutableDMIPhysicalMemoryArray.Builder.from(DMIPhysicalMemoryArray instance) Fill a builder with attribute values from the providedDMIPhysicalMemoryArrayinstance. -
Uses of DMIPhysicalMemoryArray in io.github.eggy03.dmidecode.service.memory
Methods in io.github.eggy03.dmidecode.service.memory that return types with arguments of type DMIPhysicalMemoryArrayModifier and TypeMethodDescription@NonNull Optional<DMIPhysicalMemoryArray> DMIPhysicalMemoryArrayService.get(long timeout) Retrieves physical memory array information present in the system using an isolateddmidecodeprocess with a configurable timeout.