Uses of Class
io.github.eggy03.dmidecode.entity.memory.ImmutableDMIMemoryDevice
Packages that use ImmutableDMIMemoryDevice
-
Uses of ImmutableDMIMemoryDevice in io.github.eggy03.dmidecode.entity.memory
Methods in io.github.eggy03.dmidecode.entity.memory that return ImmutableDMIMemoryDeviceModifier and TypeMethodDescriptionImmutableDMIMemoryDevice.Builder.build()Builds a newImmutableDMIMemoryDevice.static ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.copyOf(DMIMemoryDevice instance) Creates an immutable copy of aDMIMemoryDevicevalue.(package private) static ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.fromJson(ImmutableDMIMemoryDevice.Json json) Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructurefinal ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withArrayHandle(@Nullable String value) Copy the current immutable object by setting a value for thearrayHandleattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withAssetTag(@Nullable String value) Copy the current immutable object by setting a value for theassetTagattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withBankLocator(@Nullable String value) Copy the current immutable object by setting a value for thebankLocatorattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withCacheSize(@Nullable String value) Copy the current immutable object by setting a value for thecacheSizeattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withConfiguredMemorySpeed(@Nullable String value) Copy the current immutable object by setting a value for theconfiguredMemorySpeedattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withConfiguredVoltage(@Nullable String value) Copy the current immutable object by setting a value for theconfiguredVoltageattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withDataWidth(@Nullable String value) Copy the current immutable object by setting a value for thedataWidthattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withErrorInformationHandle(@Nullable String value) Copy the current immutable object by setting a value for theerrorInformationHandleattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withFirmwareVersion(@Nullable String value) Copy the current immutable object by setting a value for thefirmwareVersionattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withFormFactor(@Nullable String value) Copy the current immutable object by setting a value for theformFactorattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withLocator(@Nullable String value) Copy the current immutable object by setting a value for thelocatorattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withLogicalSize(@Nullable String value) Copy the current immutable object by setting a value for thelogicalSizeattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withManufacturer(@Nullable String value) Copy the current immutable object by setting a value for themanufacturerattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withMaximumVoltage(@Nullable String value) Copy the current immutable object by setting a value for themaximumVoltageattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withMemoryOperatingModeCapability(@Nullable String value) Copy the current immutable object by setting a value for thememoryOperatingModeCapabilityattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withMemorySubsystemControllerManufacturerId(@Nullable String value) Copy the current immutable object by setting a value for thememorySubsystemControllerManufacturerIdattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withMemorySubsystemControllerProductId(@Nullable String value) Copy the current immutable object by setting a value for thememorySubsystemControllerProductIdattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withMemoryTechnology(@Nullable String value) Copy the current immutable object by setting a value for thememoryTechnologyattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withMinimumVoltage(@Nullable String value) Copy the current immutable object by setting a value for theminimumVoltageattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withModuleManufacturerId(@Nullable String value) Copy the current immutable object by setting a value for themoduleManufacturerIdattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withModuleProductId(@Nullable String value) Copy the current immutable object by setting a value for themoduleProductIdattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withNonVolatileSize(@Nullable String value) Copy the current immutable object by setting a value for thenonVolatileSizeattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withPartNumber(@Nullable String value) Copy the current immutable object by setting a value for thepartNumberattribute.final ImmutableDMIMemoryDeviceCopy the current immutable object by setting a value for therankattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withSerialNumber(@Nullable String value) Copy the current immutable object by setting a value for theserialNumberattribute.final ImmutableDMIMemoryDeviceCopy the current immutable object by setting a value for thesetattribute.final ImmutableDMIMemoryDeviceCopy the current immutable object by setting a value for thesizeattribute.final ImmutableDMIMemoryDeviceCopy the current immutable object by setting a value for thespeedattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withTotalWidth(@Nullable String value) Copy the current immutable object by setting a value for thetotalWidthattribute.final ImmutableDMIMemoryDeviceCopy the current immutable object by setting a value for thetypeattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withTypeDetail(@Nullable String value) Copy the current immutable object by setting a value for thetypeDetailattribute.final ImmutableDMIMemoryDeviceImmutableDMIMemoryDevice.withVolatileSize(@Nullable String value) Copy the current immutable object by setting a value for thevolatileSizeattribute.Methods in io.github.eggy03.dmidecode.entity.memory with parameters of type ImmutableDMIMemoryDeviceModifier and TypeMethodDescriptionprivate booleanImmutableDMIMemoryDevice.equalsByValue(ImmutableDMIMemoryDevice another)