Uses of Class
io.github.eggy03.dmidecode.entity.memory.ImmutableDMIPhysicalMemoryArray
Packages that use ImmutableDMIPhysicalMemoryArray
-
Uses of ImmutableDMIPhysicalMemoryArray in io.github.eggy03.dmidecode.entity.memory
Methods in io.github.eggy03.dmidecode.entity.memory that return ImmutableDMIPhysicalMemoryArrayModifier and TypeMethodDescriptionImmutableDMIPhysicalMemoryArray.Builder.build()Builds a newImmutableDMIPhysicalMemoryArray.ImmutableDMIPhysicalMemoryArray.copyOf(DMIPhysicalMemoryArray instance) Creates an immutable copy of aDMIPhysicalMemoryArrayvalue.(package private) static ImmutableDMIPhysicalMemoryArrayImmutableDMIPhysicalMemoryArray.fromJson(ImmutableDMIPhysicalMemoryArray.Json json) Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructureImmutableDMIPhysicalMemoryArray.withErrorCorrectionType(@Nullable String value) Copy the current immutable object by setting a value for theerrorCorrectionTypeattribute.ImmutableDMIPhysicalMemoryArray.withErrorInformationHandle(@Nullable String value) Copy the current immutable object by setting a value for theerrorInformationHandleattribute.ImmutableDMIPhysicalMemoryArray.withLocation(@Nullable String value) Copy the current immutable object by setting a value for thelocationattribute.ImmutableDMIPhysicalMemoryArray.withMaximumCapacity(@Nullable String value) Copy the current immutable object by setting a value for themaximumCapacityattribute.ImmutableDMIPhysicalMemoryArray.withNumberOfDevices(@Nullable Integer value) Copy the current immutable object by setting a value for thenumberOfDevicesattribute.Copy the current immutable object by setting a value for theuseattribute.Methods in io.github.eggy03.dmidecode.entity.memory with parameters of type ImmutableDMIPhysicalMemoryArrayModifier and TypeMethodDescriptionprivate booleanImmutableDMIPhysicalMemoryArray.equalsByValue(ImmutableDMIPhysicalMemoryArray another)