Uses of Package
io.github.eggy03.dmidecode.entity.memory
Packages that use io.github.eggy03.dmidecode.entity.memory
Package
Description
-
Classes in io.github.eggy03.dmidecode.entity.memory used by io.github.eggy03.dmidecode.entity.memoryClassDescriptionImmutable representation of memory device information retrieved via DMI.Immutable representation of physical memory array information retrieved via DMI.Immutable implementation of
DMIMemoryDevice.Builds instances of typeImmutableDMIMemoryDevice.Deprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructureImmutable implementation ofDMIPhysicalMemoryArray.Builds instances of typeImmutableDMIPhysicalMemoryArray.Deprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure -
Classes in io.github.eggy03.dmidecode.entity.memory used by io.github.eggy03.dmidecode.service.memoryClassDescriptionImmutable representation of memory device information retrieved via DMI.Immutable representation of physical memory array information retrieved via DMI.