Class AbstractDMIPortableBattery

java.lang.Object
io.github.eggy03.dmidecode.entity.peripheral.AbstractDMIPortableBattery
Direct Known Subclasses:
DMIPortableBattery, DMIPortableBattery.Json

@Immutable @NullMarked public abstract class AbstractDMIPortableBattery extends Object
Immutable representation of portable battery information retrieved via DMI.

Fields correspond to properties reported by dmidecode for the Portable Battery (Type 22) SMBIOS structure.

Instances of this class are thread-safe.

Usage example


 DMIPortableBattery battery = new DMIPortableBattery.Builder()
     .location("Internal Battery")
     .manufacturer("LG")
     .designCapacity("50000 mWh")
     .designVoltage("11.4 V")
     .build();

 // Create a modified copy
 DMIPortableBattery updated = battery
     .withMaximumError("2%");
 
Since:
0.2.0
  • Constructor Details

    • AbstractDMIPortableBattery

      public AbstractDMIPortableBattery()
  • Method Details

    • location

      public abstract @Nullable String location()
    • manufacturer

      public abstract @Nullable String manufacturer()
    • name

      public abstract @Nullable String name()
    • designCapacity

      public abstract @Nullable String designCapacity()
    • designVoltage

      public abstract @Nullable String designVoltage()
    • sbdsVersion

      public abstract @Nullable String sbdsVersion()
    • maximumError

      public abstract @Nullable String maximumError()
    • sbdsSerialNumber

      public abstract @Nullable String sbdsSerialNumber()
    • sbdsManufactureDate

      public abstract @Nullable String sbdsManufactureDate()
    • sbdsChemistry

      public abstract @Nullable String sbdsChemistry()
    • oemSpecificInformation

      public abstract @Nullable String oemSpecificInformation()
    • toString

      public String toString()
      Overrides:
      toString in class Object