Class AbstractDMICache

java.lang.Object
io.github.eggy03.dmidecode.entity.processor.AbstractDMICache
Direct Known Subclasses:
DMICache, DMICache.Json

@Immutable @NullMarked public abstract class AbstractDMICache extends Object
Immutable representation of processor cache information retrieved via DMI.

Fields correspond to properties reported by dmidecode for the Cache Information (Type 7) SMBIOS structure.

Instances of this class are thread-safe.

Usage example


 DMICache cache = new DMICache.Builder()
     .socketDesignation("L3-Cache")
     .location("Internal")
     .installedSize("32 MB")
     .associativity("16-way Set-Associative")
     .build();

 // Create a modified copy
 DMICache updated = cache
     .withInstalledSize("64 MB");
 
Since:
0.2.0
  • Constructor Details

    • AbstractDMICache

      public AbstractDMICache()
  • Method Details

    • socketDesignation

      public abstract @Nullable String socketDesignation()
    • configuration

      public abstract @Nullable String configuration()
    • operationalMode

      public abstract @Nullable String operationalMode()
    • location

      public abstract @Nullable String location()
    • installedSize

      public abstract @Nullable String installedSize()
    • maximumSize

      public abstract @Nullable String maximumSize()
    • supportedSramTypes

      public abstract @Nullable List<@Nullable String> supportedSramTypes()
    • installedSramType

      public abstract @Nullable String installedSramType()
    • speed

      public abstract @Nullable String speed()
    • errorCorrectionType

      public abstract @Nullable String errorCorrectionType()
    • systemType

      public abstract @Nullable String systemType()
    • associativity

      public abstract @Nullable String associativity()
    • toString

      public String toString()
      Overrides:
      toString in class Object