Class DMICache.Builder
java.lang.Object
io.github.eggy03.dmidecode.entity.processor.DMICache.Builder
- Enclosing class:
DMICache
@Generated(from="AbstractDMICache",
generator="Immutables")
public static final class DMICache.Builder
extends Object
-
Field Summary
FieldsModifier and TypeFieldDescriptionprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable String -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionfinal DMICache.BuilderaddAllSupportedSramTypes(Iterable<@Nullable String> elements) Adds elements tosupportedSramTypeslist.final DMICache.BuilderaddSupportedSramTypes(@Nullable String element) Adds one element tosupportedSramTypeslist.final DMICache.BuilderaddSupportedSramTypes(@Nullable String... elements) Adds elements tosupportedSramTypeslist.final DMICache.Builderassociativity(@Nullable String associativity) Initializes the value for theassociativityattribute.build()Builds a newDMICache.final DMICache.Builderconfiguration(@Nullable String configuration) Initializes the value for theconfigurationattribute.final DMICache.BuildererrorCorrectionType(@Nullable String errorCorrectionType) Initializes the value for theerrorCorrectionTypeattribute.final DMICache.Builderfrom(AbstractDMICache instance) Fill a builder with attribute values from the providedAbstractDMICacheinstance.final DMICache.BuilderinstalledSize(@Nullable String installedSize) Initializes the value for theinstalledSizeattribute.final DMICache.BuilderinstalledSramType(@Nullable String installedSramType) Initializes the value for theinstalledSramTypeattribute.final DMICache.BuilderInitializes the value for thelocationattribute.final DMICache.BuildermaximumSize(@Nullable String maximumSize) Initializes the value for themaximumSizeattribute.final DMICache.BuilderoperationalMode(@Nullable String operationalMode) Initializes the value for theoperationalModeattribute.final DMICache.BuildersocketDesignation(@Nullable String socketDesignation) Initializes the value for thesocketDesignationattribute.final DMICache.BuilderInitializes the value for thespeedattribute.final DMICache.BuildersupportedSramTypes(@Nullable Iterable<@Nullable String> elements) Sets or replaces all elements forsupportedSramTypeslist.final DMICache.BuildersystemType(@Nullable String systemType) Initializes the value for thesystemTypeattribute.
-
Field Details
-
socketDesignation
-
configuration
-
operationalMode
-
location
-
installedSize
-
maximumSize
-
supportedSramTypes
-
installedSramType
-
speed
-
errorCorrectionType
-
systemType
-
associativity
-
-
Constructor Details
-
Builder
public Builder()Creates a builder forDMICacheinstances.new DMICache.Builder() .socketDesignation(String | null) // nullablesocketDesignation.configuration(String | null) // nullableconfiguration.operationalMode(String | null) // nullableoperationalMode.location(String | null) // nullablelocation.installedSize(String | null) // nullableinstalledSize.maximumSize(String | null) // nullablemaximumSize.supportedSramTypes(List<String> | null) // nullablesupportedSramTypes.installedSramType(String | null) // nullableinstalledSramType.speed(String | null) // nullablespeed.errorCorrectionType(String | null) // nullableerrorCorrectionType.systemType(String | null) // nullablesystemType.associativity(String | null) // nullableassociativity.build();
-
-
Method Details
-
from
Fill a builder with attribute values from the providedAbstractDMICacheinstance. Regular attribute values will be replaced with those from the given instance. Absent optional values will not replace present values. Collection elements and entries will be added, not replaced.- Parameters:
instance- The instance from which to copy values- Returns:
thisbuilder for use in a chained invocation
-
socketDesignation
Initializes the value for thesocketDesignationattribute.- Parameters:
socketDesignation- The value for socketDesignation (can benull)- Returns:
thisbuilder for use in a chained invocation
-
configuration
Initializes the value for theconfigurationattribute.- Parameters:
configuration- The value for configuration (can benull)- Returns:
thisbuilder for use in a chained invocation
-
operationalMode
Initializes the value for theoperationalModeattribute.- Parameters:
operationalMode- The value for operationalMode (can benull)- Returns:
thisbuilder for use in a chained invocation
-
location
Initializes the value for thelocationattribute.- Parameters:
location- The value for location (can benull)- Returns:
thisbuilder for use in a chained invocation
-
installedSize
Initializes the value for theinstalledSizeattribute.- Parameters:
installedSize- The value for installedSize (can benull)- Returns:
thisbuilder for use in a chained invocation
-
maximumSize
Initializes the value for themaximumSizeattribute.- Parameters:
maximumSize- The value for maximumSize (can benull)- Returns:
thisbuilder for use in a chained invocation
-
addSupportedSramTypes
Adds one element tosupportedSramTypeslist.- Parameters:
element- A supportedSramTypes element- Returns:
thisbuilder for use in a chained invocation
-
addSupportedSramTypes
Adds elements tosupportedSramTypeslist.- Parameters:
elements- An array of supportedSramTypes elements- Returns:
thisbuilder for use in a chained invocation
-
supportedSramTypes
Sets or replaces all elements forsupportedSramTypeslist.- Parameters:
elements- An iterable of supportedSramTypes elements- Returns:
thisbuilder for use in a chained invocation
-
addAllSupportedSramTypes
Adds elements tosupportedSramTypeslist.- Parameters:
elements- An iterable of supportedSramTypes elements- Returns:
thisbuilder for use in a chained invocation
-
installedSramType
Initializes the value for theinstalledSramTypeattribute.- Parameters:
installedSramType- The value for installedSramType (can benull)- Returns:
thisbuilder for use in a chained invocation
-
speed
Initializes the value for thespeedattribute.- Parameters:
speed- The value for speed (can benull)- Returns:
thisbuilder for use in a chained invocation
-
errorCorrectionType
Initializes the value for theerrorCorrectionTypeattribute.- Parameters:
errorCorrectionType- The value for errorCorrectionType (can benull)- Returns:
thisbuilder for use in a chained invocation
-
systemType
Initializes the value for thesystemTypeattribute.- Parameters:
systemType- The value for systemType (can benull)- Returns:
thisbuilder for use in a chained invocation
-
associativity
Initializes the value for theassociativityattribute.- Parameters:
associativity- The value for associativity (can benull)- Returns:
thisbuilder for use in a chained invocation
-
build
Builds a newDMICache.- Returns:
- An immutable instance of DMICache
- Throws:
IllegalStateException- if any required attributes are missing
-