Class DMICache.Json
java.lang.Object
io.github.eggy03.dmidecode.entity.processor.AbstractDMICache
io.github.eggy03.dmidecode.entity.processor.DMICache.Json
- Enclosing class:
DMICache
@Generated(from="AbstractDMICache",
generator="Immutables")
@Deprecated
static final class DMICache.Json
extends AbstractDMICache
Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Utility type used to correctly read immutable object from JSON representation.
-
Field Summary
FieldsModifier and TypeFieldDescription(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.Deprecated.(package private) @Nullable StringDeprecated. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescription@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable Stringlocation()Deprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.voidsetAssociativity(@Nullable String associativity) Deprecated.voidsetConfiguration(@Nullable String configuration) Deprecated.voidsetErrorCorrectionType(@Nullable String errorCorrectionType) Deprecated.voidsetInstalledSize(@Nullable String installedSize) Deprecated.voidsetInstalledSramType(@Nullable String installedSramType) Deprecated.voidsetLocation(@Nullable String location) Deprecated.voidsetMaximumSize(@Nullable String maximumSize) Deprecated.voidsetOperationalMode(@Nullable String operationalMode) Deprecated.voidsetSocketDesignation(@Nullable String socketDesignation) Deprecated.voidDeprecated.voidsetSupportedSramTypes(@Nullable List<String> supportedSramTypes) Deprecated.voidsetSystemType(@Nullable String systemType) Deprecated.@Nullable StringDeprecated.@Nullable Stringspeed()Deprecated.Deprecated.@Nullable StringDeprecated.Methods inherited from class io.github.eggy03.dmidecode.entity.processor.AbstractDMICache
toString
-
Field Details
-
_socketDesignation
@Nullable String _socketDesignationDeprecated. -
_configuration
@Nullable String _configurationDeprecated. -
_operationalMode
@Nullable String _operationalModeDeprecated. -
_location
@Nullable String _locationDeprecated. -
_installedSize
@Nullable String _installedSizeDeprecated. -
_maximumSize
@Nullable String _maximumSizeDeprecated. -
_supportedSramTypes
Deprecated. -
_installedSramType
@Nullable String _installedSramTypeDeprecated. -
_speed
@Nullable String _speedDeprecated. -
_errorCorrectionType
@Nullable String _errorCorrectionTypeDeprecated. -
_systemType
@Nullable String _systemTypeDeprecated. -
_associativity
@Nullable String _associativityDeprecated.
-
-
Constructor Details
-
Json
Json()Deprecated.
-
-
Method Details
-
setSocketDesignation
Deprecated. -
setConfiguration
Deprecated. -
setOperationalMode
Deprecated. -
setLocation
Deprecated. -
setInstalledSize
Deprecated. -
setMaximumSize
Deprecated. -
setSupportedSramTypes
Deprecated. -
setInstalledSramType
Deprecated. -
setSpeed
Deprecated. -
setErrorCorrectionType
Deprecated. -
setSystemType
Deprecated. -
setAssociativity
Deprecated. -
socketDesignation
Deprecated.- Specified by:
socketDesignationin classAbstractDMICache
-
configuration
Deprecated.- Specified by:
configurationin classAbstractDMICache
-
operationalMode
Deprecated.- Specified by:
operationalModein classAbstractDMICache
-
location
Deprecated.- Specified by:
locationin classAbstractDMICache
-
installedSize
Deprecated.- Specified by:
installedSizein classAbstractDMICache
-
maximumSize
Deprecated.- Specified by:
maximumSizein classAbstractDMICache
-
supportedSramTypes
Deprecated.- Specified by:
supportedSramTypesin classAbstractDMICache
-
installedSramType
Deprecated.- Specified by:
installedSramTypein classAbstractDMICache
-
speed
Deprecated.- Specified by:
speedin classAbstractDMICache
-
errorCorrectionType
Deprecated.- Specified by:
errorCorrectionTypein classAbstractDMICache
-
systemType
Deprecated.- Specified by:
systemTypein classAbstractDMICache
-
associativity
Deprecated.- Specified by:
associativityin classAbstractDMICache
-