Class DMIProcessor.Builder
java.lang.Object
io.github.eggy03.dmidecode.entity.processor.DMIProcessor.Builder
- Enclosing class:
DMIProcessor
@Generated(from="AbstractDMIProcessor",
generator="Immutables")
public static final class DMIProcessor.Builder
extends Object
Builds instances of type
DMIProcessor.
Initialize attributes and then invoke the build() method to create an
immutable instance.
Builder is not thread-safe and generally should not be stored in a field or collection,
but instead used immediately to create instances.
-
Field Summary
FieldsModifier and TypeFieldDescriptionprivate @Nullable Stringprivate @Nullable Integerprivate @Nullable Integerprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Integerprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable String -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionfinal DMIProcessor.BuilderaddAllCharacteristics(Iterable<@Nullable String> elements) Adds elements tocharacteristicslist.final DMIProcessor.BuilderaddAllFlags(Iterable<@Nullable String> elements) Adds elements toflagslist.final DMIProcessor.BuilderaddCharacteristics(@Nullable String element) Adds one element tocharacteristicslist.final DMIProcessor.BuilderaddCharacteristics(@Nullable String... elements) Adds elements tocharacteristicslist.final DMIProcessor.BuilderAdds one element toflagslist.final DMIProcessor.BuilderAdds elements toflagslist.final DMIProcessor.BuilderInitializes the value for theassetTagattribute.build()Builds a newDMIProcessor.final DMIProcessor.Buildercharacteristics(@Nullable Iterable<@Nullable String> elements) Sets or replaces all elements forcharacteristicslist.final DMIProcessor.BuilderInitializes the value for thecoreCountattribute.final DMIProcessor.BuildercoreEnabled(@Nullable Integer coreEnabled) Initializes the value for thecoreEnabledattribute.final DMIProcessor.BuildercurrentSpeed(@Nullable String currentSpeed) Initializes the value for thecurrentSpeedattribute.final DMIProcessor.BuilderexternalClock(@Nullable String externalClock) Initializes the value for theexternalClockattribute.final DMIProcessor.BuilderInitializes the value for thefamilyattribute.final DMIProcessor.BuilderSets or replaces all elements forflagslist.final DMIProcessor.Builderfrom(AbstractDMIProcessor instance) Fill a builder with attribute values from the providedAbstractDMIProcessorinstance.final DMIProcessor.BuilderInitializes the value for theidattribute.final DMIProcessor.Builderl1CacheHandle(@Nullable String l1CacheHandle) Initializes the value for thel1CacheHandleattribute.final DMIProcessor.Builderl2CacheHandle(@Nullable String l2CacheHandle) Initializes the value for thel2CacheHandleattribute.final DMIProcessor.Builderl3CacheHandle(@Nullable String l3CacheHandle) Initializes the value for thel3CacheHandleattribute.final DMIProcessor.Buildermanufacturer(@Nullable String manufacturer) Initializes the value for themanufacturerattribute.final DMIProcessor.BuilderInitializes the value for themaxSpeedattribute.final DMIProcessor.BuilderpartNumber(@Nullable String partNumber) Initializes the value for thepartNumberattribute.final DMIProcessor.BuilderserialNumber(@Nullable String serialNumber) Initializes the value for theserialNumberattribute.final DMIProcessor.BuilderInitializes the value for thesignatureattribute.final DMIProcessor.BuildersocketDesignation(@Nullable String socketDesignation) Initializes the value for thesocketDesignationattribute.final DMIProcessor.BuilderInitializes the value for thestatusattribute.final DMIProcessor.BuilderthreadCount(@Nullable Integer threadCount) Initializes the value for thethreadCountattribute.final DMIProcessor.BuilderInitializes the value for thetypeattribute.final DMIProcessor.BuilderInitializes the value for theupgradeattribute.final DMIProcessor.BuilderInitializes the value for theversionattribute.final DMIProcessor.BuilderInitializes the value for thevoltageattribute.
-
Field Details
-
socketDesignation
-
type
-
family
-
manufacturer
-
id
-
signature
-
flags
-
version
-
voltage
-
externalClock
-
maxSpeed
-
currentSpeed
-
status
-
upgrade
-
l1CacheHandle
-
l2CacheHandle
-
l3CacheHandle
-
serialNumber
-
assetTag
-
partNumber
-
coreCount
-
coreEnabled
-
threadCount
-
characteristics
-
-
Constructor Details
-
Builder
public Builder()Creates a builder forDMIProcessorinstances.new DMIProcessor.Builder() .socketDesignation(String | null) // nullablesocketDesignation.type(String | null) // nullabletype.family(String | null) // nullablefamily.manufacturer(String | null) // nullablemanufacturer.id(String | null) // nullableid.signature(String | null) // nullablesignature.flags(List<String> | null) // nullableflags.version(String | null) // nullableversion.voltage(String | null) // nullablevoltage.externalClock(String | null) // nullableexternalClock.maxSpeed(String | null) // nullablemaxSpeed.currentSpeed(String | null) // nullablecurrentSpeed.status(String | null) // nullablestatus.upgrade(String | null) // nullableupgrade.l1CacheHandle(String | null) // nullablel1CacheHandle.l2CacheHandle(String | null) // nullablel2CacheHandle.l3CacheHandle(String | null) // nullablel3CacheHandle.serialNumber(String | null) // nullableserialNumber.assetTag(String | null) // nullableassetTag.partNumber(String | null) // nullablepartNumber.coreCount(Integer | null) // nullablecoreCount.coreEnabled(Integer | null) // nullablecoreEnabled.threadCount(Integer | null) // nullablethreadCount.characteristics(List<String> | null) // nullablecharacteristics.build();
-
-
Method Details
-
from
Fill a builder with attribute values from the providedAbstractDMIProcessorinstance. Regular attribute values will be replaced with those from the given instance. Absent optional values will not replace present values. Collection elements and entries will be added, not replaced.- Parameters:
instance- The instance from which to copy values- Returns:
thisbuilder for use in a chained invocation
-
socketDesignation
Initializes the value for thesocketDesignationattribute.- Parameters:
socketDesignation- The value for socketDesignation (can benull)- Returns:
thisbuilder for use in a chained invocation
-
type
Initializes the value for thetypeattribute.- Parameters:
type- The value for type (can benull)- Returns:
thisbuilder for use in a chained invocation
-
family
Initializes the value for thefamilyattribute.- Parameters:
family- The value for family (can benull)- Returns:
thisbuilder for use in a chained invocation
-
manufacturer
Initializes the value for themanufacturerattribute.- Parameters:
manufacturer- The value for manufacturer (can benull)- Returns:
thisbuilder for use in a chained invocation
-
id
Initializes the value for theidattribute.- Parameters:
id- The value for id (can benull)- Returns:
thisbuilder for use in a chained invocation
-
signature
Initializes the value for thesignatureattribute.- Parameters:
signature- The value for signature (can benull)- Returns:
thisbuilder for use in a chained invocation
-
addFlags
Adds one element toflagslist.- Parameters:
element- A flags element- Returns:
thisbuilder for use in a chained invocation
-
addFlags
Adds elements toflagslist.- Parameters:
elements- An array of flags elements- Returns:
thisbuilder for use in a chained invocation
-
flags
Sets or replaces all elements forflagslist.- Parameters:
elements- An iterable of flags elements- Returns:
thisbuilder for use in a chained invocation
-
addAllFlags
Adds elements toflagslist.- Parameters:
elements- An iterable of flags elements- Returns:
thisbuilder for use in a chained invocation
-
version
Initializes the value for theversionattribute.- Parameters:
version- The value for version (can benull)- Returns:
thisbuilder for use in a chained invocation
-
voltage
Initializes the value for thevoltageattribute.- Parameters:
voltage- The value for voltage (can benull)- Returns:
thisbuilder for use in a chained invocation
-
externalClock
Initializes the value for theexternalClockattribute.- Parameters:
externalClock- The value for externalClock (can benull)- Returns:
thisbuilder for use in a chained invocation
-
maxSpeed
Initializes the value for themaxSpeedattribute.- Parameters:
maxSpeed- The value for maxSpeed (can benull)- Returns:
thisbuilder for use in a chained invocation
-
currentSpeed
Initializes the value for thecurrentSpeedattribute.- Parameters:
currentSpeed- The value for currentSpeed (can benull)- Returns:
thisbuilder for use in a chained invocation
-
status
Initializes the value for thestatusattribute.- Parameters:
status- The value for status (can benull)- Returns:
thisbuilder for use in a chained invocation
-
upgrade
Initializes the value for theupgradeattribute.- Parameters:
upgrade- The value for upgrade (can benull)- Returns:
thisbuilder for use in a chained invocation
-
l1CacheHandle
Initializes the value for thel1CacheHandleattribute.- Parameters:
l1CacheHandle- The value for l1CacheHandle (can benull)- Returns:
thisbuilder for use in a chained invocation
-
l2CacheHandle
Initializes the value for thel2CacheHandleattribute.- Parameters:
l2CacheHandle- The value for l2CacheHandle (can benull)- Returns:
thisbuilder for use in a chained invocation
-
l3CacheHandle
Initializes the value for thel3CacheHandleattribute.- Parameters:
l3CacheHandle- The value for l3CacheHandle (can benull)- Returns:
thisbuilder for use in a chained invocation
-
serialNumber
Initializes the value for theserialNumberattribute.- Parameters:
serialNumber- The value for serialNumber (can benull)- Returns:
thisbuilder for use in a chained invocation
-
assetTag
Initializes the value for theassetTagattribute.- Parameters:
assetTag- The value for assetTag (can benull)- Returns:
thisbuilder for use in a chained invocation
-
partNumber
Initializes the value for thepartNumberattribute.- Parameters:
partNumber- The value for partNumber (can benull)- Returns:
thisbuilder for use in a chained invocation
-
coreCount
Initializes the value for thecoreCountattribute.- Parameters:
coreCount- The value for coreCount (can benull)- Returns:
thisbuilder for use in a chained invocation
-
coreEnabled
Initializes the value for thecoreEnabledattribute.- Parameters:
coreEnabled- The value for coreEnabled (can benull)- Returns:
thisbuilder for use in a chained invocation
-
threadCount
Initializes the value for thethreadCountattribute.- Parameters:
threadCount- The value for threadCount (can benull)- Returns:
thisbuilder for use in a chained invocation
-
addCharacteristics
Adds one element tocharacteristicslist.- Parameters:
element- A characteristics element- Returns:
thisbuilder for use in a chained invocation
-
addCharacteristics
Adds elements tocharacteristicslist.- Parameters:
elements- An array of characteristics elements- Returns:
thisbuilder for use in a chained invocation
-
characteristics
Sets or replaces all elements forcharacteristicslist.- Parameters:
elements- An iterable of characteristics elements- Returns:
thisbuilder for use in a chained invocation
-
addAllCharacteristics
Adds elements tocharacteristicslist.- Parameters:
elements- An iterable of characteristics elements- Returns:
thisbuilder for use in a chained invocation
-
build
Builds a newDMIProcessor.- Returns:
- An immutable instance of DMIProcessor
- Throws:
IllegalStateException- if any required attributes are missing
-