Class ImmutableDMICache.Builder

java.lang.Object
io.github.eggy03.dmidecode.entity.processor.ImmutableDMICache.Builder
Enclosing class:
ImmutableDMICache

@Generated(from="DMICache", generator="Immutables") public static final class ImmutableDMICache.Builder extends Object
Builds instances of type ImmutableDMICache. Initialize attributes and then invoke the build() method to create an immutable instance.

Builder is not thread-safe and generally should not be stored in a field or collection, but instead used immediately to create instances.

  • Field Details

    • socketDesignation

      private @Nullable String socketDesignation
    • configuration

      private @Nullable String configuration
    • operationalMode

      private @Nullable String operationalMode
    • location

      private @Nullable String location
    • installedSize

      private @Nullable String installedSize
    • maximumSize

      private @Nullable String maximumSize
    • supportedSramTypes

      private @Nullable List<String> supportedSramTypes
    • installedSramType

      private @Nullable String installedSramType
    • speed

      private @Nullable String speed
    • errorCorrectionType

      private @Nullable String errorCorrectionType
    • systemType

      private @Nullable String systemType
    • associativity

      private @Nullable String associativity
  • Constructor Details

  • Method Details

    • from

      public final ImmutableDMICache.Builder from(DMICache instance)
      Fill a builder with attribute values from the provided DMICache instance. Regular attribute values will be replaced with those from the given instance. Absent optional values will not replace present values. Collection elements and entries will be added, not replaced.
      Parameters:
      instance - The instance from which to copy values
      Returns:
      this builder for use in a chained invocation
    • socketDesignation

      public final ImmutableDMICache.Builder socketDesignation(@Nullable String socketDesignation)
      Initializes the value for the socketDesignation attribute.
      Parameters:
      socketDesignation - The value for socketDesignation (can be null)
      Returns:
      this builder for use in a chained invocation
    • configuration

      public final ImmutableDMICache.Builder configuration(@Nullable String configuration)
      Initializes the value for the configuration attribute.
      Parameters:
      configuration - The value for configuration (can be null)
      Returns:
      this builder for use in a chained invocation
    • operationalMode

      public final ImmutableDMICache.Builder operationalMode(@Nullable String operationalMode)
      Initializes the value for the operationalMode attribute.
      Parameters:
      operationalMode - The value for operationalMode (can be null)
      Returns:
      this builder for use in a chained invocation
    • location

      public final ImmutableDMICache.Builder location(@Nullable String location)
      Initializes the value for the location attribute.
      Parameters:
      location - The value for location (can be null)
      Returns:
      this builder for use in a chained invocation
    • installedSize

      public final ImmutableDMICache.Builder installedSize(@Nullable String installedSize)
      Initializes the value for the installedSize attribute.
      Parameters:
      installedSize - The value for installedSize (can be null)
      Returns:
      this builder for use in a chained invocation
    • maximumSize

      public final ImmutableDMICache.Builder maximumSize(@Nullable String maximumSize)
      Initializes the value for the maximumSize attribute.
      Parameters:
      maximumSize - The value for maximumSize (can be null)
      Returns:
      this builder for use in a chained invocation
    • addSupportedSramTypes

      public final ImmutableDMICache.Builder addSupportedSramTypes(@Nullable String element)
      Adds one element to supportedSramTypes list.
      Parameters:
      element - A supportedSramTypes element
      Returns:
      this builder for use in a chained invocation
    • addSupportedSramTypes

      public final ImmutableDMICache.Builder addSupportedSramTypes(@Nullable String... elements)
      Adds elements to supportedSramTypes list.
      Parameters:
      elements - An array of supportedSramTypes elements
      Returns:
      this builder for use in a chained invocation
    • supportedSramTypes

      public final ImmutableDMICache.Builder supportedSramTypes(@Nullable Iterable<@Nullable String> elements)
      Sets or replaces all elements for supportedSramTypes list.
      Parameters:
      elements - An iterable of supportedSramTypes elements
      Returns:
      this builder for use in a chained invocation
    • addAllSupportedSramTypes

      public final ImmutableDMICache.Builder addAllSupportedSramTypes(Iterable<@Nullable String> elements)
      Adds elements to supportedSramTypes list.
      Parameters:
      elements - An iterable of supportedSramTypes elements
      Returns:
      this builder for use in a chained invocation
    • installedSramType

      public final ImmutableDMICache.Builder installedSramType(@Nullable String installedSramType)
      Initializes the value for the installedSramType attribute.
      Parameters:
      installedSramType - The value for installedSramType (can be null)
      Returns:
      this builder for use in a chained invocation
    • speed

      public final ImmutableDMICache.Builder speed(@Nullable String speed)
      Initializes the value for the speed attribute.
      Parameters:
      speed - The value for speed (can be null)
      Returns:
      this builder for use in a chained invocation
    • errorCorrectionType

      public final ImmutableDMICache.Builder errorCorrectionType(@Nullable String errorCorrectionType)
      Initializes the value for the errorCorrectionType attribute.
      Parameters:
      errorCorrectionType - The value for errorCorrectionType (can be null)
      Returns:
      this builder for use in a chained invocation
    • systemType

      public final ImmutableDMICache.Builder systemType(@Nullable String systemType)
      Initializes the value for the systemType attribute.
      Parameters:
      systemType - The value for systemType (can be null)
      Returns:
      this builder for use in a chained invocation
    • associativity

      public final ImmutableDMICache.Builder associativity(@Nullable String associativity)
      Initializes the value for the associativity attribute.
      Parameters:
      associativity - The value for associativity (can be null)
      Returns:
      this builder for use in a chained invocation
    • build

      public ImmutableDMICache build()
      Builds a new ImmutableDMICache.
      Returns:
      An immutable instance of DMICache
      Throws:
      IllegalStateException - if any required attributes are missing