Class ImmutableDMICache.Json

java.lang.Object
io.github.eggy03.dmidecode.entity.processor.DMICache
io.github.eggy03.dmidecode.entity.processor.ImmutableDMICache.Json
Enclosing class:
ImmutableDMICache

@Generated(from="DMICache", generator="Immutables") @Deprecated static final class ImmutableDMICache.Json extends DMICache
Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Utility type used to correctly read immutable object from JSON representation.
  • Field Details

    • _socketDesignation

      @Nullable String _socketDesignation
      Deprecated.
    • _configuration

      @Nullable String _configuration
      Deprecated.
    • _operationalMode

      @Nullable String _operationalMode
      Deprecated.
    • _location

      @Nullable String _location
      Deprecated.
    • _installedSize

      @Nullable String _installedSize
      Deprecated.
    • _maximumSize

      @Nullable String _maximumSize
      Deprecated.
    • _supportedSramTypes

      @Nullable List<String> _supportedSramTypes
      Deprecated.
    • _installedSramType

      @Nullable String _installedSramType
      Deprecated.
    • _speed

      @Nullable String _speed
      Deprecated.
    • _errorCorrectionType

      @Nullable String _errorCorrectionType
      Deprecated.
    • _systemType

      @Nullable String _systemType
      Deprecated.
    • _associativity

      @Nullable String _associativity
      Deprecated.
  • Constructor Details

    • Json

      Json()
      Deprecated.
  • Method Details

    • setSocketDesignation

      public void setSocketDesignation(@Nullable String socketDesignation)
      Deprecated.
    • setConfiguration

      public void setConfiguration(@Nullable String configuration)
      Deprecated.
    • setOperationalMode

      public void setOperationalMode(@Nullable String operationalMode)
      Deprecated.
    • setLocation

      public void setLocation(@Nullable String location)
      Deprecated.
    • setInstalledSize

      public void setInstalledSize(@Nullable String installedSize)
      Deprecated.
    • setMaximumSize

      public void setMaximumSize(@Nullable String maximumSize)
      Deprecated.
    • setSupportedSramTypes

      public void setSupportedSramTypes(@Nullable List<String> supportedSramTypes)
      Deprecated.
    • setInstalledSramType

      public void setInstalledSramType(@Nullable String installedSramType)
      Deprecated.
    • setSpeed

      public void setSpeed(@Nullable String speed)
      Deprecated.
    • setErrorCorrectionType

      public void setErrorCorrectionType(@Nullable String errorCorrectionType)
      Deprecated.
    • setSystemType

      public void setSystemType(@Nullable String systemType)
      Deprecated.
    • setAssociativity

      public void setAssociativity(@Nullable String associativity)
      Deprecated.
    • socketDesignation

      public @Nullable String socketDesignation()
      Deprecated.
      Specified by:
      socketDesignation in class DMICache
    • configuration

      public @Nullable String configuration()
      Deprecated.
      Specified by:
      configuration in class DMICache
    • operationalMode

      public @Nullable String operationalMode()
      Deprecated.
      Specified by:
      operationalMode in class DMICache
    • location

      public @Nullable String location()
      Deprecated.
      Specified by:
      location in class DMICache
    • installedSize

      public @Nullable String installedSize()
      Deprecated.
      Specified by:
      installedSize in class DMICache
    • maximumSize

      public @Nullable String maximumSize()
      Deprecated.
      Specified by:
      maximumSize in class DMICache
    • supportedSramTypes

      public @Nullable List<String> supportedSramTypes()
      Deprecated.
      Specified by:
      supportedSramTypes in class DMICache
    • installedSramType

      public @Nullable String installedSramType()
      Deprecated.
      Specified by:
      installedSramType in class DMICache
    • speed

      public @Nullable String speed()
      Deprecated.
      Specified by:
      speed in class DMICache
    • errorCorrectionType

      public @Nullable String errorCorrectionType()
      Deprecated.
      Specified by:
      errorCorrectionType in class DMICache
    • systemType

      public @Nullable String systemType()
      Deprecated.
      Specified by:
      systemType in class DMICache
    • associativity

      public @Nullable String associativity()
      Deprecated.
      Specified by:
      associativity in class DMICache