Class ImmutableDMIProcessor.Builder

java.lang.Object
io.github.eggy03.dmidecode.entity.processor.ImmutableDMIProcessor.Builder
Enclosing class:
ImmutableDMIProcessor

@Generated(from="DMIProcessor", generator="Immutables") public static final class ImmutableDMIProcessor.Builder extends Object
Builds instances of type ImmutableDMIProcessor. Initialize attributes and then invoke the build() method to create an immutable instance.

Builder is not thread-safe and generally should not be stored in a field or collection, but instead used immediately to create instances.

  • Field Details

    • socketDesignation

      private @Nullable String socketDesignation
    • type

      private @Nullable String type
    • family

      private @Nullable String family
    • manufacturer

      private @Nullable String manufacturer
    • id

      private @Nullable String id
    • signature

      private @Nullable String signature
    • flags

      private @Nullable List<String> flags
    • version

      private @Nullable String version
    • voltage

      private @Nullable String voltage
    • externalClock

      private @Nullable String externalClock
    • maxSpeed

      private @Nullable String maxSpeed
    • currentSpeed

      private @Nullable String currentSpeed
    • status

      private @Nullable String status
    • upgrade

      private @Nullable String upgrade
    • l1CacheHandle

      private @Nullable String l1CacheHandle
    • l2CacheHandle

      private @Nullable String l2CacheHandle
    • l3CacheHandle

      private @Nullable String l3CacheHandle
    • serialNumber

      private @Nullable String serialNumber
    • assetTag

      private @Nullable String assetTag
    • partNumber

      private @Nullable String partNumber
    • coreCount

      private @Nullable Integer coreCount
    • coreEnabled

      private @Nullable Integer coreEnabled
    • threadCount

      private @Nullable Integer threadCount
    • characteristics

      private @Nullable List<String> characteristics
  • Constructor Details

    • Builder

      public Builder()
      Creates a builder for ImmutableDMIProcessor instances.
       new ImmutableDMIProcessor.Builder()
          .socketDesignation(String | null) // nullable socketDesignation
          .type(String | null) // nullable type
          .family(String | null) // nullable family
          .manufacturer(String | null) // nullable manufacturer
          .id(String | null) // nullable id
          .signature(String | null) // nullable signature
          .flags(List<String> | null) // nullable flags
          .version(String | null) // nullable version
          .voltage(String | null) // nullable voltage
          .externalClock(String | null) // nullable externalClock
          .maxSpeed(String | null) // nullable maxSpeed
          .currentSpeed(String | null) // nullable currentSpeed
          .status(String | null) // nullable status
          .upgrade(String | null) // nullable upgrade
          .l1CacheHandle(String | null) // nullable l1CacheHandle
          .l2CacheHandle(String | null) // nullable l2CacheHandle
          .l3CacheHandle(String | null) // nullable l3CacheHandle
          .serialNumber(String | null) // nullable serialNumber
          .assetTag(String | null) // nullable assetTag
          .partNumber(String | null) // nullable partNumber
          .coreCount(Integer | null) // nullable coreCount
          .coreEnabled(Integer | null) // nullable coreEnabled
          .threadCount(Integer | null) // nullable threadCount
          .characteristics(List<String> | null) // nullable characteristics
          .build();
       
  • Method Details

    • from

      public final ImmutableDMIProcessor.Builder from(DMIProcessor instance)
      Fill a builder with attribute values from the provided DMIProcessor instance. Regular attribute values will be replaced with those from the given instance. Absent optional values will not replace present values. Collection elements and entries will be added, not replaced.
      Parameters:
      instance - The instance from which to copy values
      Returns:
      this builder for use in a chained invocation
    • socketDesignation

      public final ImmutableDMIProcessor.Builder socketDesignation(@Nullable String socketDesignation)
      Initializes the value for the socketDesignation attribute.
      Parameters:
      socketDesignation - The value for socketDesignation (can be null)
      Returns:
      this builder for use in a chained invocation
    • type

      public final ImmutableDMIProcessor.Builder type(@Nullable String type)
      Initializes the value for the type attribute.
      Parameters:
      type - The value for type (can be null)
      Returns:
      this builder for use in a chained invocation
    • family

      public final ImmutableDMIProcessor.Builder family(@Nullable String family)
      Initializes the value for the family attribute.
      Parameters:
      family - The value for family (can be null)
      Returns:
      this builder for use in a chained invocation
    • manufacturer

      public final ImmutableDMIProcessor.Builder manufacturer(@Nullable String manufacturer)
      Initializes the value for the manufacturer attribute.
      Parameters:
      manufacturer - The value for manufacturer (can be null)
      Returns:
      this builder for use in a chained invocation
    • id

      public final ImmutableDMIProcessor.Builder id(@Nullable String id)
      Initializes the value for the id attribute.
      Parameters:
      id - The value for id (can be null)
      Returns:
      this builder for use in a chained invocation
    • signature

      public final ImmutableDMIProcessor.Builder signature(@Nullable String signature)
      Initializes the value for the signature attribute.
      Parameters:
      signature - The value for signature (can be null)
      Returns:
      this builder for use in a chained invocation
    • addFlags

      public final ImmutableDMIProcessor.Builder addFlags(@Nullable String element)
      Adds one element to flags list.
      Parameters:
      element - A flags element
      Returns:
      this builder for use in a chained invocation
    • addFlags

      public final ImmutableDMIProcessor.Builder addFlags(@Nullable String... elements)
      Adds elements to flags list.
      Parameters:
      elements - An array of flags elements
      Returns:
      this builder for use in a chained invocation
    • flags

      public final ImmutableDMIProcessor.Builder flags(@Nullable Iterable<@Nullable String> elements)
      Sets or replaces all elements for flags list.
      Parameters:
      elements - An iterable of flags elements
      Returns:
      this builder for use in a chained invocation
    • addAllFlags

      public final ImmutableDMIProcessor.Builder addAllFlags(Iterable<@Nullable String> elements)
      Adds elements to flags list.
      Parameters:
      elements - An iterable of flags elements
      Returns:
      this builder for use in a chained invocation
    • version

      public final ImmutableDMIProcessor.Builder version(@Nullable String version)
      Initializes the value for the version attribute.
      Parameters:
      version - The value for version (can be null)
      Returns:
      this builder for use in a chained invocation
    • voltage

      public final ImmutableDMIProcessor.Builder voltage(@Nullable String voltage)
      Initializes the value for the voltage attribute.
      Parameters:
      voltage - The value for voltage (can be null)
      Returns:
      this builder for use in a chained invocation
    • externalClock

      public final ImmutableDMIProcessor.Builder externalClock(@Nullable String externalClock)
      Initializes the value for the externalClock attribute.
      Parameters:
      externalClock - The value for externalClock (can be null)
      Returns:
      this builder for use in a chained invocation
    • maxSpeed

      public final ImmutableDMIProcessor.Builder maxSpeed(@Nullable String maxSpeed)
      Initializes the value for the maxSpeed attribute.
      Parameters:
      maxSpeed - The value for maxSpeed (can be null)
      Returns:
      this builder for use in a chained invocation
    • currentSpeed

      public final ImmutableDMIProcessor.Builder currentSpeed(@Nullable String currentSpeed)
      Initializes the value for the currentSpeed attribute.
      Parameters:
      currentSpeed - The value for currentSpeed (can be null)
      Returns:
      this builder for use in a chained invocation
    • status

      public final ImmutableDMIProcessor.Builder status(@Nullable String status)
      Initializes the value for the status attribute.
      Parameters:
      status - The value for status (can be null)
      Returns:
      this builder for use in a chained invocation
    • upgrade

      public final ImmutableDMIProcessor.Builder upgrade(@Nullable String upgrade)
      Initializes the value for the upgrade attribute.
      Parameters:
      upgrade - The value for upgrade (can be null)
      Returns:
      this builder for use in a chained invocation
    • l1CacheHandle

      public final ImmutableDMIProcessor.Builder l1CacheHandle(@Nullable String l1CacheHandle)
      Initializes the value for the l1CacheHandle attribute.
      Parameters:
      l1CacheHandle - The value for l1CacheHandle (can be null)
      Returns:
      this builder for use in a chained invocation
    • l2CacheHandle

      public final ImmutableDMIProcessor.Builder l2CacheHandle(@Nullable String l2CacheHandle)
      Initializes the value for the l2CacheHandle attribute.
      Parameters:
      l2CacheHandle - The value for l2CacheHandle (can be null)
      Returns:
      this builder for use in a chained invocation
    • l3CacheHandle

      public final ImmutableDMIProcessor.Builder l3CacheHandle(@Nullable String l3CacheHandle)
      Initializes the value for the l3CacheHandle attribute.
      Parameters:
      l3CacheHandle - The value for l3CacheHandle (can be null)
      Returns:
      this builder for use in a chained invocation
    • serialNumber

      public final ImmutableDMIProcessor.Builder serialNumber(@Nullable String serialNumber)
      Initializes the value for the serialNumber attribute.
      Parameters:
      serialNumber - The value for serialNumber (can be null)
      Returns:
      this builder for use in a chained invocation
    • assetTag

      public final ImmutableDMIProcessor.Builder assetTag(@Nullable String assetTag)
      Initializes the value for the assetTag attribute.
      Parameters:
      assetTag - The value for assetTag (can be null)
      Returns:
      this builder for use in a chained invocation
    • partNumber

      public final ImmutableDMIProcessor.Builder partNumber(@Nullable String partNumber)
      Initializes the value for the partNumber attribute.
      Parameters:
      partNumber - The value for partNumber (can be null)
      Returns:
      this builder for use in a chained invocation
    • coreCount

      public final ImmutableDMIProcessor.Builder coreCount(@Nullable Integer coreCount)
      Initializes the value for the coreCount attribute.
      Parameters:
      coreCount - The value for coreCount (can be null)
      Returns:
      this builder for use in a chained invocation
    • coreEnabled

      public final ImmutableDMIProcessor.Builder coreEnabled(@Nullable Integer coreEnabled)
      Initializes the value for the coreEnabled attribute.
      Parameters:
      coreEnabled - The value for coreEnabled (can be null)
      Returns:
      this builder for use in a chained invocation
    • threadCount

      public final ImmutableDMIProcessor.Builder threadCount(@Nullable Integer threadCount)
      Initializes the value for the threadCount attribute.
      Parameters:
      threadCount - The value for threadCount (can be null)
      Returns:
      this builder for use in a chained invocation
    • addCharacteristics

      public final ImmutableDMIProcessor.Builder addCharacteristics(@Nullable String element)
      Adds one element to characteristics list.
      Parameters:
      element - A characteristics element
      Returns:
      this builder for use in a chained invocation
    • addCharacteristics

      public final ImmutableDMIProcessor.Builder addCharacteristics(@Nullable String... elements)
      Adds elements to characteristics list.
      Parameters:
      elements - An array of characteristics elements
      Returns:
      this builder for use in a chained invocation
    • characteristics

      public final ImmutableDMIProcessor.Builder characteristics(@Nullable Iterable<@Nullable String> elements)
      Sets or replaces all elements for characteristics list.
      Parameters:
      elements - An iterable of characteristics elements
      Returns:
      this builder for use in a chained invocation
    • addAllCharacteristics

      public final ImmutableDMIProcessor.Builder addAllCharacteristics(Iterable<@Nullable String> elements)
      Adds elements to characteristics list.
      Parameters:
      elements - An iterable of characteristics elements
      Returns:
      this builder for use in a chained invocation
    • build

      public ImmutableDMIProcessor build()
      Builds a new ImmutableDMIProcessor.
      Returns:
      An immutable instance of DMIProcessor
      Throws:
      IllegalStateException - if any required attributes are missing