Class ImmutableDMIProcessor.Json

java.lang.Object
io.github.eggy03.dmidecode.entity.processor.DMIProcessor
io.github.eggy03.dmidecode.entity.processor.ImmutableDMIProcessor.Json
Enclosing class:
ImmutableDMIProcessor

@Generated(from="DMIProcessor", generator="Immutables") @Deprecated static final class ImmutableDMIProcessor.Json extends DMIProcessor
Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Utility type used to correctly read immutable object from JSON representation.
  • Field Details

    • _socketDesignation

      @Nullable String _socketDesignation
      Deprecated.
    • _type

      @Nullable String _type
      Deprecated.
    • _family

      @Nullable String _family
      Deprecated.
    • _manufacturer

      @Nullable String _manufacturer
      Deprecated.
    • _id

      @Nullable String _id
      Deprecated.
    • _signature

      @Nullable String _signature
      Deprecated.
    • _flags

      @Nullable List<String> _flags
      Deprecated.
    • _version

      @Nullable String _version
      Deprecated.
    • _voltage

      @Nullable String _voltage
      Deprecated.
    • _externalClock

      @Nullable String _externalClock
      Deprecated.
    • _maxSpeed

      @Nullable String _maxSpeed
      Deprecated.
    • _currentSpeed

      @Nullable String _currentSpeed
      Deprecated.
    • _status

      @Nullable String _status
      Deprecated.
    • _upgrade

      @Nullable String _upgrade
      Deprecated.
    • _l1CacheHandle

      @Nullable String _l1CacheHandle
      Deprecated.
    • _l2CacheHandle

      @Nullable String _l2CacheHandle
      Deprecated.
    • _l3CacheHandle

      @Nullable String _l3CacheHandle
      Deprecated.
    • _serialNumber

      @Nullable String _serialNumber
      Deprecated.
    • _assetTag

      @Nullable String _assetTag
      Deprecated.
    • _partNumber

      @Nullable String _partNumber
      Deprecated.
    • _coreCount

      @Nullable Integer _coreCount
      Deprecated.
    • _coreEnabled

      @Nullable Integer _coreEnabled
      Deprecated.
    • _threadCount

      @Nullable Integer _threadCount
      Deprecated.
    • _characteristics

      @Nullable List<String> _characteristics
      Deprecated.
  • Constructor Details

    • Json

      Json()
      Deprecated.
  • Method Details

    • setSocketDesignation

      public void setSocketDesignation(@Nullable String socketDesignation)
      Deprecated.
    • setType

      public void setType(@Nullable String type)
      Deprecated.
    • setFamily

      public void setFamily(@Nullable String family)
      Deprecated.
    • setManufacturer

      public void setManufacturer(@Nullable String manufacturer)
      Deprecated.
    • setId

      public void setId(@Nullable String id)
      Deprecated.
    • setSignature

      public void setSignature(@Nullable String signature)
      Deprecated.
    • setFlags

      public void setFlags(@Nullable List<String> flags)
      Deprecated.
    • setVersion

      public void setVersion(@Nullable String version)
      Deprecated.
    • setVoltage

      public void setVoltage(@Nullable String voltage)
      Deprecated.
    • setExternalClock

      public void setExternalClock(@Nullable String externalClock)
      Deprecated.
    • setMaxSpeed

      public void setMaxSpeed(@Nullable String maxSpeed)
      Deprecated.
    • setCurrentSpeed

      public void setCurrentSpeed(@Nullable String currentSpeed)
      Deprecated.
    • setStatus

      public void setStatus(@Nullable String status)
      Deprecated.
    • setUpgrade

      public void setUpgrade(@Nullable String upgrade)
      Deprecated.
    • setL1CacheHandle

      public void setL1CacheHandle(@Nullable String l1CacheHandle)
      Deprecated.
    • setL2CacheHandle

      public void setL2CacheHandle(@Nullable String l2CacheHandle)
      Deprecated.
    • setL3CacheHandle

      public void setL3CacheHandle(@Nullable String l3CacheHandle)
      Deprecated.
    • setSerialNumber

      public void setSerialNumber(@Nullable String serialNumber)
      Deprecated.
    • setAssetTag

      public void setAssetTag(@Nullable String assetTag)
      Deprecated.
    • setPartNumber

      public void setPartNumber(@Nullable String partNumber)
      Deprecated.
    • setCoreCount

      public void setCoreCount(@Nullable Integer coreCount)
      Deprecated.
    • setCoreEnabled

      public void setCoreEnabled(@Nullable Integer coreEnabled)
      Deprecated.
    • setThreadCount

      public void setThreadCount(@Nullable Integer threadCount)
      Deprecated.
    • setCharacteristics

      public void setCharacteristics(@Nullable List<String> characteristics)
      Deprecated.
    • socketDesignation

      public @Nullable String socketDesignation()
      Deprecated.
      Specified by:
      socketDesignation in class DMIProcessor
    • type

      public @Nullable String type()
      Deprecated.
      Specified by:
      type in class DMIProcessor
    • family

      public @Nullable String family()
      Deprecated.
      Specified by:
      family in class DMIProcessor
    • manufacturer

      public @Nullable String manufacturer()
      Deprecated.
      Specified by:
      manufacturer in class DMIProcessor
    • id

      public @Nullable String id()
      Deprecated.
      Specified by:
      id in class DMIProcessor
    • signature

      public @Nullable String signature()
      Deprecated.
      Specified by:
      signature in class DMIProcessor
    • flags

      public @Nullable List<String> flags()
      Deprecated.
      Specified by:
      flags in class DMIProcessor
    • version

      public @Nullable String version()
      Deprecated.
      Specified by:
      version in class DMIProcessor
    • voltage

      public @Nullable String voltage()
      Deprecated.
      Specified by:
      voltage in class DMIProcessor
    • externalClock

      public @Nullable String externalClock()
      Deprecated.
      Specified by:
      externalClock in class DMIProcessor
    • maxSpeed

      public @Nullable String maxSpeed()
      Deprecated.
      Specified by:
      maxSpeed in class DMIProcessor
    • currentSpeed

      public @Nullable String currentSpeed()
      Deprecated.
      Specified by:
      currentSpeed in class DMIProcessor
    • status

      public @Nullable String status()
      Deprecated.
      Specified by:
      status in class DMIProcessor
    • upgrade

      public @Nullable String upgrade()
      Deprecated.
      Specified by:
      upgrade in class DMIProcessor
    • l1CacheHandle

      public @Nullable String l1CacheHandle()
      Deprecated.
      Specified by:
      l1CacheHandle in class DMIProcessor
    • l2CacheHandle

      public @Nullable String l2CacheHandle()
      Deprecated.
      Specified by:
      l2CacheHandle in class DMIProcessor
    • l3CacheHandle

      public @Nullable String l3CacheHandle()
      Deprecated.
      Specified by:
      l3CacheHandle in class DMIProcessor
    • serialNumber

      public @Nullable String serialNumber()
      Deprecated.
      Specified by:
      serialNumber in class DMIProcessor
    • assetTag

      public @Nullable String assetTag()
      Deprecated.
      Specified by:
      assetTag in class DMIProcessor
    • partNumber

      public @Nullable String partNumber()
      Deprecated.
      Specified by:
      partNumber in class DMIProcessor
    • coreCount

      public @Nullable Integer coreCount()
      Deprecated.
      Specified by:
      coreCount in class DMIProcessor
    • coreEnabled

      public @Nullable Integer coreEnabled()
      Deprecated.
      Specified by:
      coreEnabled in class DMIProcessor
    • threadCount

      public @Nullable Integer threadCount()
      Deprecated.
      Specified by:
      threadCount in class DMIProcessor
    • characteristics

      public @Nullable List<String> characteristics()
      Deprecated.
      Specified by:
      characteristics in class DMIProcessor