Uses of Class
io.github.eggy03.dmidecode.entity.processor.AbstractDMICache
Packages that use AbstractDMICache
-
Uses of AbstractDMICache in io.github.eggy03.dmidecode.entity.processor
Subclasses of AbstractDMICache in io.github.eggy03.dmidecode.entity.processorModifier and TypeClassDescriptionfinal classImmutable representation of processor cache information retrieved via DMI.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructureMethods in io.github.eggy03.dmidecode.entity.processor with parameters of type AbstractDMICacheModifier and TypeMethodDescriptionstatic DMICacheDMICache.copyOf(AbstractDMICache instance) Creates an immutable copy of aAbstractDMICachevalue.final DMICache.BuilderDMICache.Builder.from(AbstractDMICache instance) Fill a builder with attribute values from the providedAbstractDMICacheinstance.