Uses of Class
io.github.eggy03.dmidecode.entity.processor.AbstractDMIProcessor
Packages that use AbstractDMIProcessor
-
Uses of AbstractDMIProcessor in io.github.eggy03.dmidecode.entity.processor
Subclasses of AbstractDMIProcessor in io.github.eggy03.dmidecode.entity.processorModifier and TypeClassDescriptionfinal classImmutable representation of processor information retrieved via DMI.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructureMethods in io.github.eggy03.dmidecode.entity.processor with parameters of type AbstractDMIProcessorModifier and TypeMethodDescriptionstatic DMIProcessorDMIProcessor.copyOf(AbstractDMIProcessor instance) Creates an immutable copy of aAbstractDMIProcessorvalue.final DMIProcessor.BuilderDMIProcessor.Builder.from(AbstractDMIProcessor instance) Fill a builder with attribute values from the providedAbstractDMIProcessorinstance.