Uses of Class
io.github.eggy03.dmidecode.entity.processor.DMICache
Packages that use DMICache
Package
Description
-
Uses of DMICache in io.github.eggy03.dmidecode.entity.processor
Subclasses of DMICache in io.github.eggy03.dmidecode.entity.processorModifier and TypeClassDescriptionfinal classImmutable implementation ofDMICache.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructureMethods in io.github.eggy03.dmidecode.entity.processor with parameters of type DMICacheModifier and TypeMethodDescriptionstatic ImmutableDMICacheCreates an immutable copy of aDMICachevalue.Fill a builder with attribute values from the providedDMICacheinstance. -
Uses of DMICache in io.github.eggy03.dmidecode.service.processor
Methods in io.github.eggy03.dmidecode.service.processor that return types with arguments of type DMICacheModifier and TypeMethodDescription@Unmodifiable @NonNull List<DMICache> DMICacheService.get(long timeout) Retrieves cache entries present in the system using an isolateddmidecodeprocess with a configurable timeout.