Uses of Class
io.github.eggy03.dmidecode.entity.processor.DMIProcessor
Packages that use DMIProcessor
Package
Description
-
Uses of DMIProcessor in io.github.eggy03.dmidecode.entity.processor
Subclasses of DMIProcessor in io.github.eggy03.dmidecode.entity.processorModifier and TypeClassDescriptionfinal classImmutable implementation ofDMIProcessor.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructureMethods in io.github.eggy03.dmidecode.entity.processor with parameters of type DMIProcessorModifier and TypeMethodDescriptionstatic ImmutableDMIProcessorImmutableDMIProcessor.copyOf(DMIProcessor instance) Creates an immutable copy of aDMIProcessorvalue.ImmutableDMIProcessor.Builder.from(DMIProcessor instance) Fill a builder with attribute values from the providedDMIProcessorinstance. -
Uses of DMIProcessor in io.github.eggy03.dmidecode.service.processor
Methods in io.github.eggy03.dmidecode.service.processor that return types with arguments of type DMIProcessorModifier and TypeMethodDescription@Unmodifiable @NonNull List<DMIProcessor> DMIProcessorService.get(long timeout) Retrieves processor information present in the system using an isolateddmidecodeprocess with a configurable timeout.