Uses of Class
io.github.eggy03.dmidecode.entity.processor.ImmutableDMICache
Packages that use ImmutableDMICache
-
Uses of ImmutableDMICache in io.github.eggy03.dmidecode.entity.processor
Methods in io.github.eggy03.dmidecode.entity.processor that return ImmutableDMICacheModifier and TypeMethodDescriptionImmutableDMICache.Builder.build()Builds a newImmutableDMICache.static ImmutableDMICacheCreates an immutable copy of aDMICachevalue.(package private) static ImmutableDMICacheImmutableDMICache.fromJson(ImmutableDMICache.Json json) Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructurefinal ImmutableDMICacheImmutableDMICache.withAssociativity(@Nullable String value) Copy the current immutable object by setting a value for theassociativityattribute.final ImmutableDMICacheImmutableDMICache.withConfiguration(@Nullable String value) Copy the current immutable object by setting a value for theconfigurationattribute.final ImmutableDMICacheImmutableDMICache.withErrorCorrectionType(@Nullable String value) Copy the current immutable object by setting a value for theerrorCorrectionTypeattribute.final ImmutableDMICacheImmutableDMICache.withInstalledSize(@Nullable String value) Copy the current immutable object by setting a value for theinstalledSizeattribute.final ImmutableDMICacheImmutableDMICache.withInstalledSramType(@Nullable String value) Copy the current immutable object by setting a value for theinstalledSramTypeattribute.final ImmutableDMICacheImmutableDMICache.withLocation(@Nullable String value) Copy the current immutable object by setting a value for thelocationattribute.final ImmutableDMICacheImmutableDMICache.withMaximumSize(@Nullable String value) Copy the current immutable object by setting a value for themaximumSizeattribute.final ImmutableDMICacheImmutableDMICache.withOperationalMode(@Nullable String value) Copy the current immutable object by setting a value for theoperationalModeattribute.final ImmutableDMICacheImmutableDMICache.withSocketDesignation(@Nullable String value) Copy the current immutable object by setting a value for thesocketDesignationattribute.final ImmutableDMICacheCopy the current immutable object by setting a value for thespeedattribute.final ImmutableDMICacheImmutableDMICache.withSupportedSramTypes(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofsupportedSramTypes.final ImmutableDMICacheImmutableDMICache.withSupportedSramTypes(@Nullable String @Nullable ... elements) Copy the current immutable object with elements that replace the content ofsupportedSramTypes.final ImmutableDMICacheImmutableDMICache.withSystemType(@Nullable String value) Copy the current immutable object by setting a value for thesystemTypeattribute.Methods in io.github.eggy03.dmidecode.entity.processor with parameters of type ImmutableDMICacheModifier and TypeMethodDescriptionprivate booleanImmutableDMICache.equalsByValue(ImmutableDMICache another)