Uses of Class
io.github.eggy03.dmidecode.entity.processor.ImmutableDMIProcessor
Packages that use ImmutableDMIProcessor
-
Uses of ImmutableDMIProcessor in io.github.eggy03.dmidecode.entity.processor
Methods in io.github.eggy03.dmidecode.entity.processor that return ImmutableDMIProcessorModifier and TypeMethodDescriptionImmutableDMIProcessor.Builder.build()Builds a newImmutableDMIProcessor.static ImmutableDMIProcessorImmutableDMIProcessor.copyOf(DMIProcessor instance) Creates an immutable copy of aDMIProcessorvalue.(package private) static ImmutableDMIProcessorImmutableDMIProcessor.fromJson(ImmutableDMIProcessor.Json json) Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructurefinal ImmutableDMIProcessorImmutableDMIProcessor.withAssetTag(@Nullable String value) Copy the current immutable object by setting a value for theassetTagattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withCharacteristics(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofcharacteristics.final ImmutableDMIProcessorImmutableDMIProcessor.withCharacteristics(@Nullable String @Nullable ... elements) Copy the current immutable object with elements that replace the content ofcharacteristics.final ImmutableDMIProcessorImmutableDMIProcessor.withCoreCount(@Nullable Integer value) Copy the current immutable object by setting a value for thecoreCountattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withCoreEnabled(@Nullable Integer value) Copy the current immutable object by setting a value for thecoreEnabledattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withCurrentSpeed(@Nullable String value) Copy the current immutable object by setting a value for thecurrentSpeedattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withExternalClock(@Nullable String value) Copy the current immutable object by setting a value for theexternalClockattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withFamily(@Nullable String value) Copy the current immutable object by setting a value for thefamilyattribute.final ImmutableDMIProcessorCopy the current immutable object with elements that replace the content offlags.final ImmutableDMIProcessorCopy the current immutable object with elements that replace the content offlags.final ImmutableDMIProcessorCopy the current immutable object by setting a value for theidattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withL1CacheHandle(@Nullable String value) Copy the current immutable object by setting a value for thel1CacheHandleattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withL2CacheHandle(@Nullable String value) Copy the current immutable object by setting a value for thel2CacheHandleattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withL3CacheHandle(@Nullable String value) Copy the current immutable object by setting a value for thel3CacheHandleattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withManufacturer(@Nullable String value) Copy the current immutable object by setting a value for themanufacturerattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withMaxSpeed(@Nullable String value) Copy the current immutable object by setting a value for themaxSpeedattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withPartNumber(@Nullable String value) Copy the current immutable object by setting a value for thepartNumberattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withSerialNumber(@Nullable String value) Copy the current immutable object by setting a value for theserialNumberattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withSignature(@Nullable String value) Copy the current immutable object by setting a value for thesignatureattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withSocketDesignation(@Nullable String value) Copy the current immutable object by setting a value for thesocketDesignationattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withStatus(@Nullable String value) Copy the current immutable object by setting a value for thestatusattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withThreadCount(@Nullable Integer value) Copy the current immutable object by setting a value for thethreadCountattribute.final ImmutableDMIProcessorCopy the current immutable object by setting a value for thetypeattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withUpgrade(@Nullable String value) Copy the current immutable object by setting a value for theupgradeattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withVersion(@Nullable String value) Copy the current immutable object by setting a value for theversionattribute.final ImmutableDMIProcessorImmutableDMIProcessor.withVoltage(@Nullable String value) Copy the current immutable object by setting a value for thevoltageattribute.Methods in io.github.eggy03.dmidecode.entity.processor with parameters of type ImmutableDMIProcessorModifier and TypeMethodDescriptionprivate booleanImmutableDMIProcessor.equalsByValue(ImmutableDMIProcessor another)