Package io.github.eggy03.dmidecode.entity.processor
package io.github.eggy03.dmidecode.entity.processor
-
ClassesClassDescriptionImmutable representation of processor cache information retrieved via DMI.Immutable representation of processor information retrieved via DMI.Immutable implementation of
DMICache.Builds instances of typeImmutableDMICache.Deprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructureImmutable implementation ofDMIProcessor.Builds instances of typeImmutableDMIProcessor.Deprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure