Class ImmutableDMISystem.Builder

java.lang.Object
io.github.eggy03.dmidecode.entity.system.ImmutableDMISystem.Builder
Enclosing class:
ImmutableDMISystem

@Generated(from="DMISystem", generator="Immutables") public static final class ImmutableDMISystem.Builder extends Object
Builds instances of type ImmutableDMISystem. Initialize attributes and then invoke the build() method to create an immutable instance.

Builder is not thread-safe and generally should not be stored in a field or collection, but instead used immediately to create instances.

  • Field Details

    • manufacturer

      private @Nullable String manufacturer
    • productName

      private @Nullable String productName
    • version

      private @Nullable String version
    • serialNumber

      private @Nullable String serialNumber
    • uuid

      private @Nullable String uuid
    • wakeupType

      private @Nullable String wakeupType
    • skuNumber

      private @Nullable String skuNumber
    • family

      private @Nullable String family
  • Constructor Details

    • Builder

      public Builder()
      Creates a builder for ImmutableDMISystem instances.
       new ImmutableDMISystem.Builder()
          .manufacturer(String | null) // nullable manufacturer
          .productName(String | null) // nullable productName
          .version(String | null) // nullable version
          .serialNumber(String | null) // nullable serialNumber
          .uuid(String | null) // nullable uuid
          .wakeupType(String | null) // nullable wakeupType
          .skuNumber(String | null) // nullable skuNumber
          .family(String | null) // nullable family
          .build();
       
  • Method Details

    • from

      public final ImmutableDMISystem.Builder from(DMISystem instance)
      Fill a builder with attribute values from the provided DMISystem instance. Regular attribute values will be replaced with those from the given instance. Absent optional values will not replace present values.
      Parameters:
      instance - The instance from which to copy values
      Returns:
      this builder for use in a chained invocation
    • manufacturer

      public final ImmutableDMISystem.Builder manufacturer(@Nullable String manufacturer)
      Initializes the value for the manufacturer attribute.
      Parameters:
      manufacturer - The value for manufacturer (can be null)
      Returns:
      this builder for use in a chained invocation
    • productName

      public final ImmutableDMISystem.Builder productName(@Nullable String productName)
      Initializes the value for the productName attribute.
      Parameters:
      productName - The value for productName (can be null)
      Returns:
      this builder for use in a chained invocation
    • version

      public final ImmutableDMISystem.Builder version(@Nullable String version)
      Initializes the value for the version attribute.
      Parameters:
      version - The value for version (can be null)
      Returns:
      this builder for use in a chained invocation
    • serialNumber

      public final ImmutableDMISystem.Builder serialNumber(@Nullable String serialNumber)
      Initializes the value for the serialNumber attribute.
      Parameters:
      serialNumber - The value for serialNumber (can be null)
      Returns:
      this builder for use in a chained invocation
    • uuid

      public final ImmutableDMISystem.Builder uuid(@Nullable String uuid)
      Initializes the value for the uuid attribute.
      Parameters:
      uuid - The value for uuid (can be null)
      Returns:
      this builder for use in a chained invocation
    • wakeupType

      public final ImmutableDMISystem.Builder wakeupType(@Nullable String wakeupType)
      Initializes the value for the wakeupType attribute.
      Parameters:
      wakeupType - The value for wakeupType (can be null)
      Returns:
      this builder for use in a chained invocation
    • skuNumber

      public final ImmutableDMISystem.Builder skuNumber(@Nullable String skuNumber)
      Initializes the value for the skuNumber attribute.
      Parameters:
      skuNumber - The value for skuNumber (can be null)
      Returns:
      this builder for use in a chained invocation
    • family

      public final ImmutableDMISystem.Builder family(@Nullable String family)
      Initializes the value for the family attribute.
      Parameters:
      family - The value for family (can be null)
      Returns:
      this builder for use in a chained invocation
    • build

      public ImmutableDMISystem build()
      Builds a new ImmutableDMISystem.
      Returns:
      An immutable instance of DMISystem
      Throws:
      IllegalStateException - if any required attributes are missing