Uses of Class
io.github.eggy03.dmidecode.entity.system.AbstractDMISystem
Packages that use AbstractDMISystem
-
Uses of AbstractDMISystem in io.github.eggy03.dmidecode.entity.system
Subclasses of AbstractDMISystem in io.github.eggy03.dmidecode.entity.systemModifier and TypeClassDescriptionfinal classImmutable representation of system information retrieved via DMI.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructureMethods in io.github.eggy03.dmidecode.entity.system with parameters of type AbstractDMISystemModifier and TypeMethodDescriptionstatic DMISystemDMISystem.copyOf(AbstractDMISystem instance) Creates an immutable copy of aAbstractDMISystemvalue.final DMISystem.BuilderDMISystem.Builder.from(AbstractDMISystem instance) Fill a builder with attribute values from the providedAbstractDMISysteminstance.