Uses of Class
io.github.eggy03.dmidecode.entity.system.ImmutableDMISystem
Packages that use ImmutableDMISystem
-
Uses of ImmutableDMISystem in io.github.eggy03.dmidecode.entity.system
Methods in io.github.eggy03.dmidecode.entity.system that return ImmutableDMISystemModifier and TypeMethodDescriptionImmutableDMISystem.Builder.build()Builds a newImmutableDMISystem.static ImmutableDMISystemCreates an immutable copy of aDMISystemvalue.(package private) static ImmutableDMISystemImmutableDMISystem.fromJson(ImmutableDMISystem.Json json) Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructurefinal ImmutableDMISystemImmutableDMISystem.withFamily(@Nullable String value) Copy the current immutable object by setting a value for thefamilyattribute.final ImmutableDMISystemImmutableDMISystem.withManufacturer(@Nullable String value) Copy the current immutable object by setting a value for themanufacturerattribute.final ImmutableDMISystemImmutableDMISystem.withProductName(@Nullable String value) Copy the current immutable object by setting a value for theproductNameattribute.final ImmutableDMISystemImmutableDMISystem.withSerialNumber(@Nullable String value) Copy the current immutable object by setting a value for theserialNumberattribute.final ImmutableDMISystemImmutableDMISystem.withSkuNumber(@Nullable String value) Copy the current immutable object by setting a value for theskuNumberattribute.final ImmutableDMISystemCopy the current immutable object by setting a value for theuuidattribute.final ImmutableDMISystemImmutableDMISystem.withVersion(@Nullable String value) Copy the current immutable object by setting a value for theversionattribute.final ImmutableDMISystemImmutableDMISystem.withWakeupType(@Nullable String value) Copy the current immutable object by setting a value for thewakeupTypeattribute.Methods in io.github.eggy03.dmidecode.entity.system with parameters of type ImmutableDMISystemModifier and TypeMethodDescriptionprivate booleanImmutableDMISystem.equalsByValue(ImmutableDMISystem another)