Interface CommonDMIServiceInterface<S>

Type Parameters:
S - the entity type returned by the service implementation
All Known Implementing Classes:
DMIBIOSService, DMICacheService, DMIMemoryDeviceService, DMIPortableBatteryService, DMIPortConnectorInformationService, DMIProcessorService, DMISystemSlotsService

public interface CommonDMIServiceInterface<S>
Common service interface whose method implementations provide a way to fetch DMI information from the system using the dmidecode utility in the form of a List.

Useful for implementing services that return more than one DMI structure, such as CPU Caches, Memory Device.

Since:
0.1.0
See Also:
  • Method Summary

    Modifier and Type
    Method
    Description
    get(long timeout)
    Implementations of this method are expected to execute the corresponding dmidecode command and then map the output to the expected entity types.
  • Method Details

    • get

      List<S> get(long timeout)
      Implementations of this method are expected to execute the corresponding dmidecode command and then map the output to the expected entity types.
      Parameters:
      timeout - the maximum time (in seconds) to wait for the dmidecode command to complete before terminating the process
      Returns:
      a List of entities of type <S> defined by the caller
      Since:
      0.1.0