Uses of Interface
io.github.eggy03.dmidecode.service.CommonDMIServiceInterface
Packages that use CommonDMIServiceInterface
Package
Description
-
Uses of CommonDMIServiceInterface in io.github.eggy03.dmidecode.service.board
Classes in io.github.eggy03.dmidecode.service.board that implement CommonDMIServiceInterfaceModifier and TypeClassDescriptionclassService class for fetching BIOS information from the system.classService class for fetching port connector information from the system.classService class for fetching system slot information from the system. -
Uses of CommonDMIServiceInterface in io.github.eggy03.dmidecode.service.memory
Classes in io.github.eggy03.dmidecode.service.memory that implement CommonDMIServiceInterfaceModifier and TypeClassDescriptionclassService class for fetching memory device information from the system. -
Uses of CommonDMIServiceInterface in io.github.eggy03.dmidecode.service.peripheral
Classes in io.github.eggy03.dmidecode.service.peripheral that implement CommonDMIServiceInterfaceModifier and TypeClassDescriptionclassService class for fetching portable battery information from the system. -
Uses of CommonDMIServiceInterface in io.github.eggy03.dmidecode.service.processor
Classes in io.github.eggy03.dmidecode.service.processor that implement CommonDMIServiceInterfaceModifier and TypeClassDescriptionclassService class for fetching cache information from the system.classService class for fetching processor information from the system.