Class DMIPhysicalMemoryArrayService

java.lang.Object
io.github.eggy03.dmidecode.service.memory.DMIPhysicalMemoryArrayService
All Implemented Interfaces:
OptionalCommonDMIServiceInterface<DMIPhysicalMemoryArray>

public class DMIPhysicalMemoryArrayService extends Object implements OptionalCommonDMIServiceInterface<DMIPhysicalMemoryArray>
Service class for fetching physical memory array information from the system.

This class executes the DMIType.PHYSICAL_MEMORY_ARRAY dmidecode command and maps the resulting output into a DMIPhysicalMemoryArray object.

Usage examples


 DMIPhysicalMemoryArrayService service = new DMIPhysicalMemoryArrayService();
 Optional<DMIPhysicalMemoryArray> memoryArray = service.get(10);
 
Since:
0.1.0
  • Field Details

  • Constructor Details

    • DMIPhysicalMemoryArrayService

      public DMIPhysicalMemoryArrayService()
      Creates DMIPhysicalMemoryArrayService with default configuration.
      Since:
      0.3.0
    • DMIPhysicalMemoryArrayService

      DMIPhysicalMemoryArrayService(@NonNull TerminalService terminalService, @NonNull DMIPhysicalMemoryArrayMapper mapper)
      Package Private constructor with injectable dependencies
      Parameters:
      terminalService - the TerminalService instance to use, must not be null
      mapper - the mapper instance to use, must not be null
      Since:
      0.3.0
  • Method Details