Package io.github.eggy03.dmidecode.service.processor
package io.github.eggy03.dmidecode.service.processor
-
ClassesClassDescriptionService class for fetching cache information from the system.Service class for fetching processor information from the system.