All Classes and Interfaces
Class
Description
Immutable representation of a baseboard (motherboard) device retrieved via DMI.
Immutable representation of BIOS information retrieved via DMI.
Immutable representation of BIOS language information retrieved via DMI.
Immutable representation of processor cache information retrieved via DMI.
Immutable representation of system chassis information retrieved via DMI.
Immutable representation of memory device information retrieved via DMI.
Immutable representation of physical memory array information retrieved via DMI.
Immutable representation of portable battery information retrieved via DMI.
Immutable representation of port connector information retrieved via DMI.
Immutable representation of processor information retrieved via DMI.
Immutable representation of system information retrieved via DMI.
Immutable representation of system slot information retrieved via DMI.
A common mapping interface for converting raw
dmidecode output
into strongly typed Java objects.Common service interface whose method implementations provide a way to fetch
DMI information from the system using the
dmidecode utility
in the form of a List.Immutable representation of a baseboard (motherboard) device retrieved via DMI.
Builds instances of type
DMIBaseboard.Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Provides a type-safe implementation of
CommonDMIMapper
and maps raw dmidecode output to objects or lists of DMIBaseboard.Service class for fetching baseboard/motherboard information from the system.
Immutable representation of BIOS information retrieved via DMI.
Builds instances of type
DMIBIOS.Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Immutable representation of BIOS language information retrieved via DMI.
Builds instances of type
DMIBIOSLanguage.Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Provides a type-safe implementation of
CommonDMIMapper
and maps raw dmidecode output to objects or lists of DMIBIOSLanguage.Service class for fetching BIOS language information from the system.
Provides a type-safe implementation of
CommonDMIMapper
and maps raw dmidecode output to objects or lists of DMIBIOS.Service class for fetching BIOS information from the system.
Immutable representation of processor cache information retrieved via DMI.
Builds instances of type
DMICache.Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Provides a type-safe implementation of
CommonDMIMapper
and maps raw dmidecode output to objects or lists of DMICache.Service class for fetching cache information from the system.
Immutable representation of system chassis information retrieved via DMI.
Builds instances of type
DMIChassis.Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Provides a type-safe implementation of
CommonDMIMapper
and maps raw dmidecode output to objects or lists of DMIChassis.Service class for fetching chassis information from the system.
Immutable representation of memory device information retrieved via DMI.
Builds instances of type
DMIMemoryDevice.Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Provides a type-safe implementation of
CommonDMIMapper
and maps raw dmidecode output to objects or lists of DMIMemoryDevice.Service class for fetching memory device information from the system.
Immutable representation of physical memory array information retrieved via DMI.
Builds instances of type
DMIPhysicalMemoryArray.Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Provides a type-safe implementation of
CommonDMIMapper
and maps raw dmidecode output to objects or lists of DMIPhysicalMemoryArray.Service class for fetching physical memory array information from the system.
Immutable representation of portable battery information retrieved via DMI.
Builds instances of type
DMIPortableBattery.Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Provides a type-safe implementation of
CommonDMIMapper
and maps raw dmidecode output to objects or lists of DMIPortableBattery.Service class for fetching portable battery information from the system.
Provides a type-safe implementation of
CommonDMIMapper
and maps raw dmidecode output to objects or lists of DMIPortConnectorInformation.Immutable representation of port connector information retrieved via DMI.
Builds instances of type
DMIPortConnectorInformation.Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Service class for fetching port connector information from the system.
Immutable representation of processor information retrieved via DMI.
Builds instances of type
DMIProcessor.Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Provides a type-safe implementation of
CommonDMIMapper
and maps raw dmidecode output to objects or lists of DMIProcessor.Service class for fetching processor information from the system.
Immutable representation of system information retrieved via DMI.
Builds instances of type
DMISystem.Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Provides a type-safe implementation of
CommonDMIMapper
and maps raw dmidecode output to objects or lists of DMISystem.Service class for fetching system information from the system.
Immutable representation of system slot information retrieved via DMI.
Builds instances of type
DMISystemSlots.Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Provides a type-safe implementation of
CommonDMIMapper
and maps raw dmidecode output to objects or lists of DMISystemSlots.Service class for fetching system slot information from the system.
Enumeration of DMI types as defined by the
dmidecode specification.
When marked on a method (or a constructor), it serves as an indication that
the method's behavior depends on unstable and or environment-specific logic
and may break without notice.
A custom annotation that is intended to be applied with
package classes.
Value.Immutable,
on
invalid reference
io.github.eggy03.dmidecode.entity
When marked on a method (or a constructor), it indicates that annotated method or constructor
has a definition that invokes a method or a constructor annotated with
FragileMethodEnum to classify the type of method that is marked as fragile
Common service interface whose method implementations provide a way to fetch
a single DMI structure from the system using the
dmidecode utility
in the form of an Optional.Thrown when the terminal fails to execute a command or a script
A utility class that provides a way to launch a terminal session
Indicates that the underlying `Collection` or `Map` is unmodifiable.