Annotation Type ImmutableEntityStyle


@Target({PACKAGE,TYPE}) @Retention(CLASS) public @interface ImmutableEntityStyle

A custom annotation that is intended to be applied with Value.Immutable, on

invalid reference
io.github.eggy03.dmidecode.entity
package classes.

It modifies the naming and structural style of the generated immutable implementations via Value.Style and contains JsonSerialize for automatic Jackson integration.

Since:
0.2.0