Class ImmutableDMIBIOSLanguage
java.lang.Object
io.github.eggy03.dmidecode.entity.board.DMIBIOSLanguage
io.github.eggy03.dmidecode.entity.board.ImmutableDMIBIOSLanguage
@Generated(from="DMIBIOSLanguage",
generator="Immutables")
@Generated("org.immutables.processor.ProxyProcessor")
public final class ImmutableDMIBIOSLanguage
extends DMIBIOSLanguage
Immutable implementation of
DMIBIOSLanguage.
Use the builder to create immutable instances:
new ImmutableDMIBIOSLanguage.Builder().
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classBuilds instances of typeImmutableDMIBIOSLanguage.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure -
Field Summary
Fields -
Constructor Summary
ConstructorsModifierConstructorDescriptionprivateImmutableDMIBIOSLanguage(@Nullable List<String> installableLanguages, @Nullable String currentLanguage) -
Method Summary
Modifier and TypeMethodDescriptionstatic ImmutableDMIBIOSLanguagecopyOf(DMIBIOSLanguage instance) Creates an immutable copy of aDMIBIOSLanguagevalue.private static <T> List<T> createSafeList(Iterable<? extends T> iterable, boolean checkNulls, boolean skipNulls) private static <T> List<T> createUnmodifiableList(boolean clone, List<? extends T> list) @Nullable StringbooleanThis instance is equal to all instances ofImmutableDMIBIOSLanguagethat have equal attribute values.private booleanequalsByValue(ImmutableDMIBIOSLanguage another) (package private) static ImmutableDMIBIOSLanguageDeprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructureinthashCode()Computes a hash code from attributes:installableLanguages,currentLanguage.toString()Prints the immutable valueDMIBIOSLanguagewith attribute values.final ImmutableDMIBIOSLanguagewithCurrentLanguage(@Nullable String value) Copy the current immutable object by setting a value for thecurrentLanguageattribute.final ImmutableDMIBIOSLanguagewithInstallableLanguages(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofinstallableLanguages.final ImmutableDMIBIOSLanguagewithInstallableLanguages(@Nullable String @Nullable ... elements) Copy the current immutable object with elements that replace the content ofinstallableLanguages.Methods inherited from class io.github.eggy03.dmidecode.entity.board.DMIBIOSLanguage
toJson
-
Field Details
-
installableLanguages
-
currentLanguage
-
-
Constructor Details
-
ImmutableDMIBIOSLanguage
-
-
Method Details
-
installableLanguages
- Specified by:
installableLanguagesin classDMIBIOSLanguage- Returns:
- The value of the
installableLanguagesattribute
-
currentLanguage
- Specified by:
currentLanguagein classDMIBIOSLanguage- Returns:
- The value of the
currentLanguageattribute
-
withInstallableLanguages
public final ImmutableDMIBIOSLanguage withInstallableLanguages(@Nullable String @Nullable ... elements) Copy the current immutable object with elements that replace the content ofinstallableLanguages.- Parameters:
elements- The elements to set- Returns:
- A modified copy of
thisobject
-
withInstallableLanguages
public final ImmutableDMIBIOSLanguage withInstallableLanguages(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofinstallableLanguages. A shallow reference equality check is used to prevent copying of the same value by returningthis.- Parameters:
elements- An iterable of installableLanguages elements to set- Returns:
- A modified copy or
thisif not changed
-
withCurrentLanguage
Copy the current immutable object by setting a value for thecurrentLanguageattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for currentLanguage (can benull)- Returns:
- A modified copy or the
thisobject
-
equals
This instance is equal to all instances ofImmutableDMIBIOSLanguagethat have equal attribute values. -
equalsByValue
-
hashCode
public int hashCode()Computes a hash code from attributes:installableLanguages,currentLanguage. -
toString
Prints the immutable valueDMIBIOSLanguagewith attribute values. -
fromJson
Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructure- Parameters:
json- A JSON-bindable data structure- Returns:
- An immutable value type
-
copyOf
Creates an immutable copy of aDMIBIOSLanguagevalue. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.- Parameters:
instance- The instance to copy- Returns:
- A copied immutable DMIBIOSLanguage instance
-
createSafeList
-
createUnmodifiableList
-