Class ImmutableDMIBaseboard
java.lang.Object
io.github.eggy03.dmidecode.entity.board.DMIBaseboard
io.github.eggy03.dmidecode.entity.board.ImmutableDMIBaseboard
@Generated(from="DMIBaseboard",
generator="Immutables")
@Generated("org.immutables.processor.ProxyProcessor")
public final class ImmutableDMIBaseboard
extends DMIBaseboard
Immutable implementation of
DMIBaseboard.
Use the builder to create immutable instances:
new ImmutableDMIBaseboard.Builder().
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classBuilds instances of typeImmutableDMIBaseboard.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure -
Field Summary
FieldsModifier and TypeFieldDescriptionprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Integerprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable String -
Constructor Summary
ConstructorsModifierConstructorDescriptionprivateImmutableDMIBaseboard(@Nullable String manufacturer, @Nullable String productName, @Nullable String version, @Nullable String serialNumber, @Nullable String assetTag, @Nullable List<String> features, @Nullable String locationInChassis, @Nullable String chassisHandle, @Nullable String type, @Nullable Integer containedObjectHandles) -
Method Summary
Modifier and TypeMethodDescription@Nullable StringassetTag()@Nullable String@Nullable Integerstatic ImmutableDMIBaseboardcopyOf(DMIBaseboard instance) Creates an immutable copy of aDMIBaseboardvalue.private static <T> List<T> createSafeList(Iterable<? extends T> iterable, boolean checkNulls, boolean skipNulls) private static <T> List<T> createUnmodifiableList(boolean clone, List<? extends T> list) booleanThis instance is equal to all instances ofImmutableDMIBaseboardthat have equal attribute values.private booleanequalsByValue(ImmutableDMIBaseboard another) features()(package private) static ImmutableDMIBaseboardDeprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructureinthashCode()Computes a hash code from attributes:manufacturer,productName,version,serialNumber,assetTag,features,locationInChassis,chassisHandle,type,containedObjectHandles.@Nullable String@Nullable String@Nullable String@Nullable StringtoString()Prints the immutable valueDMIBaseboardwith attribute values.@Nullable Stringtype()@Nullable Stringversion()final ImmutableDMIBaseboardwithAssetTag(@Nullable String value) Copy the current immutable object by setting a value for theassetTagattribute.final ImmutableDMIBaseboardwithChassisHandle(@Nullable String value) Copy the current immutable object by setting a value for thechassisHandleattribute.final ImmutableDMIBaseboardwithContainedObjectHandles(@Nullable Integer value) Copy the current immutable object by setting a value for thecontainedObjectHandlesattribute.final ImmutableDMIBaseboardwithFeatures(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content offeatures.final ImmutableDMIBaseboardwithFeatures(@Nullable String @Nullable ... elements) Copy the current immutable object with elements that replace the content offeatures.final ImmutableDMIBaseboardwithLocationInChassis(@Nullable String value) Copy the current immutable object by setting a value for thelocationInChassisattribute.final ImmutableDMIBaseboardwithManufacturer(@Nullable String value) Copy the current immutable object by setting a value for themanufacturerattribute.final ImmutableDMIBaseboardwithProductName(@Nullable String value) Copy the current immutable object by setting a value for theproductNameattribute.final ImmutableDMIBaseboardwithSerialNumber(@Nullable String value) Copy the current immutable object by setting a value for theserialNumberattribute.final ImmutableDMIBaseboardCopy the current immutable object by setting a value for thetypeattribute.final ImmutableDMIBaseboardwithVersion(@Nullable String value) Copy the current immutable object by setting a value for theversionattribute.Methods inherited from class io.github.eggy03.dmidecode.entity.board.DMIBaseboard
toJson
-
Field Details
-
manufacturer
-
productName
-
version
-
serialNumber
-
assetTag
-
features
-
locationInChassis
-
chassisHandle
-
type
-
containedObjectHandles
-
-
Constructor Details
-
ImmutableDMIBaseboard
private ImmutableDMIBaseboard(@Nullable String manufacturer, @Nullable String productName, @Nullable String version, @Nullable String serialNumber, @Nullable String assetTag, @Nullable List<String> features, @Nullable String locationInChassis, @Nullable String chassisHandle, @Nullable String type, @Nullable Integer containedObjectHandles)
-
-
Method Details
-
manufacturer
- Specified by:
manufacturerin classDMIBaseboard- Returns:
- The value of the
manufacturerattribute
-
productName
- Specified by:
productNamein classDMIBaseboard- Returns:
- The value of the
productNameattribute
-
version
- Specified by:
versionin classDMIBaseboard- Returns:
- The value of the
versionattribute
-
serialNumber
- Specified by:
serialNumberin classDMIBaseboard- Returns:
- The value of the
serialNumberattribute
-
assetTag
- Specified by:
assetTagin classDMIBaseboard- Returns:
- The value of the
assetTagattribute
-
features
- Specified by:
featuresin classDMIBaseboard- Returns:
- The value of the
featuresattribute
-
locationInChassis
- Specified by:
locationInChassisin classDMIBaseboard- Returns:
- The value of the
locationInChassisattribute
-
chassisHandle
- Specified by:
chassisHandlein classDMIBaseboard- Returns:
- The value of the
chassisHandleattribute
-
type
- Specified by:
typein classDMIBaseboard- Returns:
- The value of the
typeattribute
-
containedObjectHandles
- Specified by:
containedObjectHandlesin classDMIBaseboard- Returns:
- The value of the
containedObjectHandlesattribute
-
withManufacturer
Copy the current immutable object by setting a value for themanufacturerattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for manufacturer (can benull)- Returns:
- A modified copy or the
thisobject
-
withProductName
Copy the current immutable object by setting a value for theproductNameattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for productName (can benull)- Returns:
- A modified copy or the
thisobject
-
withVersion
Copy the current immutable object by setting a value for theversionattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for version (can benull)- Returns:
- A modified copy or the
thisobject
-
withSerialNumber
Copy the current immutable object by setting a value for theserialNumberattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for serialNumber (can benull)- Returns:
- A modified copy or the
thisobject
-
withAssetTag
Copy the current immutable object by setting a value for theassetTagattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for assetTag (can benull)- Returns:
- A modified copy or the
thisobject
-
withFeatures
Copy the current immutable object with elements that replace the content offeatures.- Parameters:
elements- The elements to set- Returns:
- A modified copy of
thisobject
-
withFeatures
Copy the current immutable object with elements that replace the content offeatures. A shallow reference equality check is used to prevent copying of the same value by returningthis.- Parameters:
elements- An iterable of features elements to set- Returns:
- A modified copy or
thisif not changed
-
withLocationInChassis
Copy the current immutable object by setting a value for thelocationInChassisattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for locationInChassis (can benull)- Returns:
- A modified copy or the
thisobject
-
withChassisHandle
Copy the current immutable object by setting a value for thechassisHandleattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for chassisHandle (can benull)- Returns:
- A modified copy or the
thisobject
-
withType
Copy the current immutable object by setting a value for thetypeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for type (can benull)- Returns:
- A modified copy or the
thisobject
-
withContainedObjectHandles
Copy the current immutable object by setting a value for thecontainedObjectHandlesattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for containedObjectHandles (can benull)- Returns:
- A modified copy or the
thisobject
-
equals
This instance is equal to all instances ofImmutableDMIBaseboardthat have equal attribute values. -
equalsByValue
-
hashCode
public int hashCode()Computes a hash code from attributes:manufacturer,productName,version,serialNumber,assetTag,features,locationInChassis,chassisHandle,type,containedObjectHandles. -
toString
Prints the immutable valueDMIBaseboardwith attribute values. -
fromJson
Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructure- Parameters:
json- A JSON-bindable data structure- Returns:
- An immutable value type
-
copyOf
Creates an immutable copy of aDMIBaseboardvalue. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.- Parameters:
instance- The instance to copy- Returns:
- A copied immutable DMIBaseboard instance
-
createSafeList
-
createUnmodifiableList
-