Class ImmutableDMISystemSlots
java.lang.Object
io.github.eggy03.dmidecode.entity.board.DMISystemSlots
io.github.eggy03.dmidecode.entity.board.ImmutableDMISystemSlots
@Generated(from="DMISystemSlots",
generator="Immutables")
@Generated("org.immutables.processor.ProxyProcessor")
public final class ImmutableDMISystemSlots
extends DMISystemSlots
Immutable implementation of
DMISystemSlots.
Use the builder to create immutable instances:
new ImmutableDMISystemSlots.Builder().
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classBuilds instances of typeImmutableDMISystemSlots.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure -
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescription@Nullable Stringstatic ImmutableDMISystemSlotscopyOf(DMISystemSlots instance) Creates an immutable copy of aDMISystemSlotsvalue.private static <T> List<T> createSafeList(Iterable<? extends T> iterable, boolean checkNulls, boolean skipNulls) private static <T> List<T> createUnmodifiableList(boolean clone, List<? extends T> list) @Nullable String@Nullable StringbooleanThis instance is equal to all instances ofImmutableDMISystemSlotsthat have equal attribute values.private booleanequalsByValue(ImmutableDMISystemSlots another) (package private) static ImmutableDMISystemSlotsDeprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructureinthashCode()Computes a hash code from attributes:designation,type,currentUsage,length,id,characteristics,busAddress.@Nullable Integerid()@Nullable Stringlength()toString()Prints the immutable valueDMISystemSlotswith attribute values.@Nullable Stringtype()final ImmutableDMISystemSlotswithBusAddress(@Nullable String value) Copy the current immutable object by setting a value for thebusAddressattribute.final ImmutableDMISystemSlotswithCharacteristics(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofcharacteristics.final ImmutableDMISystemSlotswithCharacteristics(@Nullable String @Nullable ... elements) Copy the current immutable object with elements that replace the content ofcharacteristics.final ImmutableDMISystemSlotswithCurrentUsage(@Nullable String value) Copy the current immutable object by setting a value for thecurrentUsageattribute.final ImmutableDMISystemSlotswithDesignation(@Nullable String value) Copy the current immutable object by setting a value for thedesignationattribute.final ImmutableDMISystemSlotsCopy the current immutable object by setting a value for theidattribute.final ImmutableDMISystemSlotswithLength(@Nullable String value) Copy the current immutable object by setting a value for thelengthattribute.final ImmutableDMISystemSlotsCopy the current immutable object by setting a value for thetypeattribute.Methods inherited from class io.github.eggy03.dmidecode.entity.board.DMISystemSlots
toJson
-
Field Details
-
designation
-
type
-
currentUsage
-
length
-
id
-
characteristics
-
busAddress
-
-
Constructor Details
-
ImmutableDMISystemSlots
-
-
Method Details
-
designation
- Specified by:
designationin classDMISystemSlots- Returns:
- The value of the
designationattribute
-
type
- Specified by:
typein classDMISystemSlots- Returns:
- The value of the
typeattribute
-
currentUsage
- Specified by:
currentUsagein classDMISystemSlots- Returns:
- The value of the
currentUsageattribute
-
length
- Specified by:
lengthin classDMISystemSlots- Returns:
- The value of the
lengthattribute
-
id
- Specified by:
idin classDMISystemSlots- Returns:
- The value of the
idattribute
-
characteristics
- Specified by:
characteristicsin classDMISystemSlots- Returns:
- The value of the
characteristicsattribute
-
busAddress
- Specified by:
busAddressin classDMISystemSlots- Returns:
- The value of the
busAddressattribute
-
withDesignation
Copy the current immutable object by setting a value for thedesignationattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for designation (can benull)- Returns:
- A modified copy or the
thisobject
-
withType
Copy the current immutable object by setting a value for thetypeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for type (can benull)- Returns:
- A modified copy or the
thisobject
-
withCurrentUsage
Copy the current immutable object by setting a value for thecurrentUsageattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for currentUsage (can benull)- Returns:
- A modified copy or the
thisobject
-
withLength
Copy the current immutable object by setting a value for thelengthattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for length (can benull)- Returns:
- A modified copy or the
thisobject
-
withId
Copy the current immutable object by setting a value for theidattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for id (can benull)- Returns:
- A modified copy or the
thisobject
-
withCharacteristics
Copy the current immutable object with elements that replace the content ofcharacteristics.- Parameters:
elements- The elements to set- Returns:
- A modified copy of
thisobject
-
withCharacteristics
public final ImmutableDMISystemSlots withCharacteristics(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofcharacteristics. A shallow reference equality check is used to prevent copying of the same value by returningthis.- Parameters:
elements- An iterable of characteristics elements to set- Returns:
- A modified copy or
thisif not changed
-
withBusAddress
Copy the current immutable object by setting a value for thebusAddressattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for busAddress (can benull)- Returns:
- A modified copy or the
thisobject
-
equals
This instance is equal to all instances ofImmutableDMISystemSlotsthat have equal attribute values. -
equalsByValue
-
hashCode
public int hashCode()Computes a hash code from attributes:designation,type,currentUsage,length,id,characteristics,busAddress. -
toString
Prints the immutable valueDMISystemSlotswith attribute values. -
fromJson
Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructure- Parameters:
json- A JSON-bindable data structure- Returns:
- An immutable value type
-
copyOf
Creates an immutable copy of aDMISystemSlotsvalue. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.- Parameters:
instance- The instance to copy- Returns:
- A copied immutable DMISystemSlots instance
-
createSafeList
-
createUnmodifiableList
-