Class AbstractDMIPhysicalMemoryArray
java.lang.Object
io.github.eggy03.dmidecode.entity.memory.AbstractDMIPhysicalMemoryArray
- Direct Known Subclasses:
DMIPhysicalMemoryArray,DMIPhysicalMemoryArray.Json
Immutable representation of physical memory array information retrieved via DMI.
Fields correspond to properties reported by dmidecode for the Physical
Memory Array (Type 16) SMBIOS structure.
Instances of this class are thread-safe.
Usage example
DMIPhysicalMemoryArray array = new DMIPhysicalMemoryArray.Builder()
.location("System Board Or Motherboard")
.use("System Memory")
.maximumCapacity("128 GB")
.numberOfDevices(4)
.build();
// Create a modified copy
DMIPhysicalMemoryArray updated = array
.withErrorCorrectionType("Multi-bit ECC");
- Since:
- 0.2.0