Class DMIMemoryDevice
java.lang.Object
io.github.eggy03.dmidecode.entity.memory.DMIMemoryDevice
- Direct Known Subclasses:
ImmutableDMIMemoryDevice,ImmutableDMIMemoryDevice.Json
Immutable representation of memory device information retrieved via DMI.
Fields correspond to properties reported by dmidecode for the Memory
Device (Type 17) SMBIOS structure.
Instances of this class are thread-safe.
- Since:
- 0.2.0
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionabstract @Nullable Stringabstract @Nullable StringassetTag()abstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringlocator()abstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Integerrank()abstract @Nullable Stringabstract @Nullable Stringset()abstract @Nullable Stringsize()abstract @Nullable Stringspeed()toJson()abstract @Nullable Stringabstract @Nullable Stringtype()abstract @Nullable Stringabstract @Nullable String
-
Constructor Details
-
DMIMemoryDevice
public DMIMemoryDevice()
-
-
Method Details
-
arrayHandle
-
errorInformationHandle
-
totalWidth
-
dataWidth
-
size
-
formFactor
-
set
-
locator
-
bankLocator
-
type
-
typeDetail
-
speed
-
manufacturer
-
serialNumber
-
assetTag
-
partNumber
-
rank
-
configuredMemorySpeed
-
minimumVoltage
-
maximumVoltage
-
configuredVoltage
-
memoryTechnology
-
memoryOperatingModeCapability
-
firmwareVersion
-
moduleManufacturerId
-
moduleProductId
-
memorySubsystemControllerManufacturerId
-
memorySubsystemControllerProductId
-
nonVolatileSize
-
volatileSize
-
cacheSize
-
logicalSize
-
toJson
-