Class DMIPhysicalMemoryArray
java.lang.Object
io.github.eggy03.dmidecode.entity.memory.DMIPhysicalMemoryArray
- Direct Known Subclasses:
ImmutableDMIPhysicalMemoryArray,ImmutableDMIPhysicalMemoryArray.Json
Immutable representation of physical memory array information retrieved via DMI.
Fields correspond to properties reported by dmidecode for the Physical
Memory Array (Type 16) SMBIOS structure.
Instances of this class are thread-safe.
- Since:
- 0.2.0
-
Constructor Details
-
DMIPhysicalMemoryArray
public DMIPhysicalMemoryArray()
-
-
Method Details
-
location
-
use
-
errorCorrectionType
-
maximumCapacity
-
errorInformationHandle
-
numberOfDevices
-
toJson
-