Class DMIPhysicalMemoryArray
java.lang.Object
io.github.eggy03.dmidecode.entity.memory.AbstractDMIPhysicalMemoryArray
io.github.eggy03.dmidecode.entity.memory.DMIPhysicalMemoryArray
@Generated(from="AbstractDMIPhysicalMemoryArray",
generator="Immutables")
@Generated("org.immutables.processor.ProxyProcessor")
public final class DMIPhysicalMemoryArray
extends AbstractDMIPhysicalMemoryArray
Immutable representation of physical memory array information retrieved via DMI.
Fields correspond to properties reported by dmidecode for the Physical
Memory Array (Type 16) SMBIOS structure.
Instances of this class are thread-safe.
Usage example
DMIPhysicalMemoryArray array = new DMIPhysicalMemoryArray.Builder()
.location("System Board Or Motherboard")
.use("System Memory")
.maximumCapacity("128 GB")
.numberOfDevices(4)
.build();
// Create a modified copy
DMIPhysicalMemoryArray updated = array
.withErrorCorrectionType("Multi-bit ECC");
- Since:
- 0.2.0
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classBuilds instances of typeDMIPhysicalMemoryArray.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure -
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic DMIPhysicalMemoryArraycopyOf(AbstractDMIPhysicalMemoryArray instance) Creates an immutable copy of aAbstractDMIPhysicalMemoryArrayvalue.booleanThis instance is equal to all instances ofDMIPhysicalMemoryArraythat have equal attribute values.private booleanequalsByValue(DMIPhysicalMemoryArray another) @Nullable String@Nullable String(package private) static DMIPhysicalMemoryArrayDeprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructureinthashCode()Computes a hash code from attributes:location,use,errorCorrectionType,maximumCapacity,errorInformationHandle,numberOfDevices.@Nullable Stringlocation()@Nullable String@Nullable Integer@Nullable Stringuse()final DMIPhysicalMemoryArraywithErrorCorrectionType(@Nullable String value) Copy the current immutable object by setting a value for theerrorCorrectionTypeattribute.final DMIPhysicalMemoryArraywithErrorInformationHandle(@Nullable String value) Copy the current immutable object by setting a value for theerrorInformationHandleattribute.final DMIPhysicalMemoryArraywithLocation(@Nullable String value) Copy the current immutable object by setting a value for thelocationattribute.final DMIPhysicalMemoryArraywithMaximumCapacity(@Nullable String value) Copy the current immutable object by setting a value for themaximumCapacityattribute.final DMIPhysicalMemoryArraywithNumberOfDevices(@Nullable Integer value) Copy the current immutable object by setting a value for thenumberOfDevicesattribute.final DMIPhysicalMemoryArrayCopy the current immutable object by setting a value for theuseattribute.Methods inherited from class io.github.eggy03.dmidecode.entity.memory.AbstractDMIPhysicalMemoryArray
toString
-
Field Details
-
location
-
use
-
errorCorrectionType
-
maximumCapacity
-
errorInformationHandle
-
numberOfDevices
-
-
Constructor Details
-
DMIPhysicalMemoryArray
-
-
Method Details
-
location
- Specified by:
locationin classAbstractDMIPhysicalMemoryArray- Returns:
- The value of the
locationattribute
-
use
- Specified by:
usein classAbstractDMIPhysicalMemoryArray- Returns:
- The value of the
useattribute
-
errorCorrectionType
- Specified by:
errorCorrectionTypein classAbstractDMIPhysicalMemoryArray- Returns:
- The value of the
errorCorrectionTypeattribute
-
maximumCapacity
- Specified by:
maximumCapacityin classAbstractDMIPhysicalMemoryArray- Returns:
- The value of the
maximumCapacityattribute
-
errorInformationHandle
- Specified by:
errorInformationHandlein classAbstractDMIPhysicalMemoryArray- Returns:
- The value of the
errorInformationHandleattribute
-
numberOfDevices
- Specified by:
numberOfDevicesin classAbstractDMIPhysicalMemoryArray- Returns:
- The value of the
numberOfDevicesattribute
-
withLocation
Copy the current immutable object by setting a value for thelocationattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for location (can benull)- Returns:
- A modified copy or the
thisobject
-
withUse
Copy the current immutable object by setting a value for theuseattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for use (can benull)- Returns:
- A modified copy or the
thisobject
-
withErrorCorrectionType
Copy the current immutable object by setting a value for theerrorCorrectionTypeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for errorCorrectionType (can benull)- Returns:
- A modified copy or the
thisobject
-
withMaximumCapacity
Copy the current immutable object by setting a value for themaximumCapacityattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for maximumCapacity (can benull)- Returns:
- A modified copy or the
thisobject
-
withErrorInformationHandle
Copy the current immutable object by setting a value for theerrorInformationHandleattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for errorInformationHandle (can benull)- Returns:
- A modified copy or the
thisobject
-
withNumberOfDevices
Copy the current immutable object by setting a value for thenumberOfDevicesattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for numberOfDevices (can benull)- Returns:
- A modified copy or the
thisobject
-
equals
This instance is equal to all instances ofDMIPhysicalMemoryArraythat have equal attribute values. -
equalsByValue
-
hashCode
public int hashCode()Computes a hash code from attributes:location,use,errorCorrectionType,maximumCapacity,errorInformationHandle,numberOfDevices. -
fromJson
Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructure- Parameters:
json- A JSON-bindable data structure- Returns:
- An immutable value type
-
copyOf
Creates an immutable copy of aAbstractDMIPhysicalMemoryArrayvalue. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.- Parameters:
instance- The instance to copy- Returns:
- A copied immutable DMIPhysicalMemoryArray instance
-