Class DMIPhysicalMemoryArray.Json
java.lang.Object
io.github.eggy03.dmidecode.entity.memory.AbstractDMIPhysicalMemoryArray
io.github.eggy03.dmidecode.entity.memory.DMIPhysicalMemoryArray.Json
- Enclosing class:
DMIPhysicalMemoryArray
@Generated(from="AbstractDMIPhysicalMemoryArray",
generator="Immutables")
@Deprecated
static final class DMIPhysicalMemoryArray.Json
extends AbstractDMIPhysicalMemoryArray
Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Utility type used to correctly read immutable object from JSON representation.
-
Field Summary
FieldsModifier and TypeFieldDescription(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable IntegerDeprecated.(package private) @Nullable StringDeprecated. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescription@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable Stringlocation()Deprecated.@Nullable StringDeprecated.@Nullable IntegerDeprecated.voidsetErrorCorrectionType(@Nullable String errorCorrectionType) Deprecated.voidsetErrorInformationHandle(@Nullable String errorInformationHandle) Deprecated.voidsetLocation(@Nullable String location) Deprecated.voidsetMaximumCapacity(@Nullable String maximumCapacity) Deprecated.voidsetNumberOfDevices(@Nullable Integer numberOfDevices) Deprecated.voidDeprecated.@Nullable Stringuse()Deprecated.Methods inherited from class io.github.eggy03.dmidecode.entity.memory.AbstractDMIPhysicalMemoryArray
toString
-
Field Details
-
_location
@Nullable String _locationDeprecated. -
_use
@Nullable String _useDeprecated. -
_errorCorrectionType
@Nullable String _errorCorrectionTypeDeprecated. -
_maximumCapacity
@Nullable String _maximumCapacityDeprecated. -
_errorInformationHandle
@Nullable String _errorInformationHandleDeprecated. -
_numberOfDevices
@Nullable Integer _numberOfDevicesDeprecated.
-
-
Constructor Details
-
Json
Json()Deprecated.
-
-
Method Details
-
setLocation
Deprecated. -
setUse
Deprecated. -
setErrorCorrectionType
Deprecated. -
setMaximumCapacity
Deprecated. -
setErrorInformationHandle
Deprecated. -
setNumberOfDevices
Deprecated. -
location
Deprecated.- Specified by:
locationin classAbstractDMIPhysicalMemoryArray
-
use
Deprecated.- Specified by:
usein classAbstractDMIPhysicalMemoryArray
-
errorCorrectionType
Deprecated.- Specified by:
errorCorrectionTypein classAbstractDMIPhysicalMemoryArray
-
maximumCapacity
Deprecated.- Specified by:
maximumCapacityin classAbstractDMIPhysicalMemoryArray
-
errorInformationHandle
Deprecated.- Specified by:
errorInformationHandlein classAbstractDMIPhysicalMemoryArray
-
numberOfDevices
Deprecated.- Specified by:
numberOfDevicesin classAbstractDMIPhysicalMemoryArray
-