Class ImmutableDMIMemoryDevice
java.lang.Object
io.github.eggy03.dmidecode.entity.memory.DMIMemoryDevice
io.github.eggy03.dmidecode.entity.memory.ImmutableDMIMemoryDevice
@Generated(from="DMIMemoryDevice",
generator="Immutables")
@Generated("org.immutables.processor.ProxyProcessor")
public final class ImmutableDMIMemoryDevice
extends DMIMemoryDevice
Immutable implementation of
DMIMemoryDevice.
Use the builder to create immutable instances:
new ImmutableDMIMemoryDevice.Builder().
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classBuilds instances of typeImmutableDMIMemoryDevice.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure -
Field Summary
FieldsModifier and TypeFieldDescriptionprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Integerprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable String -
Constructor Summary
ConstructorsModifierConstructorDescriptionprivateImmutableDMIMemoryDevice(@Nullable String arrayHandle, @Nullable String errorInformationHandle, @Nullable String totalWidth, @Nullable String dataWidth, @Nullable String size, @Nullable String formFactor, @Nullable String set, @Nullable String locator, @Nullable String bankLocator, @Nullable String type, @Nullable String typeDetail, @Nullable String speed, @Nullable String manufacturer, @Nullable String serialNumber, @Nullable String assetTag, @Nullable String partNumber, @Nullable Integer rank, @Nullable String configuredMemorySpeed, @Nullable String minimumVoltage, @Nullable String maximumVoltage, @Nullable String configuredVoltage, @Nullable String memoryTechnology, @Nullable String memoryOperatingModeCapability, @Nullable String firmwareVersion, @Nullable String moduleManufacturerId, @Nullable String moduleProductId, @Nullable String memorySubsystemControllerManufacturerId, @Nullable String memorySubsystemControllerProductId, @Nullable String nonVolatileSize, @Nullable String volatileSize, @Nullable String cacheSize, @Nullable String logicalSize) -
Method Summary
Modifier and TypeMethodDescription@Nullable String@Nullable StringassetTag()@Nullable String@Nullable String@Nullable String@Nullable Stringstatic ImmutableDMIMemoryDevicecopyOf(DMIMemoryDevice instance) Creates an immutable copy of aDMIMemoryDevicevalue.@Nullable StringbooleanThis instance is equal to all instances ofImmutableDMIMemoryDevicethat have equal attribute values.private booleanequalsByValue(ImmutableDMIMemoryDevice another) @Nullable String@Nullable String@Nullable String(package private) static ImmutableDMIMemoryDeviceDeprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructureinthashCode()Computes a hash code from attributes:arrayHandle,errorInformationHandle,totalWidth,dataWidth,size,formFactor,set,locator,bankLocator,type,typeDetail,speed,manufacturer,serialNumber,assetTag,partNumber,rank,configuredMemorySpeed,minimumVoltage,maximumVoltage,configuredVoltage,memoryTechnology,memoryOperatingModeCapability,firmwareVersion,moduleManufacturerId,moduleProductId,memorySubsystemControllerManufacturerId,memorySubsystemControllerProductId,nonVolatileSize,volatileSize,cacheSize,logicalSize.@Nullable Stringlocator()@Nullable String@Nullable String@Nullable String@Nullable String@Nullable String@Nullable String@Nullable String@Nullable String@Nullable String@Nullable String@Nullable String@Nullable String@Nullable Integerrank()@Nullable String@Nullable Stringset()@Nullable Stringsize()@Nullable Stringspeed()toString()Prints the immutable valueDMIMemoryDevicewith attribute values.@Nullable String@Nullable Stringtype()@Nullable String@Nullable Stringfinal ImmutableDMIMemoryDevicewithArrayHandle(@Nullable String value) Copy the current immutable object by setting a value for thearrayHandleattribute.final ImmutableDMIMemoryDevicewithAssetTag(@Nullable String value) Copy the current immutable object by setting a value for theassetTagattribute.final ImmutableDMIMemoryDevicewithBankLocator(@Nullable String value) Copy the current immutable object by setting a value for thebankLocatorattribute.final ImmutableDMIMemoryDevicewithCacheSize(@Nullable String value) Copy the current immutable object by setting a value for thecacheSizeattribute.final ImmutableDMIMemoryDevicewithConfiguredMemorySpeed(@Nullable String value) Copy the current immutable object by setting a value for theconfiguredMemorySpeedattribute.final ImmutableDMIMemoryDevicewithConfiguredVoltage(@Nullable String value) Copy the current immutable object by setting a value for theconfiguredVoltageattribute.final ImmutableDMIMemoryDevicewithDataWidth(@Nullable String value) Copy the current immutable object by setting a value for thedataWidthattribute.final ImmutableDMIMemoryDevicewithErrorInformationHandle(@Nullable String value) Copy the current immutable object by setting a value for theerrorInformationHandleattribute.final ImmutableDMIMemoryDevicewithFirmwareVersion(@Nullable String value) Copy the current immutable object by setting a value for thefirmwareVersionattribute.final ImmutableDMIMemoryDevicewithFormFactor(@Nullable String value) Copy the current immutable object by setting a value for theformFactorattribute.final ImmutableDMIMemoryDevicewithLocator(@Nullable String value) Copy the current immutable object by setting a value for thelocatorattribute.final ImmutableDMIMemoryDevicewithLogicalSize(@Nullable String value) Copy the current immutable object by setting a value for thelogicalSizeattribute.final ImmutableDMIMemoryDevicewithManufacturer(@Nullable String value) Copy the current immutable object by setting a value for themanufacturerattribute.final ImmutableDMIMemoryDevicewithMaximumVoltage(@Nullable String value) Copy the current immutable object by setting a value for themaximumVoltageattribute.final ImmutableDMIMemoryDevicewithMemoryOperatingModeCapability(@Nullable String value) Copy the current immutable object by setting a value for thememoryOperatingModeCapabilityattribute.final ImmutableDMIMemoryDevicewithMemorySubsystemControllerManufacturerId(@Nullable String value) Copy the current immutable object by setting a value for thememorySubsystemControllerManufacturerIdattribute.final ImmutableDMIMemoryDevicewithMemorySubsystemControllerProductId(@Nullable String value) Copy the current immutable object by setting a value for thememorySubsystemControllerProductIdattribute.final ImmutableDMIMemoryDevicewithMemoryTechnology(@Nullable String value) Copy the current immutable object by setting a value for thememoryTechnologyattribute.final ImmutableDMIMemoryDevicewithMinimumVoltage(@Nullable String value) Copy the current immutable object by setting a value for theminimumVoltageattribute.final ImmutableDMIMemoryDevicewithModuleManufacturerId(@Nullable String value) Copy the current immutable object by setting a value for themoduleManufacturerIdattribute.final ImmutableDMIMemoryDevicewithModuleProductId(@Nullable String value) Copy the current immutable object by setting a value for themoduleProductIdattribute.final ImmutableDMIMemoryDevicewithNonVolatileSize(@Nullable String value) Copy the current immutable object by setting a value for thenonVolatileSizeattribute.final ImmutableDMIMemoryDevicewithPartNumber(@Nullable String value) Copy the current immutable object by setting a value for thepartNumberattribute.final ImmutableDMIMemoryDeviceCopy the current immutable object by setting a value for therankattribute.final ImmutableDMIMemoryDevicewithSerialNumber(@Nullable String value) Copy the current immutable object by setting a value for theserialNumberattribute.final ImmutableDMIMemoryDeviceCopy the current immutable object by setting a value for thesetattribute.final ImmutableDMIMemoryDeviceCopy the current immutable object by setting a value for thesizeattribute.final ImmutableDMIMemoryDeviceCopy the current immutable object by setting a value for thespeedattribute.final ImmutableDMIMemoryDevicewithTotalWidth(@Nullable String value) Copy the current immutable object by setting a value for thetotalWidthattribute.final ImmutableDMIMemoryDeviceCopy the current immutable object by setting a value for thetypeattribute.final ImmutableDMIMemoryDevicewithTypeDetail(@Nullable String value) Copy the current immutable object by setting a value for thetypeDetailattribute.final ImmutableDMIMemoryDevicewithVolatileSize(@Nullable String value) Copy the current immutable object by setting a value for thevolatileSizeattribute.Methods inherited from class io.github.eggy03.dmidecode.entity.memory.DMIMemoryDevice
toJson
-
Field Details
-
arrayHandle
-
errorInformationHandle
-
totalWidth
-
dataWidth
-
size
-
formFactor
-
set
-
locator
-
bankLocator
-
type
-
typeDetail
-
speed
-
manufacturer
-
serialNumber
-
assetTag
-
partNumber
-
rank
-
configuredMemorySpeed
-
minimumVoltage
-
maximumVoltage
-
configuredVoltage
-
memoryTechnology
-
memoryOperatingModeCapability
-
firmwareVersion
-
moduleManufacturerId
-
moduleProductId
-
memorySubsystemControllerManufacturerId
-
memorySubsystemControllerProductId
-
nonVolatileSize
-
volatileSize
-
cacheSize
-
logicalSize
-
-
Constructor Details
-
ImmutableDMIMemoryDevice
private ImmutableDMIMemoryDevice(@Nullable String arrayHandle, @Nullable String errorInformationHandle, @Nullable String totalWidth, @Nullable String dataWidth, @Nullable String size, @Nullable String formFactor, @Nullable String set, @Nullable String locator, @Nullable String bankLocator, @Nullable String type, @Nullable String typeDetail, @Nullable String speed, @Nullable String manufacturer, @Nullable String serialNumber, @Nullable String assetTag, @Nullable String partNumber, @Nullable Integer rank, @Nullable String configuredMemorySpeed, @Nullable String minimumVoltage, @Nullable String maximumVoltage, @Nullable String configuredVoltage, @Nullable String memoryTechnology, @Nullable String memoryOperatingModeCapability, @Nullable String firmwareVersion, @Nullable String moduleManufacturerId, @Nullable String moduleProductId, @Nullable String memorySubsystemControllerManufacturerId, @Nullable String memorySubsystemControllerProductId, @Nullable String nonVolatileSize, @Nullable String volatileSize, @Nullable String cacheSize, @Nullable String logicalSize)
-
-
Method Details
-
arrayHandle
- Specified by:
arrayHandlein classDMIMemoryDevice- Returns:
- The value of the
arrayHandleattribute
-
errorInformationHandle
- Specified by:
errorInformationHandlein classDMIMemoryDevice- Returns:
- The value of the
errorInformationHandleattribute
-
totalWidth
- Specified by:
totalWidthin classDMIMemoryDevice- Returns:
- The value of the
totalWidthattribute
-
dataWidth
- Specified by:
dataWidthin classDMIMemoryDevice- Returns:
- The value of the
dataWidthattribute
-
size
- Specified by:
sizein classDMIMemoryDevice- Returns:
- The value of the
sizeattribute
-
formFactor
- Specified by:
formFactorin classDMIMemoryDevice- Returns:
- The value of the
formFactorattribute
-
set
- Specified by:
setin classDMIMemoryDevice- Returns:
- The value of the
setattribute
-
locator
- Specified by:
locatorin classDMIMemoryDevice- Returns:
- The value of the
locatorattribute
-
bankLocator
- Specified by:
bankLocatorin classDMIMemoryDevice- Returns:
- The value of the
bankLocatorattribute
-
type
- Specified by:
typein classDMIMemoryDevice- Returns:
- The value of the
typeattribute
-
typeDetail
- Specified by:
typeDetailin classDMIMemoryDevice- Returns:
- The value of the
typeDetailattribute
-
speed
- Specified by:
speedin classDMIMemoryDevice- Returns:
- The value of the
speedattribute
-
manufacturer
- Specified by:
manufacturerin classDMIMemoryDevice- Returns:
- The value of the
manufacturerattribute
-
serialNumber
- Specified by:
serialNumberin classDMIMemoryDevice- Returns:
- The value of the
serialNumberattribute
-
assetTag
- Specified by:
assetTagin classDMIMemoryDevice- Returns:
- The value of the
assetTagattribute
-
partNumber
- Specified by:
partNumberin classDMIMemoryDevice- Returns:
- The value of the
partNumberattribute
-
rank
- Specified by:
rankin classDMIMemoryDevice- Returns:
- The value of the
rankattribute
-
configuredMemorySpeed
- Specified by:
configuredMemorySpeedin classDMIMemoryDevice- Returns:
- The value of the
configuredMemorySpeedattribute
-
minimumVoltage
- Specified by:
minimumVoltagein classDMIMemoryDevice- Returns:
- The value of the
minimumVoltageattribute
-
maximumVoltage
- Specified by:
maximumVoltagein classDMIMemoryDevice- Returns:
- The value of the
maximumVoltageattribute
-
configuredVoltage
- Specified by:
configuredVoltagein classDMIMemoryDevice- Returns:
- The value of the
configuredVoltageattribute
-
memoryTechnology
- Specified by:
memoryTechnologyin classDMIMemoryDevice- Returns:
- The value of the
memoryTechnologyattribute
-
memoryOperatingModeCapability
- Specified by:
memoryOperatingModeCapabilityin classDMIMemoryDevice- Returns:
- The value of the
memoryOperatingModeCapabilityattribute
-
firmwareVersion
- Specified by:
firmwareVersionin classDMIMemoryDevice- Returns:
- The value of the
firmwareVersionattribute
-
moduleManufacturerId
- Specified by:
moduleManufacturerIdin classDMIMemoryDevice- Returns:
- The value of the
moduleManufacturerIdattribute
-
moduleProductId
- Specified by:
moduleProductIdin classDMIMemoryDevice- Returns:
- The value of the
moduleProductIdattribute
-
memorySubsystemControllerManufacturerId
- Specified by:
memorySubsystemControllerManufacturerIdin classDMIMemoryDevice- Returns:
- The value of the
memorySubsystemControllerManufacturerIdattribute
-
memorySubsystemControllerProductId
- Specified by:
memorySubsystemControllerProductIdin classDMIMemoryDevice- Returns:
- The value of the
memorySubsystemControllerProductIdattribute
-
nonVolatileSize
- Specified by:
nonVolatileSizein classDMIMemoryDevice- Returns:
- The value of the
nonVolatileSizeattribute
-
volatileSize
- Specified by:
volatileSizein classDMIMemoryDevice- Returns:
- The value of the
volatileSizeattribute
-
cacheSize
- Specified by:
cacheSizein classDMIMemoryDevice- Returns:
- The value of the
cacheSizeattribute
-
logicalSize
- Specified by:
logicalSizein classDMIMemoryDevice- Returns:
- The value of the
logicalSizeattribute
-
withArrayHandle
Copy the current immutable object by setting a value for thearrayHandleattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for arrayHandle (can benull)- Returns:
- A modified copy or the
thisobject
-
withErrorInformationHandle
Copy the current immutable object by setting a value for theerrorInformationHandleattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for errorInformationHandle (can benull)- Returns:
- A modified copy or the
thisobject
-
withTotalWidth
Copy the current immutable object by setting a value for thetotalWidthattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for totalWidth (can benull)- Returns:
- A modified copy or the
thisobject
-
withDataWidth
Copy the current immutable object by setting a value for thedataWidthattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for dataWidth (can benull)- Returns:
- A modified copy or the
thisobject
-
withSize
Copy the current immutable object by setting a value for thesizeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for size (can benull)- Returns:
- A modified copy or the
thisobject
-
withFormFactor
Copy the current immutable object by setting a value for theformFactorattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for formFactor (can benull)- Returns:
- A modified copy or the
thisobject
-
withSet
Copy the current immutable object by setting a value for thesetattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for set (can benull)- Returns:
- A modified copy or the
thisobject
-
withLocator
Copy the current immutable object by setting a value for thelocatorattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for locator (can benull)- Returns:
- A modified copy or the
thisobject
-
withBankLocator
Copy the current immutable object by setting a value for thebankLocatorattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for bankLocator (can benull)- Returns:
- A modified copy or the
thisobject
-
withType
Copy the current immutable object by setting a value for thetypeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for type (can benull)- Returns:
- A modified copy or the
thisobject
-
withTypeDetail
Copy the current immutable object by setting a value for thetypeDetailattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for typeDetail (can benull)- Returns:
- A modified copy or the
thisobject
-
withSpeed
Copy the current immutable object by setting a value for thespeedattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for speed (can benull)- Returns:
- A modified copy or the
thisobject
-
withManufacturer
Copy the current immutable object by setting a value for themanufacturerattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for manufacturer (can benull)- Returns:
- A modified copy or the
thisobject
-
withSerialNumber
Copy the current immutable object by setting a value for theserialNumberattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for serialNumber (can benull)- Returns:
- A modified copy or the
thisobject
-
withAssetTag
Copy the current immutable object by setting a value for theassetTagattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for assetTag (can benull)- Returns:
- A modified copy or the
thisobject
-
withPartNumber
Copy the current immutable object by setting a value for thepartNumberattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for partNumber (can benull)- Returns:
- A modified copy or the
thisobject
-
withRank
Copy the current immutable object by setting a value for therankattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for rank (can benull)- Returns:
- A modified copy or the
thisobject
-
withConfiguredMemorySpeed
Copy the current immutable object by setting a value for theconfiguredMemorySpeedattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for configuredMemorySpeed (can benull)- Returns:
- A modified copy or the
thisobject
-
withMinimumVoltage
Copy the current immutable object by setting a value for theminimumVoltageattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for minimumVoltage (can benull)- Returns:
- A modified copy or the
thisobject
-
withMaximumVoltage
Copy the current immutable object by setting a value for themaximumVoltageattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for maximumVoltage (can benull)- Returns:
- A modified copy or the
thisobject
-
withConfiguredVoltage
Copy the current immutable object by setting a value for theconfiguredVoltageattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for configuredVoltage (can benull)- Returns:
- A modified copy or the
thisobject
-
withMemoryTechnology
Copy the current immutable object by setting a value for thememoryTechnologyattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for memoryTechnology (can benull)- Returns:
- A modified copy or the
thisobject
-
withMemoryOperatingModeCapability
Copy the current immutable object by setting a value for thememoryOperatingModeCapabilityattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for memoryOperatingModeCapability (can benull)- Returns:
- A modified copy or the
thisobject
-
withFirmwareVersion
Copy the current immutable object by setting a value for thefirmwareVersionattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for firmwareVersion (can benull)- Returns:
- A modified copy or the
thisobject
-
withModuleManufacturerId
Copy the current immutable object by setting a value for themoduleManufacturerIdattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for moduleManufacturerId (can benull)- Returns:
- A modified copy or the
thisobject
-
withModuleProductId
Copy the current immutable object by setting a value for themoduleProductIdattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for moduleProductId (can benull)- Returns:
- A modified copy or the
thisobject
-
withMemorySubsystemControllerManufacturerId
public final ImmutableDMIMemoryDevice withMemorySubsystemControllerManufacturerId(@Nullable String value) Copy the current immutable object by setting a value for thememorySubsystemControllerManufacturerIdattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for memorySubsystemControllerManufacturerId (can benull)- Returns:
- A modified copy or the
thisobject
-
withMemorySubsystemControllerProductId
public final ImmutableDMIMemoryDevice withMemorySubsystemControllerProductId(@Nullable String value) Copy the current immutable object by setting a value for thememorySubsystemControllerProductIdattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for memorySubsystemControllerProductId (can benull)- Returns:
- A modified copy or the
thisobject
-
withNonVolatileSize
Copy the current immutable object by setting a value for thenonVolatileSizeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for nonVolatileSize (can benull)- Returns:
- A modified copy or the
thisobject
-
withVolatileSize
Copy the current immutable object by setting a value for thevolatileSizeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for volatileSize (can benull)- Returns:
- A modified copy or the
thisobject
-
withCacheSize
Copy the current immutable object by setting a value for thecacheSizeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for cacheSize (can benull)- Returns:
- A modified copy or the
thisobject
-
withLogicalSize
Copy the current immutable object by setting a value for thelogicalSizeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for logicalSize (can benull)- Returns:
- A modified copy or the
thisobject
-
equals
This instance is equal to all instances ofImmutableDMIMemoryDevicethat have equal attribute values. -
equalsByValue
-
hashCode
public int hashCode()Computes a hash code from attributes:arrayHandle,errorInformationHandle,totalWidth,dataWidth,size,formFactor,set,locator,bankLocator,type,typeDetail,speed,manufacturer,serialNumber,assetTag,partNumber,rank,configuredMemorySpeed,minimumVoltage,maximumVoltage,configuredVoltage,memoryTechnology,memoryOperatingModeCapability,firmwareVersion,moduleManufacturerId,moduleProductId,memorySubsystemControllerManufacturerId,memorySubsystemControllerProductId,nonVolatileSize,volatileSize,cacheSize,logicalSize. -
toString
Prints the immutable valueDMIMemoryDevicewith attribute values. -
fromJson
Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructure- Parameters:
json- A JSON-bindable data structure- Returns:
- An immutable value type
-
copyOf
Creates an immutable copy of aDMIMemoryDevicevalue. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.- Parameters:
instance- The instance to copy- Returns:
- A copied immutable DMIMemoryDevice instance
-