Class ImmutableDMIMemoryDevice.Builder
java.lang.Object
io.github.eggy03.dmidecode.entity.memory.ImmutableDMIMemoryDevice.Builder
- Enclosing class:
ImmutableDMIMemoryDevice
@Generated(from="DMIMemoryDevice",
generator="Immutables")
public static final class ImmutableDMIMemoryDevice.Builder
extends Object
Builds instances of type
ImmutableDMIMemoryDevice.
Initialize attributes and then invoke the build() method to create an
immutable instance.
Builder is not thread-safe and generally should not be stored in a field or collection,
but instead used immediately to create instances.
-
Field Summary
FieldsModifier and TypeFieldDescriptionprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Integerprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable String -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionarrayHandle(@Nullable String arrayHandle) Initializes the value for thearrayHandleattribute.Initializes the value for theassetTagattribute.bankLocator(@Nullable String bankLocator) Initializes the value for thebankLocatorattribute.build()Builds a newImmutableDMIMemoryDevice.Initializes the value for thecacheSizeattribute.configuredMemorySpeed(@Nullable String configuredMemorySpeed) Initializes the value for theconfiguredMemorySpeedattribute.configuredVoltage(@Nullable String configuredVoltage) Initializes the value for theconfiguredVoltageattribute.Initializes the value for thedataWidthattribute.errorInformationHandle(@Nullable String errorInformationHandle) Initializes the value for theerrorInformationHandleattribute.firmwareVersion(@Nullable String firmwareVersion) Initializes the value for thefirmwareVersionattribute.formFactor(@Nullable String formFactor) Initializes the value for theformFactorattribute.from(DMIMemoryDevice instance) Fill a builder with attribute values from the providedDMIMemoryDeviceinstance.Initializes the value for thelocatorattribute.logicalSize(@Nullable String logicalSize) Initializes the value for thelogicalSizeattribute.manufacturer(@Nullable String manufacturer) Initializes the value for themanufacturerattribute.maximumVoltage(@Nullable String maximumVoltage) Initializes the value for themaximumVoltageattribute.memoryOperatingModeCapability(@Nullable String memoryOperatingModeCapability) Initializes the value for thememoryOperatingModeCapabilityattribute.memorySubsystemControllerManufacturerId(@Nullable String memorySubsystemControllerManufacturerId) Initializes the value for thememorySubsystemControllerManufacturerIdattribute.memorySubsystemControllerProductId(@Nullable String memorySubsystemControllerProductId) Initializes the value for thememorySubsystemControllerProductIdattribute.memoryTechnology(@Nullable String memoryTechnology) Initializes the value for thememoryTechnologyattribute.minimumVoltage(@Nullable String minimumVoltage) Initializes the value for theminimumVoltageattribute.moduleManufacturerId(@Nullable String moduleManufacturerId) Initializes the value for themoduleManufacturerIdattribute.moduleProductId(@Nullable String moduleProductId) Initializes the value for themoduleProductIdattribute.nonVolatileSize(@Nullable String nonVolatileSize) Initializes the value for thenonVolatileSizeattribute.partNumber(@Nullable String partNumber) Initializes the value for thepartNumberattribute.Initializes the value for therankattribute.serialNumber(@Nullable String serialNumber) Initializes the value for theserialNumberattribute.Initializes the value for thesetattribute.Initializes the value for thesizeattribute.Initializes the value for thespeedattribute.totalWidth(@Nullable String totalWidth) Initializes the value for thetotalWidthattribute.Initializes the value for thetypeattribute.typeDetail(@Nullable String typeDetail) Initializes the value for thetypeDetailattribute.volatileSize(@Nullable String volatileSize) Initializes the value for thevolatileSizeattribute.
-
Field Details
-
arrayHandle
-
errorInformationHandle
-
totalWidth
-
dataWidth
-
size
-
formFactor
-
set
-
locator
-
bankLocator
-
type
-
typeDetail
-
speed
-
manufacturer
-
serialNumber
-
assetTag
-
partNumber
-
rank
-
configuredMemorySpeed
-
minimumVoltage
-
maximumVoltage
-
configuredVoltage
-
memoryTechnology
-
memoryOperatingModeCapability
-
firmwareVersion
-
moduleManufacturerId
-
moduleProductId
-
memorySubsystemControllerManufacturerId
-
memorySubsystemControllerProductId
-
nonVolatileSize
-
volatileSize
-
cacheSize
-
logicalSize
-
-
Constructor Details
-
Builder
public Builder()Creates a builder forImmutableDMIMemoryDeviceinstances.new ImmutableDMIMemoryDevice.Builder() .arrayHandle(String | null) // nullablearrayHandle.errorInformationHandle(String | null) // nullableerrorInformationHandle.totalWidth(String | null) // nullabletotalWidth.dataWidth(String | null) // nullabledataWidth.size(String | null) // nullablesize.formFactor(String | null) // nullableformFactor.set(String | null) // nullableset.locator(String | null) // nullablelocator.bankLocator(String | null) // nullablebankLocator.type(String | null) // nullabletype.typeDetail(String | null) // nullabletypeDetail.speed(String | null) // nullablespeed.manufacturer(String | null) // nullablemanufacturer.serialNumber(String | null) // nullableserialNumber.assetTag(String | null) // nullableassetTag.partNumber(String | null) // nullablepartNumber.rank(Integer | null) // nullablerank.configuredMemorySpeed(String | null) // nullableconfiguredMemorySpeed.minimumVoltage(String | null) // nullableminimumVoltage.maximumVoltage(String | null) // nullablemaximumVoltage.configuredVoltage(String | null) // nullableconfiguredVoltage.memoryTechnology(String | null) // nullablememoryTechnology.memoryOperatingModeCapability(String | null) // nullablememoryOperatingModeCapability.firmwareVersion(String | null) // nullablefirmwareVersion.moduleManufacturerId(String | null) // nullablemoduleManufacturerId.moduleProductId(String | null) // nullablemoduleProductId.memorySubsystemControllerManufacturerId(String | null) // nullablememorySubsystemControllerManufacturerId.memorySubsystemControllerProductId(String | null) // nullablememorySubsystemControllerProductId.nonVolatileSize(String | null) // nullablenonVolatileSize.volatileSize(String | null) // nullablevolatileSize.cacheSize(String | null) // nullablecacheSize.logicalSize(String | null) // nullablelogicalSize.build();
-
-
Method Details
-
from
Fill a builder with attribute values from the providedDMIMemoryDeviceinstance. Regular attribute values will be replaced with those from the given instance. Absent optional values will not replace present values.- Parameters:
instance- The instance from which to copy values- Returns:
thisbuilder for use in a chained invocation
-
arrayHandle
Initializes the value for thearrayHandleattribute.- Parameters:
arrayHandle- The value for arrayHandle (can benull)- Returns:
thisbuilder for use in a chained invocation
-
errorInformationHandle
public final ImmutableDMIMemoryDevice.Builder errorInformationHandle(@Nullable String errorInformationHandle) Initializes the value for theerrorInformationHandleattribute.- Parameters:
errorInformationHandle- The value for errorInformationHandle (can benull)- Returns:
thisbuilder for use in a chained invocation
-
totalWidth
Initializes the value for thetotalWidthattribute.- Parameters:
totalWidth- The value for totalWidth (can benull)- Returns:
thisbuilder for use in a chained invocation
-
dataWidth
Initializes the value for thedataWidthattribute.- Parameters:
dataWidth- The value for dataWidth (can benull)- Returns:
thisbuilder for use in a chained invocation
-
size
Initializes the value for thesizeattribute.- Parameters:
size- The value for size (can benull)- Returns:
thisbuilder for use in a chained invocation
-
formFactor
Initializes the value for theformFactorattribute.- Parameters:
formFactor- The value for formFactor (can benull)- Returns:
thisbuilder for use in a chained invocation
-
set
Initializes the value for thesetattribute.- Parameters:
set- The value for set (can benull)- Returns:
thisbuilder for use in a chained invocation
-
locator
Initializes the value for thelocatorattribute.- Parameters:
locator- The value for locator (can benull)- Returns:
thisbuilder for use in a chained invocation
-
bankLocator
Initializes the value for thebankLocatorattribute.- Parameters:
bankLocator- The value for bankLocator (can benull)- Returns:
thisbuilder for use in a chained invocation
-
type
Initializes the value for thetypeattribute.- Parameters:
type- The value for type (can benull)- Returns:
thisbuilder for use in a chained invocation
-
typeDetail
Initializes the value for thetypeDetailattribute.- Parameters:
typeDetail- The value for typeDetail (can benull)- Returns:
thisbuilder for use in a chained invocation
-
speed
Initializes the value for thespeedattribute.- Parameters:
speed- The value for speed (can benull)- Returns:
thisbuilder for use in a chained invocation
-
manufacturer
Initializes the value for themanufacturerattribute.- Parameters:
manufacturer- The value for manufacturer (can benull)- Returns:
thisbuilder for use in a chained invocation
-
serialNumber
Initializes the value for theserialNumberattribute.- Parameters:
serialNumber- The value for serialNumber (can benull)- Returns:
thisbuilder for use in a chained invocation
-
assetTag
Initializes the value for theassetTagattribute.- Parameters:
assetTag- The value for assetTag (can benull)- Returns:
thisbuilder for use in a chained invocation
-
partNumber
Initializes the value for thepartNumberattribute.- Parameters:
partNumber- The value for partNumber (can benull)- Returns:
thisbuilder for use in a chained invocation
-
rank
Initializes the value for therankattribute.- Parameters:
rank- The value for rank (can benull)- Returns:
thisbuilder for use in a chained invocation
-
configuredMemorySpeed
public final ImmutableDMIMemoryDevice.Builder configuredMemorySpeed(@Nullable String configuredMemorySpeed) Initializes the value for theconfiguredMemorySpeedattribute.- Parameters:
configuredMemorySpeed- The value for configuredMemorySpeed (can benull)- Returns:
thisbuilder for use in a chained invocation
-
minimumVoltage
Initializes the value for theminimumVoltageattribute.- Parameters:
minimumVoltage- The value for minimumVoltage (can benull)- Returns:
thisbuilder for use in a chained invocation
-
maximumVoltage
Initializes the value for themaximumVoltageattribute.- Parameters:
maximumVoltage- The value for maximumVoltage (can benull)- Returns:
thisbuilder for use in a chained invocation
-
configuredVoltage
Initializes the value for theconfiguredVoltageattribute.- Parameters:
configuredVoltage- The value for configuredVoltage (can benull)- Returns:
thisbuilder for use in a chained invocation
-
memoryTechnology
Initializes the value for thememoryTechnologyattribute.- Parameters:
memoryTechnology- The value for memoryTechnology (can benull)- Returns:
thisbuilder for use in a chained invocation
-
memoryOperatingModeCapability
public final ImmutableDMIMemoryDevice.Builder memoryOperatingModeCapability(@Nullable String memoryOperatingModeCapability) Initializes the value for thememoryOperatingModeCapabilityattribute.- Parameters:
memoryOperatingModeCapability- The value for memoryOperatingModeCapability (can benull)- Returns:
thisbuilder for use in a chained invocation
-
firmwareVersion
Initializes the value for thefirmwareVersionattribute.- Parameters:
firmwareVersion- The value for firmwareVersion (can benull)- Returns:
thisbuilder for use in a chained invocation
-
moduleManufacturerId
public final ImmutableDMIMemoryDevice.Builder moduleManufacturerId(@Nullable String moduleManufacturerId) Initializes the value for themoduleManufacturerIdattribute.- Parameters:
moduleManufacturerId- The value for moduleManufacturerId (can benull)- Returns:
thisbuilder for use in a chained invocation
-
moduleProductId
Initializes the value for themoduleProductIdattribute.- Parameters:
moduleProductId- The value for moduleProductId (can benull)- Returns:
thisbuilder for use in a chained invocation
-
memorySubsystemControllerManufacturerId
public final ImmutableDMIMemoryDevice.Builder memorySubsystemControllerManufacturerId(@Nullable String memorySubsystemControllerManufacturerId) Initializes the value for thememorySubsystemControllerManufacturerIdattribute.- Parameters:
memorySubsystemControllerManufacturerId- The value for memorySubsystemControllerManufacturerId (can benull)- Returns:
thisbuilder for use in a chained invocation
-
memorySubsystemControllerProductId
public final ImmutableDMIMemoryDevice.Builder memorySubsystemControllerProductId(@Nullable String memorySubsystemControllerProductId) Initializes the value for thememorySubsystemControllerProductIdattribute.- Parameters:
memorySubsystemControllerProductId- The value for memorySubsystemControllerProductId (can benull)- Returns:
thisbuilder for use in a chained invocation
-
nonVolatileSize
Initializes the value for thenonVolatileSizeattribute.- Parameters:
nonVolatileSize- The value for nonVolatileSize (can benull)- Returns:
thisbuilder for use in a chained invocation
-
volatileSize
Initializes the value for thevolatileSizeattribute.- Parameters:
volatileSize- The value for volatileSize (can benull)- Returns:
thisbuilder for use in a chained invocation
-
cacheSize
Initializes the value for thecacheSizeattribute.- Parameters:
cacheSize- The value for cacheSize (can benull)- Returns:
thisbuilder for use in a chained invocation
-
logicalSize
Initializes the value for thelogicalSizeattribute.- Parameters:
logicalSize- The value for logicalSize (can benull)- Returns:
thisbuilder for use in a chained invocation
-
build
Builds a newImmutableDMIMemoryDevice.- Returns:
- An immutable instance of DMIMemoryDevice
- Throws:
IllegalStateException- if any required attributes are missing
-