Class ImmutableDMIPhysicalMemoryArray.Builder
java.lang.Object
io.github.eggy03.dmidecode.entity.memory.ImmutableDMIPhysicalMemoryArray.Builder
- Enclosing class:
ImmutableDMIPhysicalMemoryArray
@Generated(from="DMIPhysicalMemoryArray",
generator="Immutables")
public static final class ImmutableDMIPhysicalMemoryArray.Builder
extends Object
Builds instances of type
ImmutableDMIPhysicalMemoryArray.
Initialize attributes and then invoke the build() method to create an
immutable instance.
Builder is not thread-safe and generally should not be stored in a field or collection,
but instead used immediately to create instances.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Builds a newImmutableDMIPhysicalMemoryArray.errorCorrectionType(@Nullable String errorCorrectionType) Initializes the value for theerrorCorrectionTypeattribute.errorInformationHandle(@Nullable String errorInformationHandle) Initializes the value for theerrorInformationHandleattribute.from(DMIPhysicalMemoryArray instance) Fill a builder with attribute values from the providedDMIPhysicalMemoryArrayinstance.Initializes the value for thelocationattribute.maximumCapacity(@Nullable String maximumCapacity) Initializes the value for themaximumCapacityattribute.numberOfDevices(@Nullable Integer numberOfDevices) Initializes the value for thenumberOfDevicesattribute.Initializes the value for theuseattribute.
-
Field Details
-
location
-
use
-
errorCorrectionType
-
maximumCapacity
-
errorInformationHandle
-
numberOfDevices
-
-
Constructor Details
-
Builder
public Builder()Creates a builder forImmutableDMIPhysicalMemoryArrayinstances.new ImmutableDMIPhysicalMemoryArray.Builder() .location(String | null) // nullablelocation.use(String | null) // nullableuse.errorCorrectionType(String | null) // nullableerrorCorrectionType.maximumCapacity(String | null) // nullablemaximumCapacity.errorInformationHandle(String | null) // nullableerrorInformationHandle.numberOfDevices(Integer | null) // nullablenumberOfDevices.build();
-
-
Method Details
-
from
Fill a builder with attribute values from the providedDMIPhysicalMemoryArrayinstance. Regular attribute values will be replaced with those from the given instance. Absent optional values will not replace present values.- Parameters:
instance- The instance from which to copy values- Returns:
thisbuilder for use in a chained invocation
-
location
Initializes the value for thelocationattribute.- Parameters:
location- The value for location (can benull)- Returns:
thisbuilder for use in a chained invocation
-
use
Initializes the value for theuseattribute.- Parameters:
use- The value for use (can benull)- Returns:
thisbuilder for use in a chained invocation
-
errorCorrectionType
public final ImmutableDMIPhysicalMemoryArray.Builder errorCorrectionType(@Nullable String errorCorrectionType) Initializes the value for theerrorCorrectionTypeattribute.- Parameters:
errorCorrectionType- The value for errorCorrectionType (can benull)- Returns:
thisbuilder for use in a chained invocation
-
maximumCapacity
public final ImmutableDMIPhysicalMemoryArray.Builder maximumCapacity(@Nullable String maximumCapacity) Initializes the value for themaximumCapacityattribute.- Parameters:
maximumCapacity- The value for maximumCapacity (can benull)- Returns:
thisbuilder for use in a chained invocation
-
errorInformationHandle
public final ImmutableDMIPhysicalMemoryArray.Builder errorInformationHandle(@Nullable String errorInformationHandle) Initializes the value for theerrorInformationHandleattribute.- Parameters:
errorInformationHandle- The value for errorInformationHandle (can benull)- Returns:
thisbuilder for use in a chained invocation
-
numberOfDevices
public final ImmutableDMIPhysicalMemoryArray.Builder numberOfDevices(@Nullable Integer numberOfDevices) Initializes the value for thenumberOfDevicesattribute.- Parameters:
numberOfDevices- The value for numberOfDevices (can benull)- Returns:
thisbuilder for use in a chained invocation
-
build
Builds a newImmutableDMIPhysicalMemoryArray.- Returns:
- An immutable instance of DMIPhysicalMemoryArray
- Throws:
IllegalStateException- if any required attributes are missing
-