Uses of Class
io.github.eggy03.dmidecode.entity.memory.DMIPhysicalMemoryArray
Packages that use DMIPhysicalMemoryArray
Package
Description
-
Uses of DMIPhysicalMemoryArray in io.github.eggy03.dmidecode.entity.memory
Methods in io.github.eggy03.dmidecode.entity.memory that return DMIPhysicalMemoryArrayModifier and TypeMethodDescriptionDMIPhysicalMemoryArray.Builder.build()Builds a newDMIPhysicalMemoryArray.static DMIPhysicalMemoryArrayDMIPhysicalMemoryArray.copyOf(AbstractDMIPhysicalMemoryArray instance) Creates an immutable copy of aAbstractDMIPhysicalMemoryArrayvalue.(package private) static DMIPhysicalMemoryArrayDMIPhysicalMemoryArray.fromJson(DMIPhysicalMemoryArray.Json json) Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructurefinal DMIPhysicalMemoryArrayDMIPhysicalMemoryArray.withErrorCorrectionType(@Nullable String value) Copy the current immutable object by setting a value for theerrorCorrectionTypeattribute.final DMIPhysicalMemoryArrayDMIPhysicalMemoryArray.withErrorInformationHandle(@Nullable String value) Copy the current immutable object by setting a value for theerrorInformationHandleattribute.final DMIPhysicalMemoryArrayDMIPhysicalMemoryArray.withLocation(@Nullable String value) Copy the current immutable object by setting a value for thelocationattribute.final DMIPhysicalMemoryArrayDMIPhysicalMemoryArray.withMaximumCapacity(@Nullable String value) Copy the current immutable object by setting a value for themaximumCapacityattribute.final DMIPhysicalMemoryArrayDMIPhysicalMemoryArray.withNumberOfDevices(@Nullable Integer value) Copy the current immutable object by setting a value for thenumberOfDevicesattribute.final DMIPhysicalMemoryArrayCopy the current immutable object by setting a value for theuseattribute.Methods in io.github.eggy03.dmidecode.entity.memory with parameters of type DMIPhysicalMemoryArrayModifier and TypeMethodDescriptionprivate booleanDMIPhysicalMemoryArray.equalsByValue(DMIPhysicalMemoryArray another) -
Uses of DMIPhysicalMemoryArray in io.github.eggy03.dmidecode.service.memory
Methods in io.github.eggy03.dmidecode.service.memory that return types with arguments of type DMIPhysicalMemoryArrayModifier and TypeMethodDescription@NonNull Optional<DMIPhysicalMemoryArray> DMIPhysicalMemoryArrayService.get(long timeout) Retrieves physical memory array information present in the system using an isolateddmidecodeprocess with a configurable timeout.