Class AbstractDMIPortableBattery
java.lang.Object
io.github.eggy03.dmidecode.entity.peripheral.AbstractDMIPortableBattery
- Direct Known Subclasses:
DMIPortableBattery,DMIPortableBattery.Json
Immutable representation of portable battery information retrieved via DMI.
Fields correspond to properties reported by dmidecode for the Portable
Battery (Type 22) SMBIOS structure.
Instances of this class are thread-safe.
Usage example
DMIPortableBattery battery = new DMIPortableBattery.Builder()
.location("Internal Battery")
.manufacturer("LG")
.designCapacity("50000 mWh")
.designVoltage("11.4 V")
.build();
// Create a modified copy
DMIPortableBattery updated = battery
.withMaximumError("2%");
- Since:
- 0.2.0
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringlocation()abstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringname()abstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable StringtoString()