Class AbstractDMICache
java.lang.Object
io.github.eggy03.dmidecode.entity.processor.AbstractDMICache
- Direct Known Subclasses:
DMICache,DMICache.Json
Immutable representation of processor cache information retrieved via DMI.
Fields correspond to properties reported by dmidecode for the Cache
Information (Type 7) SMBIOS structure.
Instances of this class are thread-safe.
Usage example
DMICache cache = new DMICache.Builder()
.socketDesignation("L3-Cache")
.location("Internal")
.installedSize("32 MB")
.associativity("16-way Set-Associative")
.build();
// Create a modified copy
DMICache updated = cache
.withInstalledSize("64 MB");
- Since:
- 0.2.0
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringlocation()abstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringabstract @Nullable Stringspeed()abstract @Nullable StringtoString()