Class DMIProcessor
java.lang.Object
io.github.eggy03.dmidecode.entity.processor.AbstractDMIProcessor
io.github.eggy03.dmidecode.entity.processor.DMIProcessor
@Generated(from="AbstractDMIProcessor",
generator="Immutables")
@Generated("org.immutables.processor.ProxyProcessor")
public final class DMIProcessor
extends AbstractDMIProcessor
Immutable representation of processor information retrieved via DMI.
Fields correspond to properties reported by dmidecode for the Processor
Information (Type 4) SMBIOS structure.
Instances of this class are thread-safe.
Usage example
DMIProcessor processor = new DMIProcessor.Builder()
.socketDesignation("CPU0")
.manufacturer("Intel")
.version("Intel(R) Core(TM) i7-12700H")
.coreCount(14)
.threadCount(20)
.currentSpeed("2700 MHz")
.build();
// Create a modified copy
DMIProcessor updated = processor
.withCurrentSpeed("3900 MHz");
- Since:
- 0.2.0
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classBuilds instances of typeDMIProcessor.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure -
Field Summary
FieldsModifier and TypeFieldDescriptionprivate final @Nullable Stringprivate final @Nullable Integerprivate final @Nullable Integerprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Integerprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable String -
Constructor Summary
ConstructorsModifierConstructorDescriptionprivateDMIProcessor(@Nullable String socketDesignation, @Nullable String type, @Nullable String family, @Nullable String manufacturer, @Nullable String id, @Nullable String signature, @Nullable List<String> flags, @Nullable String version, @Nullable String voltage, @Nullable String externalClock, @Nullable String maxSpeed, @Nullable String currentSpeed, @Nullable String status, @Nullable String upgrade, @Nullable String l1CacheHandle, @Nullable String l2CacheHandle, @Nullable String l3CacheHandle, @Nullable String serialNumber, @Nullable String assetTag, @Nullable String partNumber, @Nullable Integer coreCount, @Nullable Integer coreEnabled, @Nullable Integer threadCount, @Nullable List<String> characteristics) -
Method Summary
Modifier and TypeMethodDescription@Nullable StringassetTag()static DMIProcessorcopyOf(AbstractDMIProcessor instance) Creates an immutable copy of aAbstractDMIProcessorvalue.@Nullable Integer@Nullable Integerprivate static <T> List<T> createSafeList(Iterable<? extends T> iterable, boolean checkNulls, boolean skipNulls) private static <T> List<T> createUnmodifiableList(boolean clone, List<? extends T> list) @Nullable StringbooleanThis instance is equal to all instances ofDMIProcessorthat have equal attribute values.private booleanequalsByValue(DMIProcessor another) @Nullable String@Nullable Stringfamily()flags()(package private) static DMIProcessorfromJson(DMIProcessor.Json json) Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructureinthashCode()Computes a hash code from attributes:socketDesignation,type,family,manufacturer,id,signature,flags,version,voltage,externalClock,maxSpeed,currentSpeed,status,upgrade,l1CacheHandle,l2CacheHandle,l3CacheHandle,serialNumber,assetTag,partNumber,coreCount,coreEnabled,threadCount,characteristics.@Nullable Stringid()@Nullable String@Nullable String@Nullable String@Nullable String@Nullable StringmaxSpeed()@Nullable String@Nullable String@Nullable String@Nullable String@Nullable Stringstatus()@Nullable Integer@Nullable Stringtype()@Nullable Stringupgrade()@Nullable Stringversion()@Nullable Stringvoltage()final DMIProcessorwithAssetTag(@Nullable String value) Copy the current immutable object by setting a value for theassetTagattribute.final DMIProcessorwithCharacteristics(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofcharacteristics.final DMIProcessorwithCharacteristics(@Nullable String @Nullable ... elements) Copy the current immutable object with elements that replace the content ofcharacteristics.final DMIProcessorwithCoreCount(@Nullable Integer value) Copy the current immutable object by setting a value for thecoreCountattribute.final DMIProcessorwithCoreEnabled(@Nullable Integer value) Copy the current immutable object by setting a value for thecoreEnabledattribute.final DMIProcessorwithCurrentSpeed(@Nullable String value) Copy the current immutable object by setting a value for thecurrentSpeedattribute.final DMIProcessorwithExternalClock(@Nullable String value) Copy the current immutable object by setting a value for theexternalClockattribute.final DMIProcessorwithFamily(@Nullable String value) Copy the current immutable object by setting a value for thefamilyattribute.final DMIProcessorCopy the current immutable object with elements that replace the content offlags.final DMIProcessorCopy the current immutable object with elements that replace the content offlags.final DMIProcessorCopy the current immutable object by setting a value for theidattribute.final DMIProcessorwithL1CacheHandle(@Nullable String value) Copy the current immutable object by setting a value for thel1CacheHandleattribute.final DMIProcessorwithL2CacheHandle(@Nullable String value) Copy the current immutable object by setting a value for thel2CacheHandleattribute.final DMIProcessorwithL3CacheHandle(@Nullable String value) Copy the current immutable object by setting a value for thel3CacheHandleattribute.final DMIProcessorwithManufacturer(@Nullable String value) Copy the current immutable object by setting a value for themanufacturerattribute.final DMIProcessorwithMaxSpeed(@Nullable String value) Copy the current immutable object by setting a value for themaxSpeedattribute.final DMIProcessorwithPartNumber(@Nullable String value) Copy the current immutable object by setting a value for thepartNumberattribute.final DMIProcessorwithSerialNumber(@Nullable String value) Copy the current immutable object by setting a value for theserialNumberattribute.final DMIProcessorwithSignature(@Nullable String value) Copy the current immutable object by setting a value for thesignatureattribute.final DMIProcessorwithSocketDesignation(@Nullable String value) Copy the current immutable object by setting a value for thesocketDesignationattribute.final DMIProcessorwithStatus(@Nullable String value) Copy the current immutable object by setting a value for thestatusattribute.final DMIProcessorwithThreadCount(@Nullable Integer value) Copy the current immutable object by setting a value for thethreadCountattribute.final DMIProcessorCopy the current immutable object by setting a value for thetypeattribute.final DMIProcessorwithUpgrade(@Nullable String value) Copy the current immutable object by setting a value for theupgradeattribute.final DMIProcessorwithVersion(@Nullable String value) Copy the current immutable object by setting a value for theversionattribute.final DMIProcessorwithVoltage(@Nullable String value) Copy the current immutable object by setting a value for thevoltageattribute.Methods inherited from class io.github.eggy03.dmidecode.entity.processor.AbstractDMIProcessor
toString
-
Field Details
-
socketDesignation
-
type
-
family
-
manufacturer
-
id
-
signature
-
flags
-
version
-
voltage
-
externalClock
-
maxSpeed
-
currentSpeed
-
status
-
upgrade
-
l1CacheHandle
-
l2CacheHandle
-
l3CacheHandle
-
serialNumber
-
assetTag
-
partNumber
-
coreCount
-
coreEnabled
-
threadCount
-
characteristics
-
-
Constructor Details
-
DMIProcessor
private DMIProcessor(@Nullable String socketDesignation, @Nullable String type, @Nullable String family, @Nullable String manufacturer, @Nullable String id, @Nullable String signature, @Nullable List<String> flags, @Nullable String version, @Nullable String voltage, @Nullable String externalClock, @Nullable String maxSpeed, @Nullable String currentSpeed, @Nullable String status, @Nullable String upgrade, @Nullable String l1CacheHandle, @Nullable String l2CacheHandle, @Nullable String l3CacheHandle, @Nullable String serialNumber, @Nullable String assetTag, @Nullable String partNumber, @Nullable Integer coreCount, @Nullable Integer coreEnabled, @Nullable Integer threadCount, @Nullable List<String> characteristics)
-
-
Method Details
-
socketDesignation
- Specified by:
socketDesignationin classAbstractDMIProcessor- Returns:
- The value of the
socketDesignationattribute
-
type
- Specified by:
typein classAbstractDMIProcessor- Returns:
- The value of the
typeattribute
-
family
- Specified by:
familyin classAbstractDMIProcessor- Returns:
- The value of the
familyattribute
-
manufacturer
- Specified by:
manufacturerin classAbstractDMIProcessor- Returns:
- The value of the
manufacturerattribute
-
id
- Specified by:
idin classAbstractDMIProcessor- Returns:
- The value of the
idattribute
-
signature
- Specified by:
signaturein classAbstractDMIProcessor- Returns:
- The value of the
signatureattribute
-
flags
- Specified by:
flagsin classAbstractDMIProcessor- Returns:
- The value of the
flagsattribute
-
version
- Specified by:
versionin classAbstractDMIProcessor- Returns:
- The value of the
versionattribute
-
voltage
- Specified by:
voltagein classAbstractDMIProcessor- Returns:
- The value of the
voltageattribute
-
externalClock
- Specified by:
externalClockin classAbstractDMIProcessor- Returns:
- The value of the
externalClockattribute
-
maxSpeed
- Specified by:
maxSpeedin classAbstractDMIProcessor- Returns:
- The value of the
maxSpeedattribute
-
currentSpeed
- Specified by:
currentSpeedin classAbstractDMIProcessor- Returns:
- The value of the
currentSpeedattribute
-
status
- Specified by:
statusin classAbstractDMIProcessor- Returns:
- The value of the
statusattribute
-
upgrade
- Specified by:
upgradein classAbstractDMIProcessor- Returns:
- The value of the
upgradeattribute
-
l1CacheHandle
- Specified by:
l1CacheHandlein classAbstractDMIProcessor- Returns:
- The value of the
l1CacheHandleattribute
-
l2CacheHandle
- Specified by:
l2CacheHandlein classAbstractDMIProcessor- Returns:
- The value of the
l2CacheHandleattribute
-
l3CacheHandle
- Specified by:
l3CacheHandlein classAbstractDMIProcessor- Returns:
- The value of the
l3CacheHandleattribute
-
serialNumber
- Specified by:
serialNumberin classAbstractDMIProcessor- Returns:
- The value of the
serialNumberattribute
-
assetTag
- Specified by:
assetTagin classAbstractDMIProcessor- Returns:
- The value of the
assetTagattribute
-
partNumber
- Specified by:
partNumberin classAbstractDMIProcessor- Returns:
- The value of the
partNumberattribute
-
coreCount
- Specified by:
coreCountin classAbstractDMIProcessor- Returns:
- The value of the
coreCountattribute
-
coreEnabled
- Specified by:
coreEnabledin classAbstractDMIProcessor- Returns:
- The value of the
coreEnabledattribute
-
threadCount
- Specified by:
threadCountin classAbstractDMIProcessor- Returns:
- The value of the
threadCountattribute
-
characteristics
- Specified by:
characteristicsin classAbstractDMIProcessor- Returns:
- The value of the
characteristicsattribute
-
withSocketDesignation
Copy the current immutable object by setting a value for thesocketDesignationattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for socketDesignation (can benull)- Returns:
- A modified copy or the
thisobject
-
withType
Copy the current immutable object by setting a value for thetypeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for type (can benull)- Returns:
- A modified copy or the
thisobject
-
withFamily
Copy the current immutable object by setting a value for thefamilyattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for family (can benull)- Returns:
- A modified copy or the
thisobject
-
withManufacturer
Copy the current immutable object by setting a value for themanufacturerattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for manufacturer (can benull)- Returns:
- A modified copy or the
thisobject
-
withId
Copy the current immutable object by setting a value for theidattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for id (can benull)- Returns:
- A modified copy or the
thisobject
-
withSignature
Copy the current immutable object by setting a value for thesignatureattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for signature (can benull)- Returns:
- A modified copy or the
thisobject
-
withFlags
Copy the current immutable object with elements that replace the content offlags.- Parameters:
elements- The elements to set- Returns:
- A modified copy of
thisobject
-
withFlags
Copy the current immutable object with elements that replace the content offlags. A shallow reference equality check is used to prevent copying of the same value by returningthis.- Parameters:
elements- An iterable of flags elements to set- Returns:
- A modified copy or
thisif not changed
-
withVersion
Copy the current immutable object by setting a value for theversionattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for version (can benull)- Returns:
- A modified copy or the
thisobject
-
withVoltage
Copy the current immutable object by setting a value for thevoltageattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for voltage (can benull)- Returns:
- A modified copy or the
thisobject
-
withExternalClock
Copy the current immutable object by setting a value for theexternalClockattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for externalClock (can benull)- Returns:
- A modified copy or the
thisobject
-
withMaxSpeed
Copy the current immutable object by setting a value for themaxSpeedattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for maxSpeed (can benull)- Returns:
- A modified copy or the
thisobject
-
withCurrentSpeed
Copy the current immutable object by setting a value for thecurrentSpeedattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for currentSpeed (can benull)- Returns:
- A modified copy or the
thisobject
-
withStatus
Copy the current immutable object by setting a value for thestatusattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for status (can benull)- Returns:
- A modified copy or the
thisobject
-
withUpgrade
Copy the current immutable object by setting a value for theupgradeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for upgrade (can benull)- Returns:
- A modified copy or the
thisobject
-
withL1CacheHandle
Copy the current immutable object by setting a value for thel1CacheHandleattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for l1CacheHandle (can benull)- Returns:
- A modified copy or the
thisobject
-
withL2CacheHandle
Copy the current immutable object by setting a value for thel2CacheHandleattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for l2CacheHandle (can benull)- Returns:
- A modified copy or the
thisobject
-
withL3CacheHandle
Copy the current immutable object by setting a value for thel3CacheHandleattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for l3CacheHandle (can benull)- Returns:
- A modified copy or the
thisobject
-
withSerialNumber
Copy the current immutable object by setting a value for theserialNumberattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for serialNumber (can benull)- Returns:
- A modified copy or the
thisobject
-
withAssetTag
Copy the current immutable object by setting a value for theassetTagattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for assetTag (can benull)- Returns:
- A modified copy or the
thisobject
-
withPartNumber
Copy the current immutable object by setting a value for thepartNumberattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for partNumber (can benull)- Returns:
- A modified copy or the
thisobject
-
withCoreCount
Copy the current immutable object by setting a value for thecoreCountattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for coreCount (can benull)- Returns:
- A modified copy or the
thisobject
-
withCoreEnabled
Copy the current immutable object by setting a value for thecoreEnabledattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for coreEnabled (can benull)- Returns:
- A modified copy or the
thisobject
-
withThreadCount
Copy the current immutable object by setting a value for thethreadCountattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for threadCount (can benull)- Returns:
- A modified copy or the
thisobject
-
withCharacteristics
Copy the current immutable object with elements that replace the content ofcharacteristics.- Parameters:
elements- The elements to set- Returns:
- A modified copy of
thisobject
-
withCharacteristics
Copy the current immutable object with elements that replace the content ofcharacteristics. A shallow reference equality check is used to prevent copying of the same value by returningthis.- Parameters:
elements- An iterable of characteristics elements to set- Returns:
- A modified copy or
thisif not changed
-
equals
This instance is equal to all instances ofDMIProcessorthat have equal attribute values. -
equalsByValue
-
hashCode
public int hashCode()Computes a hash code from attributes:socketDesignation,type,family,manufacturer,id,signature,flags,version,voltage,externalClock,maxSpeed,currentSpeed,status,upgrade,l1CacheHandle,l2CacheHandle,l3CacheHandle,serialNumber,assetTag,partNumber,coreCount,coreEnabled,threadCount,characteristics. -
fromJson
Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructure- Parameters:
json- A JSON-bindable data structure- Returns:
- An immutable value type
-
copyOf
Creates an immutable copy of aAbstractDMIProcessorvalue. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.- Parameters:
instance- The instance to copy- Returns:
- A copied immutable DMIProcessor instance
-
createSafeList
-
createUnmodifiableList
-