Class ImmutableDMICache
java.lang.Object
io.github.eggy03.dmidecode.entity.processor.DMICache
io.github.eggy03.dmidecode.entity.processor.ImmutableDMICache
@Generated(from="DMICache",
generator="Immutables")
@Generated("org.immutables.processor.ProxyProcessor")
public final class ImmutableDMICache
extends DMICache
Immutable implementation of
DMICache.
Use the builder to create immutable instances:
new ImmutableDMICache.Builder().
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classBuilds instances of typeImmutableDMICache.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure -
Field Summary
FieldsModifier and TypeFieldDescriptionprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable String -
Constructor Summary
ConstructorsModifierConstructorDescriptionprivateImmutableDMICache(@Nullable String socketDesignation, @Nullable String configuration, @Nullable String operationalMode, @Nullable String location, @Nullable String installedSize, @Nullable String maximumSize, @Nullable List<String> supportedSramTypes, @Nullable String installedSramType, @Nullable String speed, @Nullable String errorCorrectionType, @Nullable String systemType, @Nullable String associativity) -
Method Summary
Modifier and TypeMethodDescription@Nullable String@Nullable Stringstatic ImmutableDMICacheCreates an immutable copy of aDMICachevalue.private static <T> List<T> createSafeList(Iterable<? extends T> iterable, boolean checkNulls, boolean skipNulls) private static <T> List<T> createUnmodifiableList(boolean clone, List<? extends T> list) booleanThis instance is equal to all instances ofImmutableDMICachethat have equal attribute values.private booleanequalsByValue(ImmutableDMICache another) @Nullable String(package private) static ImmutableDMICacheDeprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructureinthashCode()Computes a hash code from attributes:socketDesignation,configuration,operationalMode,location,installedSize,maximumSize,supportedSramTypes,installedSramType,speed,errorCorrectionType,systemType,associativity.@Nullable String@Nullable String@Nullable Stringlocation()@Nullable String@Nullable String@Nullable String@Nullable Stringspeed()@Nullable StringtoString()Prints the immutable valueDMICachewith attribute values.final ImmutableDMICachewithAssociativity(@Nullable String value) Copy the current immutable object by setting a value for theassociativityattribute.final ImmutableDMICachewithConfiguration(@Nullable String value) Copy the current immutable object by setting a value for theconfigurationattribute.final ImmutableDMICachewithErrorCorrectionType(@Nullable String value) Copy the current immutable object by setting a value for theerrorCorrectionTypeattribute.final ImmutableDMICachewithInstalledSize(@Nullable String value) Copy the current immutable object by setting a value for theinstalledSizeattribute.final ImmutableDMICachewithInstalledSramType(@Nullable String value) Copy the current immutable object by setting a value for theinstalledSramTypeattribute.final ImmutableDMICachewithLocation(@Nullable String value) Copy the current immutable object by setting a value for thelocationattribute.final ImmutableDMICachewithMaximumSize(@Nullable String value) Copy the current immutable object by setting a value for themaximumSizeattribute.final ImmutableDMICachewithOperationalMode(@Nullable String value) Copy the current immutable object by setting a value for theoperationalModeattribute.final ImmutableDMICachewithSocketDesignation(@Nullable String value) Copy the current immutable object by setting a value for thesocketDesignationattribute.final ImmutableDMICacheCopy the current immutable object by setting a value for thespeedattribute.final ImmutableDMICachewithSupportedSramTypes(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofsupportedSramTypes.final ImmutableDMICachewithSupportedSramTypes(@Nullable String @Nullable ... elements) Copy the current immutable object with elements that replace the content ofsupportedSramTypes.final ImmutableDMICachewithSystemType(@Nullable String value) Copy the current immutable object by setting a value for thesystemTypeattribute.
-
Field Details
-
socketDesignation
-
configuration
-
operationalMode
-
location
-
installedSize
-
maximumSize
-
supportedSramTypes
-
installedSramType
-
speed
-
errorCorrectionType
-
systemType
-
associativity
-
-
Constructor Details
-
ImmutableDMICache
private ImmutableDMICache(@Nullable String socketDesignation, @Nullable String configuration, @Nullable String operationalMode, @Nullable String location, @Nullable String installedSize, @Nullable String maximumSize, @Nullable List<String> supportedSramTypes, @Nullable String installedSramType, @Nullable String speed, @Nullable String errorCorrectionType, @Nullable String systemType, @Nullable String associativity)
-
-
Method Details
-
socketDesignation
- Specified by:
socketDesignationin classDMICache- Returns:
- The value of the
socketDesignationattribute
-
configuration
- Specified by:
configurationin classDMICache- Returns:
- The value of the
configurationattribute
-
operationalMode
- Specified by:
operationalModein classDMICache- Returns:
- The value of the
operationalModeattribute
-
location
-
installedSize
- Specified by:
installedSizein classDMICache- Returns:
- The value of the
installedSizeattribute
-
maximumSize
- Specified by:
maximumSizein classDMICache- Returns:
- The value of the
maximumSizeattribute
-
supportedSramTypes
- Specified by:
supportedSramTypesin classDMICache- Returns:
- The value of the
supportedSramTypesattribute
-
installedSramType
- Specified by:
installedSramTypein classDMICache- Returns:
- The value of the
installedSramTypeattribute
-
speed
-
errorCorrectionType
- Specified by:
errorCorrectionTypein classDMICache- Returns:
- The value of the
errorCorrectionTypeattribute
-
systemType
- Specified by:
systemTypein classDMICache- Returns:
- The value of the
systemTypeattribute
-
associativity
- Specified by:
associativityin classDMICache- Returns:
- The value of the
associativityattribute
-
withSocketDesignation
Copy the current immutable object by setting a value for thesocketDesignationattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for socketDesignation (can benull)- Returns:
- A modified copy or the
thisobject
-
withConfiguration
Copy the current immutable object by setting a value for theconfigurationattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for configuration (can benull)- Returns:
- A modified copy or the
thisobject
-
withOperationalMode
Copy the current immutable object by setting a value for theoperationalModeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for operationalMode (can benull)- Returns:
- A modified copy or the
thisobject
-
withLocation
Copy the current immutable object by setting a value for thelocationattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for location (can benull)- Returns:
- A modified copy or the
thisobject
-
withInstalledSize
Copy the current immutable object by setting a value for theinstalledSizeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for installedSize (can benull)- Returns:
- A modified copy or the
thisobject
-
withMaximumSize
Copy the current immutable object by setting a value for themaximumSizeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for maximumSize (can benull)- Returns:
- A modified copy or the
thisobject
-
withSupportedSramTypes
Copy the current immutable object with elements that replace the content ofsupportedSramTypes.- Parameters:
elements- The elements to set- Returns:
- A modified copy of
thisobject
-
withSupportedSramTypes
public final ImmutableDMICache withSupportedSramTypes(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofsupportedSramTypes. A shallow reference equality check is used to prevent copying of the same value by returningthis.- Parameters:
elements- An iterable of supportedSramTypes elements to set- Returns:
- A modified copy or
thisif not changed
-
withInstalledSramType
Copy the current immutable object by setting a value for theinstalledSramTypeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for installedSramType (can benull)- Returns:
- A modified copy or the
thisobject
-
withSpeed
Copy the current immutable object by setting a value for thespeedattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for speed (can benull)- Returns:
- A modified copy or the
thisobject
-
withErrorCorrectionType
Copy the current immutable object by setting a value for theerrorCorrectionTypeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for errorCorrectionType (can benull)- Returns:
- A modified copy or the
thisobject
-
withSystemType
Copy the current immutable object by setting a value for thesystemTypeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for systemType (can benull)- Returns:
- A modified copy or the
thisobject
-
withAssociativity
Copy the current immutable object by setting a value for theassociativityattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for associativity (can benull)- Returns:
- A modified copy or the
thisobject
-
equals
This instance is equal to all instances ofImmutableDMICachethat have equal attribute values. -
equalsByValue
-
hashCode
public int hashCode()Computes a hash code from attributes:socketDesignation,configuration,operationalMode,location,installedSize,maximumSize,supportedSramTypes,installedSramType,speed,errorCorrectionType,systemType,associativity. -
toString
Prints the immutable valueDMICachewith attribute values. -
fromJson
Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructure- Parameters:
json- A JSON-bindable data structure- Returns:
- An immutable value type
-
copyOf
Creates an immutable copy of aDMICachevalue. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.- Parameters:
instance- The instance to copy- Returns:
- A copied immutable DMICache instance
-
createSafeList
-
createUnmodifiableList
-