Class ImmutableDMICache.Builder
java.lang.Object
io.github.eggy03.dmidecode.entity.processor.ImmutableDMICache.Builder
- Enclosing class:
ImmutableDMICache
@Generated(from="DMICache",
generator="Immutables")
public static final class ImmutableDMICache.Builder
extends Object
Builds instances of type
ImmutableDMICache.
Initialize attributes and then invoke the build() method to create an
immutable instance.
Builder is not thread-safe and generally should not be stored in a field or collection,
but instead used immediately to create instances.
-
Field Summary
FieldsModifier and TypeFieldDescriptionprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable Stringprivate @Nullable String -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddAllSupportedSramTypes(Iterable<@Nullable String> elements) Adds elements tosupportedSramTypeslist.addSupportedSramTypes(@Nullable String element) Adds one element tosupportedSramTypeslist.addSupportedSramTypes(@Nullable String... elements) Adds elements tosupportedSramTypeslist.associativity(@Nullable String associativity) Initializes the value for theassociativityattribute.build()Builds a newImmutableDMICache.configuration(@Nullable String configuration) Initializes the value for theconfigurationattribute.errorCorrectionType(@Nullable String errorCorrectionType) Initializes the value for theerrorCorrectionTypeattribute.Fill a builder with attribute values from the providedDMICacheinstance.installedSize(@Nullable String installedSize) Initializes the value for theinstalledSizeattribute.installedSramType(@Nullable String installedSramType) Initializes the value for theinstalledSramTypeattribute.Initializes the value for thelocationattribute.maximumSize(@Nullable String maximumSize) Initializes the value for themaximumSizeattribute.operationalMode(@Nullable String operationalMode) Initializes the value for theoperationalModeattribute.socketDesignation(@Nullable String socketDesignation) Initializes the value for thesocketDesignationattribute.Initializes the value for thespeedattribute.supportedSramTypes(@Nullable Iterable<@Nullable String> elements) Sets or replaces all elements forsupportedSramTypeslist.systemType(@Nullable String systemType) Initializes the value for thesystemTypeattribute.
-
Field Details
-
socketDesignation
-
configuration
-
operationalMode
-
location
-
installedSize
-
maximumSize
-
supportedSramTypes
-
installedSramType
-
speed
-
errorCorrectionType
-
systemType
-
associativity
-
-
Constructor Details
-
Builder
public Builder()Creates a builder forImmutableDMICacheinstances.new ImmutableDMICache.Builder() .socketDesignation(String | null) // nullablesocketDesignation.configuration(String | null) // nullableconfiguration.operationalMode(String | null) // nullableoperationalMode.location(String | null) // nullablelocation.installedSize(String | null) // nullableinstalledSize.maximumSize(String | null) // nullablemaximumSize.supportedSramTypes(List<String> | null) // nullablesupportedSramTypes.installedSramType(String | null) // nullableinstalledSramType.speed(String | null) // nullablespeed.errorCorrectionType(String | null) // nullableerrorCorrectionType.systemType(String | null) // nullablesystemType.associativity(String | null) // nullableassociativity.build();
-
-
Method Details
-
from
Fill a builder with attribute values from the providedDMICacheinstance. Regular attribute values will be replaced with those from the given instance. Absent optional values will not replace present values. Collection elements and entries will be added, not replaced.- Parameters:
instance- The instance from which to copy values- Returns:
thisbuilder for use in a chained invocation
-
socketDesignation
Initializes the value for thesocketDesignationattribute.- Parameters:
socketDesignation- The value for socketDesignation (can benull)- Returns:
thisbuilder for use in a chained invocation
-
configuration
Initializes the value for theconfigurationattribute.- Parameters:
configuration- The value for configuration (can benull)- Returns:
thisbuilder for use in a chained invocation
-
operationalMode
Initializes the value for theoperationalModeattribute.- Parameters:
operationalMode- The value for operationalMode (can benull)- Returns:
thisbuilder for use in a chained invocation
-
location
Initializes the value for thelocationattribute.- Parameters:
location- The value for location (can benull)- Returns:
thisbuilder for use in a chained invocation
-
installedSize
Initializes the value for theinstalledSizeattribute.- Parameters:
installedSize- The value for installedSize (can benull)- Returns:
thisbuilder for use in a chained invocation
-
maximumSize
Initializes the value for themaximumSizeattribute.- Parameters:
maximumSize- The value for maximumSize (can benull)- Returns:
thisbuilder for use in a chained invocation
-
addSupportedSramTypes
Adds one element tosupportedSramTypeslist.- Parameters:
element- A supportedSramTypes element- Returns:
thisbuilder for use in a chained invocation
-
addSupportedSramTypes
Adds elements tosupportedSramTypeslist.- Parameters:
elements- An array of supportedSramTypes elements- Returns:
thisbuilder for use in a chained invocation
-
supportedSramTypes
public final ImmutableDMICache.Builder supportedSramTypes(@Nullable Iterable<@Nullable String> elements) Sets or replaces all elements forsupportedSramTypeslist.- Parameters:
elements- An iterable of supportedSramTypes elements- Returns:
thisbuilder for use in a chained invocation
-
addAllSupportedSramTypes
public final ImmutableDMICache.Builder addAllSupportedSramTypes(Iterable<@Nullable String> elements) Adds elements tosupportedSramTypeslist.- Parameters:
elements- An iterable of supportedSramTypes elements- Returns:
thisbuilder for use in a chained invocation
-
installedSramType
Initializes the value for theinstalledSramTypeattribute.- Parameters:
installedSramType- The value for installedSramType (can benull)- Returns:
thisbuilder for use in a chained invocation
-
speed
Initializes the value for thespeedattribute.- Parameters:
speed- The value for speed (can benull)- Returns:
thisbuilder for use in a chained invocation
-
errorCorrectionType
Initializes the value for theerrorCorrectionTypeattribute.- Parameters:
errorCorrectionType- The value for errorCorrectionType (can benull)- Returns:
thisbuilder for use in a chained invocation
-
systemType
Initializes the value for thesystemTypeattribute.- Parameters:
systemType- The value for systemType (can benull)- Returns:
thisbuilder for use in a chained invocation
-
associativity
Initializes the value for theassociativityattribute.- Parameters:
associativity- The value for associativity (can benull)- Returns:
thisbuilder for use in a chained invocation
-
build
Builds a newImmutableDMICache.- Returns:
- An immutable instance of DMICache
- Throws:
IllegalStateException- if any required attributes are missing
-