Class ImmutableDMICache.Json
java.lang.Object
io.github.eggy03.dmidecode.entity.processor.DMICache
io.github.eggy03.dmidecode.entity.processor.ImmutableDMICache.Json
- Enclosing class:
ImmutableDMICache
@Generated(from="DMICache",
generator="Immutables")
@Deprecated
static final class ImmutableDMICache.Json
extends DMICache
Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Utility type used to correctly read immutable object from JSON representation.
-
Field Summary
FieldsModifier and TypeFieldDescription(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.Deprecated.(package private) @Nullable StringDeprecated. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescription@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable Stringlocation()Deprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.voidsetAssociativity(@Nullable String associativity) Deprecated.voidsetConfiguration(@Nullable String configuration) Deprecated.voidsetErrorCorrectionType(@Nullable String errorCorrectionType) Deprecated.voidsetInstalledSize(@Nullable String installedSize) Deprecated.voidsetInstalledSramType(@Nullable String installedSramType) Deprecated.voidsetLocation(@Nullable String location) Deprecated.voidsetMaximumSize(@Nullable String maximumSize) Deprecated.voidsetOperationalMode(@Nullable String operationalMode) Deprecated.voidsetSocketDesignation(@Nullable String socketDesignation) Deprecated.voidDeprecated.voidsetSupportedSramTypes(@Nullable List<String> supportedSramTypes) Deprecated.voidsetSystemType(@Nullable String systemType) Deprecated.@Nullable StringDeprecated.@Nullable Stringspeed()Deprecated.Deprecated.@Nullable StringDeprecated.
-
Field Details
-
_socketDesignation
@Nullable String _socketDesignationDeprecated. -
_configuration
@Nullable String _configurationDeprecated. -
_operationalMode
@Nullable String _operationalModeDeprecated. -
_location
@Nullable String _locationDeprecated. -
_installedSize
@Nullable String _installedSizeDeprecated. -
_maximumSize
@Nullable String _maximumSizeDeprecated. -
_supportedSramTypes
Deprecated. -
_installedSramType
@Nullable String _installedSramTypeDeprecated. -
_speed
@Nullable String _speedDeprecated. -
_errorCorrectionType
@Nullable String _errorCorrectionTypeDeprecated. -
_systemType
@Nullable String _systemTypeDeprecated. -
_associativity
@Nullable String _associativityDeprecated.
-
-
Constructor Details
-
Json
Json()Deprecated.
-
-
Method Details
-
setSocketDesignation
Deprecated. -
setConfiguration
Deprecated. -
setOperationalMode
Deprecated. -
setLocation
Deprecated. -
setInstalledSize
Deprecated. -
setMaximumSize
Deprecated. -
setSupportedSramTypes
Deprecated. -
setInstalledSramType
Deprecated. -
setSpeed
Deprecated. -
setErrorCorrectionType
Deprecated. -
setSystemType
Deprecated. -
setAssociativity
Deprecated. -
socketDesignation
Deprecated.- Specified by:
socketDesignationin classDMICache
-
configuration
Deprecated.- Specified by:
configurationin classDMICache
-
operationalMode
Deprecated.- Specified by:
operationalModein classDMICache
-
location
Deprecated. -
installedSize
Deprecated.- Specified by:
installedSizein classDMICache
-
maximumSize
Deprecated.- Specified by:
maximumSizein classDMICache
-
supportedSramTypes
Deprecated.- Specified by:
supportedSramTypesin classDMICache
-
installedSramType
Deprecated.- Specified by:
installedSramTypein classDMICache
-
speed
Deprecated. -
errorCorrectionType
Deprecated.- Specified by:
errorCorrectionTypein classDMICache
-
systemType
Deprecated.- Specified by:
systemTypein classDMICache
-
associativity
Deprecated.- Specified by:
associativityin classDMICache
-