Class ImmutableDMIProcessor
java.lang.Object
io.github.eggy03.dmidecode.entity.processor.DMIProcessor
io.github.eggy03.dmidecode.entity.processor.ImmutableDMIProcessor
@Generated(from="DMIProcessor",
generator="Immutables")
@Generated("org.immutables.processor.ProxyProcessor")
public final class ImmutableDMIProcessor
extends DMIProcessor
Immutable implementation of
DMIProcessor.
Use the builder to create immutable instances:
new ImmutableDMIProcessor.Builder().
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classBuilds instances of typeImmutableDMIProcessor.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure -
Field Summary
FieldsModifier and TypeFieldDescriptionprivate final @Nullable Stringprivate final @Nullable Integerprivate final @Nullable Integerprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Integerprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable Stringprivate final @Nullable String -
Constructor Summary
ConstructorsModifierConstructorDescriptionprivateImmutableDMIProcessor(@Nullable String socketDesignation, @Nullable String type, @Nullable String family, @Nullable String manufacturer, @Nullable String id, @Nullable String signature, @Nullable List<String> flags, @Nullable String version, @Nullable String voltage, @Nullable String externalClock, @Nullable String maxSpeed, @Nullable String currentSpeed, @Nullable String status, @Nullable String upgrade, @Nullable String l1CacheHandle, @Nullable String l2CacheHandle, @Nullable String l3CacheHandle, @Nullable String serialNumber, @Nullable String assetTag, @Nullable String partNumber, @Nullable Integer coreCount, @Nullable Integer coreEnabled, @Nullable Integer threadCount, @Nullable List<String> characteristics) -
Method Summary
Modifier and TypeMethodDescription@Nullable StringassetTag()static ImmutableDMIProcessorcopyOf(DMIProcessor instance) Creates an immutable copy of aDMIProcessorvalue.@Nullable Integer@Nullable Integerprivate static <T> List<T> createSafeList(Iterable<? extends T> iterable, boolean checkNulls, boolean skipNulls) private static <T> List<T> createUnmodifiableList(boolean clone, List<? extends T> list) @Nullable StringbooleanThis instance is equal to all instances ofImmutableDMIProcessorthat have equal attribute values.private booleanequalsByValue(ImmutableDMIProcessor another) @Nullable String@Nullable Stringfamily()flags()(package private) static ImmutableDMIProcessorDeprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructureinthashCode()Computes a hash code from attributes:socketDesignation,type,family,manufacturer,id,signature,flags,version,voltage,externalClock,maxSpeed,currentSpeed,status,upgrade,l1CacheHandle,l2CacheHandle,l3CacheHandle,serialNumber,assetTag,partNumber,coreCount,coreEnabled,threadCount,characteristics.@Nullable Stringid()@Nullable String@Nullable String@Nullable String@Nullable String@Nullable StringmaxSpeed()@Nullable String@Nullable String@Nullable String@Nullable String@Nullable Stringstatus()@Nullable IntegertoString()Prints the immutable valueDMIProcessorwith attribute values.@Nullable Stringtype()@Nullable Stringupgrade()@Nullable Stringversion()@Nullable Stringvoltage()final ImmutableDMIProcessorwithAssetTag(@Nullable String value) Copy the current immutable object by setting a value for theassetTagattribute.final ImmutableDMIProcessorwithCharacteristics(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofcharacteristics.final ImmutableDMIProcessorwithCharacteristics(@Nullable String @Nullable ... elements) Copy the current immutable object with elements that replace the content ofcharacteristics.final ImmutableDMIProcessorwithCoreCount(@Nullable Integer value) Copy the current immutable object by setting a value for thecoreCountattribute.final ImmutableDMIProcessorwithCoreEnabled(@Nullable Integer value) Copy the current immutable object by setting a value for thecoreEnabledattribute.final ImmutableDMIProcessorwithCurrentSpeed(@Nullable String value) Copy the current immutable object by setting a value for thecurrentSpeedattribute.final ImmutableDMIProcessorwithExternalClock(@Nullable String value) Copy the current immutable object by setting a value for theexternalClockattribute.final ImmutableDMIProcessorwithFamily(@Nullable String value) Copy the current immutable object by setting a value for thefamilyattribute.final ImmutableDMIProcessorCopy the current immutable object with elements that replace the content offlags.final ImmutableDMIProcessorCopy the current immutable object with elements that replace the content offlags.final ImmutableDMIProcessorCopy the current immutable object by setting a value for theidattribute.final ImmutableDMIProcessorwithL1CacheHandle(@Nullable String value) Copy the current immutable object by setting a value for thel1CacheHandleattribute.final ImmutableDMIProcessorwithL2CacheHandle(@Nullable String value) Copy the current immutable object by setting a value for thel2CacheHandleattribute.final ImmutableDMIProcessorwithL3CacheHandle(@Nullable String value) Copy the current immutable object by setting a value for thel3CacheHandleattribute.final ImmutableDMIProcessorwithManufacturer(@Nullable String value) Copy the current immutable object by setting a value for themanufacturerattribute.final ImmutableDMIProcessorwithMaxSpeed(@Nullable String value) Copy the current immutable object by setting a value for themaxSpeedattribute.final ImmutableDMIProcessorwithPartNumber(@Nullable String value) Copy the current immutable object by setting a value for thepartNumberattribute.final ImmutableDMIProcessorwithSerialNumber(@Nullable String value) Copy the current immutable object by setting a value for theserialNumberattribute.final ImmutableDMIProcessorwithSignature(@Nullable String value) Copy the current immutable object by setting a value for thesignatureattribute.final ImmutableDMIProcessorwithSocketDesignation(@Nullable String value) Copy the current immutable object by setting a value for thesocketDesignationattribute.final ImmutableDMIProcessorwithStatus(@Nullable String value) Copy the current immutable object by setting a value for thestatusattribute.final ImmutableDMIProcessorwithThreadCount(@Nullable Integer value) Copy the current immutable object by setting a value for thethreadCountattribute.final ImmutableDMIProcessorCopy the current immutable object by setting a value for thetypeattribute.final ImmutableDMIProcessorwithUpgrade(@Nullable String value) Copy the current immutable object by setting a value for theupgradeattribute.final ImmutableDMIProcessorwithVersion(@Nullable String value) Copy the current immutable object by setting a value for theversionattribute.final ImmutableDMIProcessorwithVoltage(@Nullable String value) Copy the current immutable object by setting a value for thevoltageattribute.Methods inherited from class io.github.eggy03.dmidecode.entity.processor.DMIProcessor
toJson
-
Field Details
-
socketDesignation
-
type
-
family
-
manufacturer
-
id
-
signature
-
flags
-
version
-
voltage
-
externalClock
-
maxSpeed
-
currentSpeed
-
status
-
upgrade
-
l1CacheHandle
-
l2CacheHandle
-
l3CacheHandle
-
serialNumber
-
assetTag
-
partNumber
-
coreCount
-
coreEnabled
-
threadCount
-
characteristics
-
-
Constructor Details
-
ImmutableDMIProcessor
private ImmutableDMIProcessor(@Nullable String socketDesignation, @Nullable String type, @Nullable String family, @Nullable String manufacturer, @Nullable String id, @Nullable String signature, @Nullable List<String> flags, @Nullable String version, @Nullable String voltage, @Nullable String externalClock, @Nullable String maxSpeed, @Nullable String currentSpeed, @Nullable String status, @Nullable String upgrade, @Nullable String l1CacheHandle, @Nullable String l2CacheHandle, @Nullable String l3CacheHandle, @Nullable String serialNumber, @Nullable String assetTag, @Nullable String partNumber, @Nullable Integer coreCount, @Nullable Integer coreEnabled, @Nullable Integer threadCount, @Nullable List<String> characteristics)
-
-
Method Details
-
socketDesignation
- Specified by:
socketDesignationin classDMIProcessor- Returns:
- The value of the
socketDesignationattribute
-
type
- Specified by:
typein classDMIProcessor- Returns:
- The value of the
typeattribute
-
family
- Specified by:
familyin classDMIProcessor- Returns:
- The value of the
familyattribute
-
manufacturer
- Specified by:
manufacturerin classDMIProcessor- Returns:
- The value of the
manufacturerattribute
-
id
- Specified by:
idin classDMIProcessor- Returns:
- The value of the
idattribute
-
signature
- Specified by:
signaturein classDMIProcessor- Returns:
- The value of the
signatureattribute
-
flags
- Specified by:
flagsin classDMIProcessor- Returns:
- The value of the
flagsattribute
-
version
- Specified by:
versionin classDMIProcessor- Returns:
- The value of the
versionattribute
-
voltage
- Specified by:
voltagein classDMIProcessor- Returns:
- The value of the
voltageattribute
-
externalClock
- Specified by:
externalClockin classDMIProcessor- Returns:
- The value of the
externalClockattribute
-
maxSpeed
- Specified by:
maxSpeedin classDMIProcessor- Returns:
- The value of the
maxSpeedattribute
-
currentSpeed
- Specified by:
currentSpeedin classDMIProcessor- Returns:
- The value of the
currentSpeedattribute
-
status
- Specified by:
statusin classDMIProcessor- Returns:
- The value of the
statusattribute
-
upgrade
- Specified by:
upgradein classDMIProcessor- Returns:
- The value of the
upgradeattribute
-
l1CacheHandle
- Specified by:
l1CacheHandlein classDMIProcessor- Returns:
- The value of the
l1CacheHandleattribute
-
l2CacheHandle
- Specified by:
l2CacheHandlein classDMIProcessor- Returns:
- The value of the
l2CacheHandleattribute
-
l3CacheHandle
- Specified by:
l3CacheHandlein classDMIProcessor- Returns:
- The value of the
l3CacheHandleattribute
-
serialNumber
- Specified by:
serialNumberin classDMIProcessor- Returns:
- The value of the
serialNumberattribute
-
assetTag
- Specified by:
assetTagin classDMIProcessor- Returns:
- The value of the
assetTagattribute
-
partNumber
- Specified by:
partNumberin classDMIProcessor- Returns:
- The value of the
partNumberattribute
-
coreCount
- Specified by:
coreCountin classDMIProcessor- Returns:
- The value of the
coreCountattribute
-
coreEnabled
- Specified by:
coreEnabledin classDMIProcessor- Returns:
- The value of the
coreEnabledattribute
-
threadCount
- Specified by:
threadCountin classDMIProcessor- Returns:
- The value of the
threadCountattribute
-
characteristics
- Specified by:
characteristicsin classDMIProcessor- Returns:
- The value of the
characteristicsattribute
-
withSocketDesignation
Copy the current immutable object by setting a value for thesocketDesignationattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for socketDesignation (can benull)- Returns:
- A modified copy or the
thisobject
-
withType
Copy the current immutable object by setting a value for thetypeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for type (can benull)- Returns:
- A modified copy or the
thisobject
-
withFamily
Copy the current immutable object by setting a value for thefamilyattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for family (can benull)- Returns:
- A modified copy or the
thisobject
-
withManufacturer
Copy the current immutable object by setting a value for themanufacturerattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for manufacturer (can benull)- Returns:
- A modified copy or the
thisobject
-
withId
Copy the current immutable object by setting a value for theidattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for id (can benull)- Returns:
- A modified copy or the
thisobject
-
withSignature
Copy the current immutable object by setting a value for thesignatureattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for signature (can benull)- Returns:
- A modified copy or the
thisobject
-
withFlags
Copy the current immutable object with elements that replace the content offlags.- Parameters:
elements- The elements to set- Returns:
- A modified copy of
thisobject
-
withFlags
Copy the current immutable object with elements that replace the content offlags. A shallow reference equality check is used to prevent copying of the same value by returningthis.- Parameters:
elements- An iterable of flags elements to set- Returns:
- A modified copy or
thisif not changed
-
withVersion
Copy the current immutable object by setting a value for theversionattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for version (can benull)- Returns:
- A modified copy or the
thisobject
-
withVoltage
Copy the current immutable object by setting a value for thevoltageattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for voltage (can benull)- Returns:
- A modified copy or the
thisobject
-
withExternalClock
Copy the current immutable object by setting a value for theexternalClockattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for externalClock (can benull)- Returns:
- A modified copy or the
thisobject
-
withMaxSpeed
Copy the current immutable object by setting a value for themaxSpeedattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for maxSpeed (can benull)- Returns:
- A modified copy or the
thisobject
-
withCurrentSpeed
Copy the current immutable object by setting a value for thecurrentSpeedattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for currentSpeed (can benull)- Returns:
- A modified copy or the
thisobject
-
withStatus
Copy the current immutable object by setting a value for thestatusattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for status (can benull)- Returns:
- A modified copy or the
thisobject
-
withUpgrade
Copy the current immutable object by setting a value for theupgradeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for upgrade (can benull)- Returns:
- A modified copy or the
thisobject
-
withL1CacheHandle
Copy the current immutable object by setting a value for thel1CacheHandleattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for l1CacheHandle (can benull)- Returns:
- A modified copy or the
thisobject
-
withL2CacheHandle
Copy the current immutable object by setting a value for thel2CacheHandleattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for l2CacheHandle (can benull)- Returns:
- A modified copy or the
thisobject
-
withL3CacheHandle
Copy the current immutable object by setting a value for thel3CacheHandleattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for l3CacheHandle (can benull)- Returns:
- A modified copy or the
thisobject
-
withSerialNumber
Copy the current immutable object by setting a value for theserialNumberattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for serialNumber (can benull)- Returns:
- A modified copy or the
thisobject
-
withAssetTag
Copy the current immutable object by setting a value for theassetTagattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for assetTag (can benull)- Returns:
- A modified copy or the
thisobject
-
withPartNumber
Copy the current immutable object by setting a value for thepartNumberattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for partNumber (can benull)- Returns:
- A modified copy or the
thisobject
-
withCoreCount
Copy the current immutable object by setting a value for thecoreCountattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for coreCount (can benull)- Returns:
- A modified copy or the
thisobject
-
withCoreEnabled
Copy the current immutable object by setting a value for thecoreEnabledattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for coreEnabled (can benull)- Returns:
- A modified copy or the
thisobject
-
withThreadCount
Copy the current immutable object by setting a value for thethreadCountattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for threadCount (can benull)- Returns:
- A modified copy or the
thisobject
-
withCharacteristics
Copy the current immutable object with elements that replace the content ofcharacteristics.- Parameters:
elements- The elements to set- Returns:
- A modified copy of
thisobject
-
withCharacteristics
public final ImmutableDMIProcessor withCharacteristics(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofcharacteristics. A shallow reference equality check is used to prevent copying of the same value by returningthis.- Parameters:
elements- An iterable of characteristics elements to set- Returns:
- A modified copy or
thisif not changed
-
equals
This instance is equal to all instances ofImmutableDMIProcessorthat have equal attribute values. -
equalsByValue
-
hashCode
public int hashCode()Computes a hash code from attributes:socketDesignation,type,family,manufacturer,id,signature,flags,version,voltage,externalClock,maxSpeed,currentSpeed,status,upgrade,l1CacheHandle,l2CacheHandle,l3CacheHandle,serialNumber,assetTag,partNumber,coreCount,coreEnabled,threadCount,characteristics. -
toString
Prints the immutable valueDMIProcessorwith attribute values. -
fromJson
Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructure- Parameters:
json- A JSON-bindable data structure- Returns:
- An immutable value type
-
copyOf
Creates an immutable copy of aDMIProcessorvalue. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.- Parameters:
instance- The instance to copy- Returns:
- A copied immutable DMIProcessor instance
-
createSafeList
-
createUnmodifiableList
-