Class ImmutableDMIProcessor.Json
java.lang.Object
io.github.eggy03.dmidecode.entity.processor.DMIProcessor
io.github.eggy03.dmidecode.entity.processor.ImmutableDMIProcessor.Json
- Enclosing class:
ImmutableDMIProcessor
@Generated(from="DMIProcessor",
generator="Immutables")
@Deprecated
static final class ImmutableDMIProcessor.Json
extends DMIProcessor
Deprecated.
Do not use this type directly, it exists only for the Jackson-binding infrastructure
Utility type used to correctly read immutable object from JSON representation.
-
Field Summary
FieldsModifier and TypeFieldDescription(package private) @Nullable StringDeprecated.Deprecated.(package private) @Nullable IntegerDeprecated.(package private) @Nullable IntegerDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.Deprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable IntegerDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated.(package private) @Nullable StringDeprecated. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescription@Nullable StringassetTag()Deprecated.Deprecated.@Nullable IntegerDeprecated.@Nullable IntegerDeprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable Stringfamily()Deprecated.flags()Deprecated.@Nullable Stringid()Deprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable StringmaxSpeed()Deprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.voidsetAssetTag(@Nullable String assetTag) Deprecated.voidsetCharacteristics(@Nullable List<String> characteristics) Deprecated.voidsetCoreCount(@Nullable Integer coreCount) Deprecated.voidsetCoreEnabled(@Nullable Integer coreEnabled) Deprecated.voidsetCurrentSpeed(@Nullable String currentSpeed) Deprecated.voidsetExternalClock(@Nullable String externalClock) Deprecated.voidDeprecated.voidDeprecated.voidDeprecated.voidsetL1CacheHandle(@Nullable String l1CacheHandle) Deprecated.voidsetL2CacheHandle(@Nullable String l2CacheHandle) Deprecated.voidsetL3CacheHandle(@Nullable String l3CacheHandle) Deprecated.voidsetManufacturer(@Nullable String manufacturer) Deprecated.voidsetMaxSpeed(@Nullable String maxSpeed) Deprecated.voidsetPartNumber(@Nullable String partNumber) Deprecated.voidsetSerialNumber(@Nullable String serialNumber) Deprecated.voidsetSignature(@Nullable String signature) Deprecated.voidsetSocketDesignation(@Nullable String socketDesignation) Deprecated.voidDeprecated.voidsetThreadCount(@Nullable Integer threadCount) Deprecated.voidDeprecated.voidsetUpgrade(@Nullable String upgrade) Deprecated.voidsetVersion(@Nullable String version) Deprecated.voidsetVoltage(@Nullable String voltage) Deprecated.@Nullable StringDeprecated.@Nullable StringDeprecated.@Nullable Stringstatus()Deprecated.@Nullable IntegerDeprecated.@Nullable Stringtype()Deprecated.@Nullable Stringupgrade()Deprecated.@Nullable Stringversion()Deprecated.@Nullable Stringvoltage()Deprecated.Methods inherited from class io.github.eggy03.dmidecode.entity.processor.DMIProcessor
toJson
-
Field Details
-
_socketDesignation
@Nullable String _socketDesignationDeprecated. -
_type
@Nullable String _typeDeprecated. -
_family
@Nullable String _familyDeprecated. -
_manufacturer
@Nullable String _manufacturerDeprecated. -
_id
@Nullable String _idDeprecated. -
_signature
@Nullable String _signatureDeprecated. -
_flags
Deprecated. -
_version
@Nullable String _versionDeprecated. -
_voltage
@Nullable String _voltageDeprecated. -
_externalClock
@Nullable String _externalClockDeprecated. -
_maxSpeed
@Nullable String _maxSpeedDeprecated. -
_currentSpeed
@Nullable String _currentSpeedDeprecated. -
_status
@Nullable String _statusDeprecated. -
_upgrade
@Nullable String _upgradeDeprecated. -
_l1CacheHandle
@Nullable String _l1CacheHandleDeprecated. -
_l2CacheHandle
@Nullable String _l2CacheHandleDeprecated. -
_l3CacheHandle
@Nullable String _l3CacheHandleDeprecated. -
_serialNumber
@Nullable String _serialNumberDeprecated. -
_assetTag
@Nullable String _assetTagDeprecated. -
_partNumber
@Nullable String _partNumberDeprecated. -
_coreCount
@Nullable Integer _coreCountDeprecated. -
_coreEnabled
@Nullable Integer _coreEnabledDeprecated. -
_threadCount
@Nullable Integer _threadCountDeprecated. -
_characteristics
Deprecated.
-
-
Constructor Details
-
Json
Json()Deprecated.
-
-
Method Details
-
setSocketDesignation
Deprecated. -
setType
Deprecated. -
setFamily
Deprecated. -
setManufacturer
Deprecated. -
setId
Deprecated. -
setSignature
Deprecated. -
setFlags
Deprecated. -
setVersion
Deprecated. -
setVoltage
Deprecated. -
setExternalClock
Deprecated. -
setMaxSpeed
Deprecated. -
setCurrentSpeed
Deprecated. -
setStatus
Deprecated. -
setUpgrade
Deprecated. -
setL1CacheHandle
Deprecated. -
setL2CacheHandle
Deprecated. -
setL3CacheHandle
Deprecated. -
setSerialNumber
Deprecated. -
setAssetTag
Deprecated. -
setPartNumber
Deprecated. -
setCoreCount
Deprecated. -
setCoreEnabled
Deprecated. -
setThreadCount
Deprecated. -
setCharacteristics
Deprecated. -
socketDesignation
Deprecated.- Specified by:
socketDesignationin classDMIProcessor
-
type
Deprecated.- Specified by:
typein classDMIProcessor
-
family
Deprecated.- Specified by:
familyin classDMIProcessor
-
manufacturer
Deprecated.- Specified by:
manufacturerin classDMIProcessor
-
id
Deprecated.- Specified by:
idin classDMIProcessor
-
signature
Deprecated.- Specified by:
signaturein classDMIProcessor
-
flags
Deprecated.- Specified by:
flagsin classDMIProcessor
-
version
Deprecated.- Specified by:
versionin classDMIProcessor
-
voltage
Deprecated.- Specified by:
voltagein classDMIProcessor
-
externalClock
Deprecated.- Specified by:
externalClockin classDMIProcessor
-
maxSpeed
Deprecated.- Specified by:
maxSpeedin classDMIProcessor
-
currentSpeed
Deprecated.- Specified by:
currentSpeedin classDMIProcessor
-
status
Deprecated.- Specified by:
statusin classDMIProcessor
-
upgrade
Deprecated.- Specified by:
upgradein classDMIProcessor
-
l1CacheHandle
Deprecated.- Specified by:
l1CacheHandlein classDMIProcessor
-
l2CacheHandle
Deprecated.- Specified by:
l2CacheHandlein classDMIProcessor
-
l3CacheHandle
Deprecated.- Specified by:
l3CacheHandlein classDMIProcessor
-
serialNumber
Deprecated.- Specified by:
serialNumberin classDMIProcessor
-
assetTag
Deprecated.- Specified by:
assetTagin classDMIProcessor
-
partNumber
Deprecated.- Specified by:
partNumberin classDMIProcessor
-
coreCount
Deprecated.- Specified by:
coreCountin classDMIProcessor
-
coreEnabled
Deprecated.- Specified by:
coreEnabledin classDMIProcessor
-
threadCount
Deprecated.- Specified by:
threadCountin classDMIProcessor
-
characteristics
Deprecated.- Specified by:
characteristicsin classDMIProcessor
-