Uses of Class
io.github.eggy03.dmidecode.entity.processor.DMICache
Packages that use DMICache
Package
Description
-
Uses of DMICache in io.github.eggy03.dmidecode.entity.processor
Methods in io.github.eggy03.dmidecode.entity.processor that return DMICacheModifier and TypeMethodDescriptionDMICache.Builder.build()Builds a newDMICache.static DMICacheDMICache.copyOf(AbstractDMICache instance) Creates an immutable copy of aAbstractDMICachevalue.(package private) static DMICacheDMICache.fromJson(DMICache.Json json) Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructurefinal DMICacheDMICache.withAssociativity(@Nullable String value) Copy the current immutable object by setting a value for theassociativityattribute.final DMICacheDMICache.withConfiguration(@Nullable String value) Copy the current immutable object by setting a value for theconfigurationattribute.final DMICacheDMICache.withErrorCorrectionType(@Nullable String value) Copy the current immutable object by setting a value for theerrorCorrectionTypeattribute.final DMICacheDMICache.withInstalledSize(@Nullable String value) Copy the current immutable object by setting a value for theinstalledSizeattribute.final DMICacheDMICache.withInstalledSramType(@Nullable String value) Copy the current immutable object by setting a value for theinstalledSramTypeattribute.final DMICacheDMICache.withLocation(@Nullable String value) Copy the current immutable object by setting a value for thelocationattribute.final DMICacheDMICache.withMaximumSize(@Nullable String value) Copy the current immutable object by setting a value for themaximumSizeattribute.final DMICacheDMICache.withOperationalMode(@Nullable String value) Copy the current immutable object by setting a value for theoperationalModeattribute.final DMICacheDMICache.withSocketDesignation(@Nullable String value) Copy the current immutable object by setting a value for thesocketDesignationattribute.final DMICacheCopy the current immutable object by setting a value for thespeedattribute.final DMICacheDMICache.withSupportedSramTypes(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofsupportedSramTypes.final DMICacheDMICache.withSupportedSramTypes(@Nullable String @Nullable ... elements) Copy the current immutable object with elements that replace the content ofsupportedSramTypes.final DMICacheDMICache.withSystemType(@Nullable String value) Copy the current immutable object by setting a value for thesystemTypeattribute.Methods in io.github.eggy03.dmidecode.entity.processor with parameters of type DMICache -
Uses of DMICache in io.github.eggy03.dmidecode.service.processor
Methods in io.github.eggy03.dmidecode.service.processor that return types with arguments of type DMICacheModifier and TypeMethodDescription@Unmodifiable @NonNull List<DMICache> DMICacheService.get(long timeout) Retrieves cache entries present in the system using an isolateddmidecodeprocess with a configurable timeout.