Uses of Class
io.github.eggy03.dmidecode.entity.processor.DMIProcessor
Packages that use DMIProcessor
Package
Description
-
Uses of DMIProcessor in io.github.eggy03.dmidecode.entity.processor
Methods in io.github.eggy03.dmidecode.entity.processor that return DMIProcessorModifier and TypeMethodDescriptionDMIProcessor.Builder.build()Builds a newDMIProcessor.static DMIProcessorDMIProcessor.copyOf(AbstractDMIProcessor instance) Creates an immutable copy of aAbstractDMIProcessorvalue.(package private) static DMIProcessorDMIProcessor.fromJson(DMIProcessor.Json json) Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructurefinal DMIProcessorDMIProcessor.withAssetTag(@Nullable String value) Copy the current immutable object by setting a value for theassetTagattribute.final DMIProcessorDMIProcessor.withCharacteristics(@Nullable Iterable<@Nullable String> elements) Copy the current immutable object with elements that replace the content ofcharacteristics.final DMIProcessorDMIProcessor.withCharacteristics(@Nullable String @Nullable ... elements) Copy the current immutable object with elements that replace the content ofcharacteristics.final DMIProcessorDMIProcessor.withCoreCount(@Nullable Integer value) Copy the current immutable object by setting a value for thecoreCountattribute.final DMIProcessorDMIProcessor.withCoreEnabled(@Nullable Integer value) Copy the current immutable object by setting a value for thecoreEnabledattribute.final DMIProcessorDMIProcessor.withCurrentSpeed(@Nullable String value) Copy the current immutable object by setting a value for thecurrentSpeedattribute.final DMIProcessorDMIProcessor.withExternalClock(@Nullable String value) Copy the current immutable object by setting a value for theexternalClockattribute.final DMIProcessorDMIProcessor.withFamily(@Nullable String value) Copy the current immutable object by setting a value for thefamilyattribute.final DMIProcessorCopy the current immutable object with elements that replace the content offlags.final DMIProcessorCopy the current immutable object with elements that replace the content offlags.final DMIProcessorCopy the current immutable object by setting a value for theidattribute.final DMIProcessorDMIProcessor.withL1CacheHandle(@Nullable String value) Copy the current immutable object by setting a value for thel1CacheHandleattribute.final DMIProcessorDMIProcessor.withL2CacheHandle(@Nullable String value) Copy the current immutable object by setting a value for thel2CacheHandleattribute.final DMIProcessorDMIProcessor.withL3CacheHandle(@Nullable String value) Copy the current immutable object by setting a value for thel3CacheHandleattribute.final DMIProcessorDMIProcessor.withManufacturer(@Nullable String value) Copy the current immutable object by setting a value for themanufacturerattribute.final DMIProcessorDMIProcessor.withMaxSpeed(@Nullable String value) Copy the current immutable object by setting a value for themaxSpeedattribute.final DMIProcessorDMIProcessor.withPartNumber(@Nullable String value) Copy the current immutable object by setting a value for thepartNumberattribute.final DMIProcessorDMIProcessor.withSerialNumber(@Nullable String value) Copy the current immutable object by setting a value for theserialNumberattribute.final DMIProcessorDMIProcessor.withSignature(@Nullable String value) Copy the current immutable object by setting a value for thesignatureattribute.final DMIProcessorDMIProcessor.withSocketDesignation(@Nullable String value) Copy the current immutable object by setting a value for thesocketDesignationattribute.final DMIProcessorDMIProcessor.withStatus(@Nullable String value) Copy the current immutable object by setting a value for thestatusattribute.final DMIProcessorDMIProcessor.withThreadCount(@Nullable Integer value) Copy the current immutable object by setting a value for thethreadCountattribute.final DMIProcessorCopy the current immutable object by setting a value for thetypeattribute.final DMIProcessorDMIProcessor.withUpgrade(@Nullable String value) Copy the current immutable object by setting a value for theupgradeattribute.final DMIProcessorDMIProcessor.withVersion(@Nullable String value) Copy the current immutable object by setting a value for theversionattribute.final DMIProcessorDMIProcessor.withVoltage(@Nullable String value) Copy the current immutable object by setting a value for thevoltageattribute.Methods in io.github.eggy03.dmidecode.entity.processor with parameters of type DMIProcessorModifier and TypeMethodDescriptionprivate booleanDMIProcessor.equalsByValue(DMIProcessor another) -
Uses of DMIProcessor in io.github.eggy03.dmidecode.service.processor
Methods in io.github.eggy03.dmidecode.service.processor that return types with arguments of type DMIProcessorModifier and TypeMethodDescription@Unmodifiable @NonNull List<DMIProcessor> DMIProcessorService.get(long timeout) Retrieves processor information present in the system using an isolateddmidecodeprocess with a configurable timeout.