Package io.github.eggy03.dmidecode.entity.processor


package io.github.eggy03.dmidecode.entity.processor
  • Classes
    Class
    Description
    Immutable representation of processor cache information retrieved via DMI.
    Immutable representation of processor information retrieved via DMI.
    Immutable representation of processor cache information retrieved via DMI.
    Builds instances of type DMICache.
    Deprecated.
    Do not use this type directly, it exists only for the Jackson-binding infrastructure
    Immutable representation of processor information retrieved via DMI.
    Builds instances of type DMIProcessor.
    Deprecated.
    Do not use this type directly, it exists only for the Jackson-binding infrastructure