Uses of Package
io.github.eggy03.dmidecode.entity.processor
Packages that use io.github.eggy03.dmidecode.entity.processor
Package
Description
-
Classes in io.github.eggy03.dmidecode.entity.processor used by io.github.eggy03.dmidecode.entity.processorClassDescriptionImmutable representation of processor cache information retrieved via DMI.Immutable representation of processor information retrieved via DMI.Immutable representation of processor cache information retrieved via DMI.Builds instances of type
DMICache.Deprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructureImmutable representation of processor information retrieved via DMI.Builds instances of typeDMIProcessor.Deprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure -
Classes in io.github.eggy03.dmidecode.entity.processor used by io.github.eggy03.dmidecode.service.processorClassDescriptionImmutable representation of processor cache information retrieved via DMI.Immutable representation of processor information retrieved via DMI.