Class DMISystem
java.lang.Object
io.github.eggy03.dmidecode.entity.system.AbstractDMISystem
io.github.eggy03.dmidecode.entity.system.DMISystem
@Generated(from="AbstractDMISystem",
generator="Immutables")
@Generated("org.immutables.processor.ProxyProcessor")
public final class DMISystem
extends AbstractDMISystem
Immutable representation of system information retrieved via DMI.
Fields correspond to properties reported by dmidecode for the System
Information (Type 1) SMBIOS structure.
Instances of this class are thread-safe.
Usage example
DMISystem system = new DMISystem.Builder()
.manufacturer("LENOVO")
.productName("ThinkPad T14 Gen 3")
.serialNumber("PF123ABC")
.uuid("4C4C4544-0038-4D10-8051-CAC04F4A1234")
.build();
// Create a modified copy
DMISystem updated = system
.withSkuNumber("21CFCTO1WW");
- Since:
- 0.2.0
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classBuilds instances of typeDMISystem.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure -
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic DMISystemcopyOf(AbstractDMISystem instance) Creates an immutable copy of aAbstractDMISystemvalue.booleanThis instance is equal to all instances ofDMISystemthat have equal attribute values.private booleanequalsByValue(DMISystem another) @Nullable Stringfamily()(package private) static DMISystemfromJson(DMISystem.Json json) Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructureinthashCode()Computes a hash code from attributes:manufacturer,productName,version,serialNumber,uuid,wakeupType,skuNumber,family.@Nullable String@Nullable String@Nullable String@Nullable String@Nullable Stringuuid()@Nullable Stringversion()@Nullable Stringfinal DMISystemwithFamily(@Nullable String value) Copy the current immutable object by setting a value for thefamilyattribute.final DMISystemwithManufacturer(@Nullable String value) Copy the current immutable object by setting a value for themanufacturerattribute.final DMISystemwithProductName(@Nullable String value) Copy the current immutable object by setting a value for theproductNameattribute.final DMISystemwithSerialNumber(@Nullable String value) Copy the current immutable object by setting a value for theserialNumberattribute.final DMISystemwithSkuNumber(@Nullable String value) Copy the current immutable object by setting a value for theskuNumberattribute.final DMISystemCopy the current immutable object by setting a value for theuuidattribute.final DMISystemwithVersion(@Nullable String value) Copy the current immutable object by setting a value for theversionattribute.final DMISystemwithWakeupType(@Nullable String value) Copy the current immutable object by setting a value for thewakeupTypeattribute.Methods inherited from class io.github.eggy03.dmidecode.entity.system.AbstractDMISystem
toString
-
Field Details
-
manufacturer
-
productName
-
version
-
serialNumber
-
uuid
-
wakeupType
-
skuNumber
-
family
-
-
Constructor Details
-
DMISystem
-
-
Method Details
-
manufacturer
- Specified by:
manufacturerin classAbstractDMISystem- Returns:
- The value of the
manufacturerattribute
-
productName
- Specified by:
productNamein classAbstractDMISystem- Returns:
- The value of the
productNameattribute
-
version
- Specified by:
versionin classAbstractDMISystem- Returns:
- The value of the
versionattribute
-
serialNumber
- Specified by:
serialNumberin classAbstractDMISystem- Returns:
- The value of the
serialNumberattribute
-
uuid
- Specified by:
uuidin classAbstractDMISystem- Returns:
- The value of the
uuidattribute
-
wakeupType
- Specified by:
wakeupTypein classAbstractDMISystem- Returns:
- The value of the
wakeupTypeattribute
-
skuNumber
- Specified by:
skuNumberin classAbstractDMISystem- Returns:
- The value of the
skuNumberattribute
-
family
- Specified by:
familyin classAbstractDMISystem- Returns:
- The value of the
familyattribute
-
withManufacturer
Copy the current immutable object by setting a value for themanufacturerattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for manufacturer (can benull)- Returns:
- A modified copy or the
thisobject
-
withProductName
Copy the current immutable object by setting a value for theproductNameattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for productName (can benull)- Returns:
- A modified copy or the
thisobject
-
withVersion
Copy the current immutable object by setting a value for theversionattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for version (can benull)- Returns:
- A modified copy or the
thisobject
-
withSerialNumber
Copy the current immutable object by setting a value for theserialNumberattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for serialNumber (can benull)- Returns:
- A modified copy or the
thisobject
-
withUuid
Copy the current immutable object by setting a value for theuuidattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for uuid (can benull)- Returns:
- A modified copy or the
thisobject
-
withWakeupType
Copy the current immutable object by setting a value for thewakeupTypeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for wakeupType (can benull)- Returns:
- A modified copy or the
thisobject
-
withSkuNumber
Copy the current immutable object by setting a value for theskuNumberattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for skuNumber (can benull)- Returns:
- A modified copy or the
thisobject
-
withFamily
Copy the current immutable object by setting a value for thefamilyattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for family (can benull)- Returns:
- A modified copy or the
thisobject
-
equals
This instance is equal to all instances ofDMISystemthat have equal attribute values. -
equalsByValue
-
hashCode
public int hashCode()Computes a hash code from attributes:manufacturer,productName,version,serialNumber,uuid,wakeupType,skuNumber,family. -
fromJson
Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructure- Parameters:
json- A JSON-bindable data structure- Returns:
- An immutable value type
-
copyOf
Creates an immutable copy of aAbstractDMISystemvalue. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.- Parameters:
instance- The instance to copy- Returns:
- A copied immutable DMISystem instance
-