Class ImmutableDMISystem
java.lang.Object
io.github.eggy03.dmidecode.entity.system.DMISystem
io.github.eggy03.dmidecode.entity.system.ImmutableDMISystem
@Generated(from="DMISystem",
generator="Immutables")
@Generated("org.immutables.processor.ProxyProcessor")
public final class ImmutableDMISystem
extends DMISystem
Immutable implementation of
DMISystem.
Use the builder to create immutable instances:
new ImmutableDMISystem.Builder().
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classBuilds instances of typeImmutableDMISystem.(package private) static final classDeprecated.Do not use this type directly, it exists only for the Jackson-binding infrastructure -
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic ImmutableDMISystemCreates an immutable copy of aDMISystemvalue.booleanThis instance is equal to all instances ofImmutableDMISystemthat have equal attribute values.private booleanequalsByValue(ImmutableDMISystem another) @Nullable Stringfamily()(package private) static ImmutableDMISystemDeprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructureinthashCode()Computes a hash code from attributes:manufacturer,productName,version,serialNumber,uuid,wakeupType,skuNumber,family.@Nullable String@Nullable String@Nullable String@Nullable StringtoString()Prints the immutable valueDMISystemwith attribute values.@Nullable Stringuuid()@Nullable Stringversion()@Nullable Stringfinal ImmutableDMISystemwithFamily(@Nullable String value) Copy the current immutable object by setting a value for thefamilyattribute.final ImmutableDMISystemwithManufacturer(@Nullable String value) Copy the current immutable object by setting a value for themanufacturerattribute.final ImmutableDMISystemwithProductName(@Nullable String value) Copy the current immutable object by setting a value for theproductNameattribute.final ImmutableDMISystemwithSerialNumber(@Nullable String value) Copy the current immutable object by setting a value for theserialNumberattribute.final ImmutableDMISystemwithSkuNumber(@Nullable String value) Copy the current immutable object by setting a value for theskuNumberattribute.final ImmutableDMISystemCopy the current immutable object by setting a value for theuuidattribute.final ImmutableDMISystemwithVersion(@Nullable String value) Copy the current immutable object by setting a value for theversionattribute.final ImmutableDMISystemwithWakeupType(@Nullable String value) Copy the current immutable object by setting a value for thewakeupTypeattribute.
-
Field Details
-
manufacturer
-
productName
-
version
-
serialNumber
-
uuid
-
wakeupType
-
skuNumber
-
family
-
-
Constructor Details
-
ImmutableDMISystem
-
-
Method Details
-
manufacturer
- Specified by:
manufacturerin classDMISystem- Returns:
- The value of the
manufacturerattribute
-
productName
- Specified by:
productNamein classDMISystem- Returns:
- The value of the
productNameattribute
-
version
-
serialNumber
- Specified by:
serialNumberin classDMISystem- Returns:
- The value of the
serialNumberattribute
-
uuid
-
wakeupType
- Specified by:
wakeupTypein classDMISystem- Returns:
- The value of the
wakeupTypeattribute
-
skuNumber
-
family
-
withManufacturer
Copy the current immutable object by setting a value for themanufacturerattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for manufacturer (can benull)- Returns:
- A modified copy or the
thisobject
-
withProductName
Copy the current immutable object by setting a value for theproductNameattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for productName (can benull)- Returns:
- A modified copy or the
thisobject
-
withVersion
Copy the current immutable object by setting a value for theversionattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for version (can benull)- Returns:
- A modified copy or the
thisobject
-
withSerialNumber
Copy the current immutable object by setting a value for theserialNumberattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for serialNumber (can benull)- Returns:
- A modified copy or the
thisobject
-
withUuid
Copy the current immutable object by setting a value for theuuidattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for uuid (can benull)- Returns:
- A modified copy or the
thisobject
-
withWakeupType
Copy the current immutable object by setting a value for thewakeupTypeattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for wakeupType (can benull)- Returns:
- A modified copy or the
thisobject
-
withSkuNumber
Copy the current immutable object by setting a value for theskuNumberattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for skuNumber (can benull)- Returns:
- A modified copy or the
thisobject
-
withFamily
Copy the current immutable object by setting a value for thefamilyattribute. An equals check used to prevent copying of the same value by returningthis.- Parameters:
value- A new value for family (can benull)- Returns:
- A modified copy or the
thisobject
-
equals
This instance is equal to all instances ofImmutableDMISystemthat have equal attribute values. -
equalsByValue
-
hashCode
public int hashCode()Computes a hash code from attributes:manufacturer,productName,version,serialNumber,uuid,wakeupType,skuNumber,family. -
toString
Prints the immutable valueDMISystemwith attribute values. -
fromJson
Deprecated.Do not use this method directly, it exists only for the Jackson-binding infrastructure- Parameters:
json- A JSON-bindable data structure- Returns:
- An immutable value type
-
copyOf
Creates an immutable copy of aDMISystemvalue. Uses accessors to get values to initialize the new immutable instance. If an instance is already immutable, it is returned as is.- Parameters:
instance- The instance to copy- Returns:
- A copied immutable DMISystem instance
-