Class ImmutableDMISystem.Builder
java.lang.Object
io.github.eggy03.dmidecode.entity.system.ImmutableDMISystem.Builder
- Enclosing class:
ImmutableDMISystem
@Generated(from="DMISystem",
generator="Immutables")
public static final class ImmutableDMISystem.Builder
extends Object
Builds instances of type
ImmutableDMISystem.
Initialize attributes and then invoke the build() method to create an
immutable instance.
Builder is not thread-safe and generally should not be stored in a field or collection,
but instead used immediately to create instances.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Builds a newImmutableDMISystem.Initializes the value for thefamilyattribute.Fill a builder with attribute values from the providedDMISysteminstance.manufacturer(@Nullable String manufacturer) Initializes the value for themanufacturerattribute.productName(@Nullable String productName) Initializes the value for theproductNameattribute.serialNumber(@Nullable String serialNumber) Initializes the value for theserialNumberattribute.Initializes the value for theskuNumberattribute.Initializes the value for theuuidattribute.Initializes the value for theversionattribute.wakeupType(@Nullable String wakeupType) Initializes the value for thewakeupTypeattribute.
-
Field Details
-
manufacturer
-
productName
-
version
-
serialNumber
-
uuid
-
wakeupType
-
skuNumber
-
family
-
-
Constructor Details
-
Builder
public Builder()Creates a builder forImmutableDMISysteminstances.new ImmutableDMISystem.Builder() .manufacturer(String | null) // nullablemanufacturer.productName(String | null) // nullableproductName.version(String | null) // nullableversion.serialNumber(String | null) // nullableserialNumber.uuid(String | null) // nullableuuid.wakeupType(String | null) // nullablewakeupType.skuNumber(String | null) // nullableskuNumber.family(String | null) // nullablefamily.build();
-
-
Method Details
-
from
Fill a builder with attribute values from the providedDMISysteminstance. Regular attribute values will be replaced with those from the given instance. Absent optional values will not replace present values.- Parameters:
instance- The instance from which to copy values- Returns:
thisbuilder for use in a chained invocation
-
manufacturer
Initializes the value for themanufacturerattribute.- Parameters:
manufacturer- The value for manufacturer (can benull)- Returns:
thisbuilder for use in a chained invocation
-
productName
Initializes the value for theproductNameattribute.- Parameters:
productName- The value for productName (can benull)- Returns:
thisbuilder for use in a chained invocation
-
version
Initializes the value for theversionattribute.- Parameters:
version- The value for version (can benull)- Returns:
thisbuilder for use in a chained invocation
-
serialNumber
Initializes the value for theserialNumberattribute.- Parameters:
serialNumber- The value for serialNumber (can benull)- Returns:
thisbuilder for use in a chained invocation
-
uuid
Initializes the value for theuuidattribute.- Parameters:
uuid- The value for uuid (can benull)- Returns:
thisbuilder for use in a chained invocation
-
wakeupType
Initializes the value for thewakeupTypeattribute.- Parameters:
wakeupType- The value for wakeupType (can benull)- Returns:
thisbuilder for use in a chained invocation
-
skuNumber
Initializes the value for theskuNumberattribute.- Parameters:
skuNumber- The value for skuNumber (can benull)- Returns:
thisbuilder for use in a chained invocation
-
family
Initializes the value for thefamilyattribute.- Parameters:
family- The value for family (can benull)- Returns:
thisbuilder for use in a chained invocation
-
build
Builds a newImmutableDMISystem.- Returns:
- An immutable instance of DMISystem
- Throws:
IllegalStateException- if any required attributes are missing
-