Interface OptionalCommonDMIServiceInterface<S>
- Type Parameters:
S- the entity type returned by the service implementation
- All Known Implementing Classes:
DMIBaseboardService,DMIBIOSLanguageService,DMIChassisService,DMIPhysicalMemoryArrayService,DMISystemService
public interface OptionalCommonDMIServiceInterface<S>
Common service interface whose method implementations provide a way to fetch
a single DMI structure from the system using the
dmidecode utility
in the form of an Optional.
Useful for implementing services that are expected to return at most one DMI structure, such as system information, processor details, or chassis data.
- Since:
- 0.1.0
- See Also:
-
Method Summary
-
Method Details
-
get
Implementations of this method are expected to execute the correspondingdmidecodecommand and then map the output to the expected entity type.- Parameters:
timeout- the maximum time (in seconds) to wait for thedmidecodecommand to complete before terminating the process- Returns:
- an
Optionalcontaining the entity of type<S>if present, orOptional.empty()if the information is unavailable or not reported by the system - Since:
- 0.1.0
-